-- 员工表
CREATE TABLE `employees` (
  `employee_id` INT AUTO_INCREMENT PRIMARY KEY,
  `username` VARCHAR(50) UNIQUE NOT NULL,
  `password_hash` VARCHAR(255) NOT NULL,
  `role` ENUM('admin','cashier','chef','manager') NOT NULL,
  `last_login` DATETIME,
  `created_at` DATETIME DEFAULT CURRENT_TIMESTAMP
);

-- 用户表
CREATE TABLE `users` (
  `user_id` INT AUTO_INCREMENT PRIMARY KEY,
  `phone` VARCHAR(20) UNIQUE,
  `wechat_id` VARCHAR(50),
  `reg_date` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `last_login` DATETIME
);

-- 会员表
CREATE TABLE `members` (
  `member_id` INT PRIMARY KEY,
  `user_id` INT UNIQUE,
  `level` INT DEFAULT 1,
  `points` INT DEFAULT 0,
  `join_date` DATE,
  FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`)
);

-- 桌台表
CREATE TABLE `dining_tables` (
  `table_id` INT AUTO_INCREMENT PRIMARY KEY,
  `qr_code` VARCHAR(100) UNIQUE,
  `status` ENUM('空闲','用餐中','已预订') DEFAULT '空闲'
);

-- 菜品表
CREATE TABLE `dishes` (
  `dish_id` INT AUTO_INCREMENT PRIMARY KEY,
  `name` VARCHAR(100) NOT NULL,
  `price` DECIMAL(10,2) NOT NULL,
  `category` ENUM('热菜','凉菜','饮品','主食'),
  `stock` INT DEFAULT 0,
  `is_available` BOOLEAN DEFAULT TRUE
);

-- 订单表
CREATE TABLE `orders` (
  `order_id` VARCHAR(20) PRIMARY KEY,
  `user_id` INT,
  `table_id` INT,
  `type` ENUM('堂食','外带','外卖'),
  `status` ENUM('待支付','进行中','已完成','已取消'),
  `total_amount` DECIMAL(10,2),
  `create_time` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `payment_time` DATETIME,
  FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`),
  FOREIGN KEY (`table_id`) REFERENCES `dining_tables`(`table_id`)
);

-- 订单详情表
CREATE TABLE `order_details` (
  `detail_id` INT AUTO_INCREMENT PRIMARY KEY,
  `order_id` VARCHAR(20),
  `dish_id` INT,
  `quantity` INT,
  `price` DECIMAL(10,2),
  `status` ENUM('等待中','制作中','已完成'),
  FOREIGN KEY (`order_id`) REFERENCES `orders`(`order_id`),
  FOREIGN KEY (`dish_id`) REFERENCES `dishes`(`dish_id`)
);

-- 支付表
CREATE TABLE `payments` (
  `payment_id` VARCHAR(20) PRIMARY KEY,
  `order_id` VARCHAR(20),
  `amount` DECIMAL(10,2),
  `method` ENUM('微信','支付宝','现金','会员卡'),
  `status` ENUM('待支付','已支付','已退款'),
  `transaction_id` VARCHAR(100),
  `pay_time` DATETIME,
  FOREIGN KEY (`order_id`) REFERENCES `orders`(`order_id`)
);

-- 厨房订单表
CREATE TABLE `kitchen_orders` (
  `kitchen_id` INT AUTO_INCREMENT PRIMARY KEY,
  `detail_id` INT,
  `station` ENUM('热菜区','凉菜区','饮品区'),
  `start_time` DATETIME,
  `completion_time` DATETIME,
  FOREIGN KEY (`detail_id`) REFERENCES `order_details`(`detail_id`)
);

-- 优惠券表
CREATE TABLE `coupons` (
  `coupon_id` VARCHAR(20) PRIMARY KEY,
  `user_id` INT,
  `type` ENUM('满减','折扣','赠品'),
  `discount_amount` DECIMAL(10,2),
  `min_amount` DECIMAL(10,2),
  `start_date` DATE,
  `end_date` DATE,
  `status` ENUM('未使用','已使用','已过期'),
  FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`)
);

-- 新增日志表
CREATE TABLE system_logs (
  log_id INT AUTO_INCREMENT PRIMARY KEY,
  log_type ENUM('order', 'payment', 'action','system') NOT NULL,
  related_id VARCHAR(20),
  employee_id INT,
  action_type VARCHAR(50) NOT NULL,
  description TEXT,
  ip_address VARCHAR(45),
  created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
  INDEX idx_log_type (log_type),
  INDEX idx_created_at (created_at),
  FOREIGN KEY (employee_id) REFERENCES employees(employee_id)
);

-- 创建备份日志表
CREATE TABLE backup_logs (
    backup_id INT AUTO_INCREMENT PRIMARY KEY,
    filename VARCHAR(255) NOT NULL,
    file_size INT NOT NULL,
    employee_id INT,
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
    INDEX idx_created_at (created_at),
    FOREIGN KEY (employee_id) REFERENCES employees(employee_id)
);

-- 添加索引优化查询
ALTER TABLE backup_logs ADD INDEX idx_filename (filename(20));

-- 初始数据
INSERT INTO `employees` (`username`, `password_hash`, `role`) VALUES
('admin', SHA2('admin', 256), 'admin');

INSERT INTO `dining_tables` (`qr_code`, `status`) VALUES
('TABLE001', '空闲'),
('TABLE002', '用餐中');

INSERT INTO `dishes` (`name`, `price`, `category`, `stock`) VALUES
('红烧肉', 48.00, '热菜', 50),
('凉拌木耳', 18.00, '凉菜', 100),
('珍珠奶茶', 15.00, '饮品', 200);

-- 创建索引
ALTER TABLE `orders` ADD INDEX `idx_orders_user` (`user_id`);
ALTER TABLE `dishes` ADD INDEX `idx_dishes_category` (`category`);

-- 库存更新触发器
DELIMITER //
CREATE TRIGGER `update_stock` AFTER INSERT ON `order_details`
FOR EACH ROW
BEGIN
  UPDATE `dishes` SET `stock` = `stock` - NEW.`quantity`
  WHERE `dish_id` = NEW.`dish_id`;
END//
DELIMITER ;