<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 验证日期格式
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $start_date) || !preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)) {
    $start_date = date('Y-m-d', strtotime('-30 days'));
    $end_date = date('Y-m-d');
}

// 创建原材料表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS ingredients (
        ingredient_id INT AUTO_INCREMENT PRIMARY KEY,
        name VARCHAR(100) NOT NULL,
        unit VARCHAR(20) NOT NULL,
        stock_quantity DECIMAL(10,2) DEFAULT 0,
        min_stock DECIMAL(10,2) DEFAULT 0,
        cost_per_unit DECIMAL(10,2) DEFAULT 0
    )");

    $pdo->exec("CREATE TABLE IF NOT EXISTS dish_ingredients (
        id INT AUTO_INCREMENT PRIMARY KEY,
        dish_id INT NOT NULL,
        ingredient_id INT NOT NULL,
        quantity DECIMAL(10,2) NOT NULL,
        FOREIGN KEY (dish_id) REFERENCES dishes(dish_id),
        FOREIGN KEY (ingredient_id) REFERENCES ingredients(ingredient_id)
    )");
} catch (PDOException $e) {
    error_log("创建原材料表失败: " . $e->getMessage());
}

// 查询库存状态
try {
    $inventory_sql = "
        SELECT 
            i.ingredient_id,
            i.name,
            i.unit,
            i.stock_quantity,
            i.min_stock,
            i.cost_per_unit,
            CASE 
                WHEN i.stock_quantity <= i.min_stock THEN '需要补货'
                WHEN i.stock_quantity <= i.min_stock * 1.5 THEN '库存偏低'
                ELSE '库存充足'
            END AS stock_status
        FROM ingredients i
        ORDER BY 
            CASE 
                WHEN i.stock_quantity <= i.min_stock THEN 1
                WHEN i.stock_quantity <= i.min_stock * 1.5 THEN 2
                ELSE 3
            END,
            i.name
    ";

    $inventory_data = $pdo->query($inventory_sql)->fetchAll();

    // 统计库存状态
    $status_counts = [
        '需要补货' => 0,
        '库存偏低' => 0,
        '库存充足' => 0
    ];

    foreach ($inventory_data as $row) {
        $status_counts[$row['stock_status']]++;
    }
} catch (PDOException $e) {
    error_log("库存查询失败: " . $e->getMessage());
    $inventory_data = [];
}

// 查询原材料消耗
try {
    $consumption_sql = "
        SELECT 
            i.ingredient_id,
            i.name,
            i.unit,
            SUM(di.quantity * od.quantity) AS total_consumed,
            SUM(di.quantity * od.quantity * i.cost_per_unit) AS total_cost
        FROM order_details od
        JOIN orders o ON od.order_id = o.order_id
        JOIN dish_ingredients di ON od.dish_id = di.dish_id
        JOIN ingredients i ON di.ingredient_id = i.ingredient_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY i.ingredient_id
        ORDER BY total_consumed DESC
    ";

    $stmt = $pdo->prepare($consumption_sql);
    $stmt->execute([$start_date, $end_date]);
    $consumption_data = $stmt->fetchAll();

    // 准备图表数据
    $ingredient_names = [];
    $consumption_amounts = [];
    $cost_amounts = [];

    foreach ($consumption_data as $row) {
        $ingredient_names[] = $row['name'];
        $consumption_amounts[] = round($row['total_consumed'], 2);
        $cost_amounts[] = round($row['total_cost'], 2);
    }
} catch (PDOException $e) {
    error_log("原材料消耗查询失败: " . $e->getMessage());
    $consumption_data = [];
}

// 计算每日消耗趋势
try {
    $daily_sql = "
        SELECT 
            DATE(o.create_time) AS order_date,
            SUM(di.quantity * od.quantity) AS daily_consumption
        FROM order_details od
        JOIN orders o ON od.order_id = o.order_id
        JOIN dish_ingredients di ON od.dish_id = di.dish_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY DATE(o.create_time)
        ORDER BY order_date
    ";

    $stmt = $pdo->prepare($daily_sql);
    $stmt->execute([$start_date, $end_date]);
    $daily_data = $stmt->fetchAll();

    $dates = [];
    $daily_consumption = [];

    foreach ($daily_data as $row) {
        $dates[] = $row['order_date'];
        $daily_consumption[] = round($row['daily_consumption'], 2);
    }
} catch (PDOException $e) {
    error_log("每日消耗查询失败: " . $e->getMessage());
    $daily_data = [];
}

// 计算总消耗和总成本
$total_consumption = array_sum($consumption_amounts);
$total_cost = array_sum($cost_amounts);

// 模拟数据（实际应用中应从数据库获取）
if (empty($inventory_data)) {
    $inventory_data = [
        ['ingredient_id' => 1, 'name' => '猪肉', 'unit' => '千克', 'stock_quantity' => 25.5, 'min_stock' => 10, 'cost_per_unit' => 30, 'stock_status' => '库存充足'],
        ['ingredient_id' => 2, 'name' => '牛肉', 'unit' => '千克', 'stock_quantity' => 15.2, 'min_stock' => 8, 'cost_per_unit' => 60, 'stock_status' => '库存充足'],
        ['ingredient_id' => 3, 'name' => '鸡肉', 'unit' => '千克', 'stock_quantity' => 8.5, 'min_stock' => 10, 'cost_per_unit' => 25, 'stock_status' => '需要补货'],
        ['ingredient_id' => 4, 'name' => '大米', 'unit' => '千克', 'stock_quantity' => 50, 'min_stock' => 20, 'cost_per_unit' => 5, 'stock_status' => '库存充足'],
        ['ingredient_id' => 5, 'name' => '面粉', 'unit' => '千克', 'stock_quantity' => 15, 'min_stock' => 10, 'cost_per_unit' => 4, 'stock_status' => '库存偏低'],
        ['ingredient_id' => 6, 'name' => '食用油', 'unit' => '升', 'stock_quantity' => 12, 'min_stock' => 8, 'cost_per_unit' => 15, 'stock_status' => '库存偏低'],
        ['ingredient_id' => 7, 'name' => '盐', 'unit' => '千克', 'stock_quantity' => 5, 'min_stock' => 2, 'cost_per_unit' => 3, 'stock_status' => '库存充足'],
        ['ingredient_id' => 8, 'name' => '糖', 'unit' => '千克', 'stock_quantity' => 4, 'min_stock' => 2, 'cost_per_unit' => 6, 'stock_status' => '库存充足'],
        ['ingredient_id' => 9, 'name' => '葱', 'unit' => '千克', 'stock_quantity' => 3, 'min_stock' => 5, 'cost_per_unit' => 8, 'stock_status' => '需要补货'],
        ['ingredient_id' => 10, 'name' => '姜', 'unit' => '千克', 'stock_quantity' => 2, 'min_stock' => 2, 'cost_per_unit' => 12, 'stock_status' => '库存偏低']
    ];

    $status_counts = [
        '需要补货' => 2,
        '库存偏低' => 3,
        '库存充足' => 5
    ];
}

if (empty($consumption_data)) {
    $consumption_data = [
        ['ingredient_id' => 1, 'name' => '猪肉', 'unit' => '千克', 'total_consumed' => 45.2, 'total_cost' => 1356],
        ['ingredient_id' => 2, 'name' => '牛肉', 'unit' => '千克', 'total_consumed' => 28.5, 'total_cost' => 1710],
        ['ingredient_id' => 4, 'name' => '大米', 'unit' => '千克', 'total_consumed' => 60, 'total_cost' => 300],
        ['ingredient_id' => 3, 'name' => '鸡肉', 'unit' => '千克', 'total_consumed' => 35.8, 'total_cost' => 895],
        ['ingredient_id' => 6, 'name' => '食用油', 'unit' => '升', 'total_consumed' => 25, 'total_cost' => 375],
        ['ingredient_id' => 5, 'name' => '面粉', 'unit' => '千克', 'total_consumed' => 20, 'total_cost' => 80]
    ];

    $ingredient_names = ['猪肉', '牛肉', '大米', '鸡肉', '食用油', '面粉'];
    $consumption_amounts = [45.2, 28.5, 60, 35.8, 25, 20];
    $cost_amounts = [1356, 1710, 300, 895, 375, 80];

    $total_consumption = array_sum($consumption_amounts);
    $total_cost = array_sum($cost_amounts);
}

if (empty($daily_data)) {
    $daily_data = [];
    $current = strtotime($start_date);
    $end = strtotime($end_date);
    $dates = [];
    $daily_consumption = [];

    while ($current <= $end) {
        $date = date('Y-m-d', $current);
        $dates[] = $date;
        $daily_consumption[] = rand(50, 150);
        $current = strtotime('+1 day', $current);
    }
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>库存消耗分析</title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <h2>库存消耗分析</h2>

        <!-- 筛选条件 -->
        <div class="card">
            <h3>筛选条件</h3>
            <form method="GET" action="inventory_analysis.php" class="filter-form">
                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" value="<?= $start_date ?>">
                </div>

                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" value="<?= $end_date ?>">
                </div>

                <button type="submit" class="btn-primary">查询</button>
            </form>
        </div>

        <!-- 库存状态概览 -->
        <div class="card">
            <h3>库存状态概览</h3>
            <div class="stats-container">
                <div class="stat-box warning">
                    <div class="stat-value"><?= $status_counts['需要补货'] ?></div>
                    <div class="stat-label">需要补货</div>
                </div>
                <div class="stat-box alert">
                    <div class="stat-value"><?= $status_counts['库存偏低'] ?></div>
                    <div class="stat-label">库存偏低</div>
                </div>
                <div class="stat-box success">
                    <div class="stat-value"><?= $status_counts['库存充足'] ?></div>
                    <div class="stat-label">库存充足</div>
                </div>
            </div>
        </div>

        <!-- 原材料消耗图 -->
        <div class="card">
            <h3>原材料消耗TOP10</h3>
            <div class="chart-container">
                <canvas id="consumptionChart"></canvas>
            </div>
        </div>

        <!-- 每日消耗趋势 -->
        <div class="card">
            <h3>每日消耗趋势</h3>
            <div class="chart-container">
                <canvas id="dailyConsumptionChart"></canvas>
            </div>
        </div>

        <!-- 库存状态详情 -->
        <div class="card">
            <h3>库存状态详情</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>原材料名称</th>
                        <th>单位</th>
                        <th>当前库存</th>
                        <th>最低库存</th>
                        <th>单位成本（元）</th>
                        <th>库存状态</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($inventory_data) && is_array($inventory_data)): ?>
                        <?php foreach ($inventory_data as $row): ?>
                            <tr class="<?= strtolower(str_replace(' ', '-', $row['stock_status'])) ?>">
                                <td><?= htmlspecialchars($row['name']) ?></td>
                                <td><?= htmlspecialchars($row['unit']) ?></td>
                                <td><?= number_format($row['stock_quantity'], 2) ?></td>
                                <td><?= number_format($row['min_stock'], 2) ?></td>
                                <td><?= number_format($row['cost_per_unit'], 2) ?></td>
                                <td>
                                    <span class="status-tag <?= strtolower(str_replace(' ', '-', $row['stock_status'])) ?>">
                                        <?= $row['stock_status'] ?>
                                    </span>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="6" class="empty-state">暂无库存数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- 原材料消耗详情 -->
        <div class="card">
            <h3>原材料消耗详情</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>原材料名称</th>
                        <th>单位</th>
                        <th>消耗数量</th>
                        <th>消耗成本（元）</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($consumption_data) && is_array($consumption_data)): ?>
                        <?php foreach ($consumption_data as $row): ?>
                            <tr>
                                <td><?= htmlspecialchars($row['name']) ?></td>
                                <td><?= htmlspecialchars($row['unit']) ?></td>
                                <td><?= number_format($row['total_consumed'], 2) ?></td>
                                <td><?= number_format($row['total_cost'], 2) ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="4" class="empty-state">暂无消耗数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
                <tfoot>
                    <tr>
                        <th colspan="2">总计</th>
                        <th><?= number_format($total_consumption, 2) ?></th>
                        <th><?= number_format($total_cost, 2) ?></th>
                    </tr>
                </tfoot>
            </table>
        </div>
    </div>

    <script>
        // 原材料消耗图
        const consumptionCtx = document.getElementById('consumptionChart').getContext('2d');
        const consumptionChart = new Chart(consumptionCtx, {
            type: 'bar',
            data: {
                labels: <?= json_encode(array_slice($ingredient_names, 0, 10)) ?>,
                datasets: [{
                        label: '消耗数量',
                        data: <?= json_encode(array_slice($consumption_amounts, 0, 10)) ?>,
                        backgroundColor: 'rgba(54, 162, 235, 0.7)',
                        borderColor: 'rgba(54, 162, 235, 1)',
                        borderWidth: 1,
                        yAxisID: 'y'
                    },
                    {
                        label: '消耗成本（元）',
                        data: <?= json_encode(array_slice($cost_amounts, 0, 10)) ?>,
                        backgroundColor: 'rgba(255, 99, 132, 0.7)',
                        borderColor: 'rgba(255, 99, 132, 1)',
                        borderWidth: 1,
                        yAxisID: 'y1'
                    }
                ]
            },
            options: {
                responsive: true,
                interaction: {
                    mode: 'index',
                    intersect: false,
                },
                scales: {
                    y: {
                        type: 'linear',
                        display: true,
                        position: 'left',
                        title: {
                            display: true,
                            text: '消耗数量'
                        }
                    },
                    y1: {
                        type: 'linear',
                        display: true,
                        position: 'right',
                        title: {
                            display: true,
                            text: '消耗成本（元）'
                        },
                        grid: {
                            drawOnChartArea: false,
                        },
                    }
                }
            }
        });

        // 每日消耗趋势图
        const dailyCtx = document.getElementById('dailyConsumptionChart').getContext('2d');
        const dailyChart = new Chart(dailyCtx, {
            type: 'line',
            data: {
                labels: <?= json_encode($dates) ?>,
                datasets: [{
                    label: '每日消耗量',
                    data: <?= json_encode($daily_consumption) ?>,
                    fill: false,
                    borderColor: 'rgb(75, 192, 192)',
                    tension: 0.1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '消耗量'
                        }
                    }
                }
            }
        });
    </script>

    <style>
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
        }

        .filter-form .form-group {
            margin-bottom: 0;
        }

        .stats-container {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
        }

        .stat-box {
            flex: 1;
            text-align: center;
            padding: 15px;
            border-radius: 5px;
            margin: 0 10px;
            color: white;
        }

        .stat-box.warning {
            background-color: #e74c3c;
        }

        .stat-box.alert {
            background-color: #f39c12;
        }

        .stat-box.success {
            background-color: #27ae60;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
        }

        .stat-label {
            margin-top: 5px;
        }

        .chart-container {
            position: relative;
            margin: 20px auto;
            height: 300px;
        }

        .status-tag {
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 12px;
            color: white;
        }

        .需要补货 {
            background-color: #e74c3c;
        }

        .库存偏低 {
            background-color: #f39c12;
        }

        .库存充足 {
            background-color: #27ae60;
        }

        tr.需要补货 {
            background-color: rgba(231, 76, 60, 0.1);
        }

        tr.库存偏低 {
            background-color: rgba(243, 156, 18, 0.1);
        }

        @media (max-width: 768px) {
            .stats-container {
                flex-direction: column;
            }

            .stat-box {
                margin: 5px 0;
            }
        }
    </style>
</body>

</html>