<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 验证日期格式
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $start_date) || !preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)) {
    $start_date = date('Y-m-d', strtotime('-30 days'));
    $end_date = date('Y-m-d');
}

// 获取菜品分类
$category = isset($_GET['category']) ? $_GET['category'] : '';

// 查询热门菜品
try {
    $sql = "
        SELECT 
            d.dish_id,
            d.name,
            d.category,
            d.price,
            SUM(od.quantity) AS total_quantity,
            SUM(od.quantity * od.price) AS total_revenue,
            COUNT(DISTINCT o.order_id) AS order_count
        FROM order_details od
        JOIN orders o ON od.order_id = o.order_id
        JOIN dishes d ON od.dish_id = d.dish_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
    ";

    $params = [$start_date, $end_date];

    if (!empty($category)) {
        $sql .= " AND d.category = ?";
        $params[] = $category;
    }

    $sql .= "
        GROUP BY d.dish_id
        ORDER BY total_quantity DESC
        LIMIT 100
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $dishes_data = $stmt->fetchAll();

    // 准备图表数据
    $dish_names = [];
    $dish_quantities = [];
    $dish_revenues = [];
    $dish_categories = [];

    foreach ($dishes_data as $row) {
        $dish_names[] = $row['name'];
        $dish_quantities[] = $row['total_quantity'];
        $dish_revenues[] = round($row['total_revenue'], 2);

        if (!in_array($row['category'], $dish_categories)) {
            $dish_categories[] = $row['category'];
        }
    }
} catch (PDOException $e) {
    error_log("热门菜品查询失败: " . $e->getMessage());
    $error_message = "数据查询失败，请稍后再试";
}

// 查询菜品分类销售情况
try {
    $category_sql = "
        SELECT 
            d.category,
            COUNT(DISTINCT d.dish_id) AS dish_count,
            SUM(od.quantity) AS total_quantity,
            SUM(od.quantity * od.price) AS total_revenue
        FROM order_details od
        JOIN orders o ON od.order_id = o.order_id
        JOIN dishes d ON od.dish_id = d.dish_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY d.category
        ORDER BY total_quantity DESC
    ";

    $stmt = $pdo->prepare($category_sql);
    $stmt->execute([$start_date, $end_date]);
    $category_data = $stmt->fetchAll();

    $category_names = [];
    $category_quantities = [];
    $category_revenues = [];

    foreach ($category_data as $row) {
        $category_names[] = $row['category'];
        $category_quantities[] = $row['total_quantity'];
        $category_revenues[] = round($row['total_revenue'], 2);
    }
} catch (PDOException $e) {
    error_log("菜品分类查询失败: " . $e->getMessage());
}

// 查询所有菜品分类（用于筛选）
try {
    $all_categories = $pdo->query("SELECT DISTINCT category FROM dishes ORDER BY category")->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $all_categories = [];
    error_log("菜品分类查询失败: " . $e->getMessage());
}

// 计算总销量和总收入
$total_quantity = array_sum($dish_quantities);
$total_revenue = array_sum($dish_revenues);
?>

<!DOCTYPE html>
<html>

<head>
    <title>热门菜品分析</title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <h2>热门菜品分析</h2>

        <!-- 筛选条件 -->
        <div class="card">
            <h3>筛选条件</h3>
            <form method="GET" action="popular_dishes.php" class="filter-form">
                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" value="<?= $start_date ?>">
                </div>

                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" value="<?= $end_date ?>">
                </div>

                <div class="form-group">
                    <label>菜品分类</label>
                    <select name="category">
                        <option value="">全部分类</option>
                        <?php foreach ($all_categories as $cat): ?>
                            <option value="<?= $cat ?>" <?= $category == $cat ? 'selected' : '' ?>><?= $cat ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn-primary">查询</button>
            </form>
        </div>

        <!-- 销售概览 -->
        <div class="card">
            <h3>菜品销售概览</h3>
            <div class="stats-container">
                <div class="stat-box">
                    <div class="stat-value"><?= count($dishes_data) ?></div>
                    <div class="stat-label">销售菜品数</div>
                </div>
                <div class="stat-box">
                    <div class="stat-value"><?= $total_quantity ?></div>
                    <div class="stat-label">总销售份数</div>
                </div>
                <div class="stat-box">
                    <div class="stat-value"><?= number_format($total_revenue, 2) ?></div>
                    <div class="stat-label">总销售金额（元）</div>
                </div>
            </div>
        </div>

        <!-- 热门菜品销量图 -->
        <div class="card">
            <h3>热门菜品销量TOP10</h3>
            <div class="chart-container">
                <canvas id="topDishesChart"></canvas>
            </div>
        </div>

        <!-- 菜品分类销售情况 -->
        <div class="card">
            <h3>菜品分类销售情况</h3>
            <div class="chart-container">
                <canvas id="categoryChart"></canvas>
            </div>
        </div>

        <!-- 热门菜品详细数据 -->
        <div class="card">
            <h3>热门菜品详细数据</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>排名</th>
                        <th>菜品名称</th>
                        <th>分类</th>
                        <th>单价（元）</th>
                        <th>销售份数</th>
                        <th>销售金额（元）</th>
                        <th>订单数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($dishes_data) && is_array($dishes_data)): ?>
                        <?php foreach ($dishes_data as $index => $row): ?>
                            <tr>
                                <td><?= $index + 1 ?></td>
                                <td><?= htmlspecialchars($row['name']) ?></td>
                                <td><?= htmlspecialchars($row['category']) ?></td>
                                <td><?= number_format($row['price'], 2) ?></td>
                                <td><?= $row['total_quantity'] ?></td>
                                <td><?= number_format($row['total_revenue'], 2) ?></td>
                                <td><?= $row['order_count'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="7" class="empty-state">暂无菜品销售数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 热门菜品销量图
        const topDishesCtx = document.getElementById('topDishesChart').getContext('2d');
        const topDishesChart = new Chart(topDishesCtx, {
            type: 'bar',
            data: {
                labels: <?= json_encode(array_slice($dish_names, 0, 10)) ?>,
                datasets: [{
                    label: '销售份数',
                    data: <?= json_encode(array_slice($dish_quantities, 0, 10)) ?>,
                    backgroundColor: 'rgba(54, 162, 235, 0.7)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '销售份数'
                        }
                    }
                }
            }
        });

        // 菜品分类销售情况
        const categoryCtx = document.getElementById('categoryChart').getContext('2d');
        const categoryChart = new Chart(categoryCtx, {
            type: 'pie',
            data: {
                labels: <?= json_encode($category_names) ?>,
                datasets: [{
                    data: <?= json_encode($category_quantities) ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)',
                        'rgba(153, 102, 255, 0.7)',
                        'rgba(255, 159, 64, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: {
                        position: 'right',
                    },
                    title: {
                        display: true,
                        text: '各分类销售份数占比'
                    }
                }
            }
        });
    </script>

    <style>
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
        }

        .filter-form .form-group {
            margin-bottom: 0;
        }

        .stats-container {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
        }

        .stat-box {
            flex: 1;
            text-align: center;
            padding: 15px;
            background-color: #f8f9fa;
            border-radius: 5px;
            margin: 0 10px;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #2c3e50;
        }

        .stat-label {
            margin-top: 5px;
            color: #7f8c8d;
        }

        .chart-container {
            position: relative;
            margin: 20px auto;
            height: 300px;
        }

        @media (max-width: 768px) {
            .stats-container {
                flex-direction: column;
            }

            .stat-box {
                margin: 5px 0;
            }
        }
    </style>
</body>

</html>