<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取统计周期
$period = isset($_GET['period']) ? $_GET['period'] : 'day';
$valid_periods = ['day', 'week', 'month'];
if (!in_array($period, $valid_periods)) {
    $period = 'day';
}

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 验证日期格式
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $start_date) || !preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)) {
    $start_date = date('Y-m-d', strtotime('-30 days'));
    $end_date = date('Y-m-d');
}

// 根据周期选择SQL分组
$group_by = '';
$date_format = '';
switch ($period) {
    case 'day':
        $group_by = "DATE(o.create_time)";
        $date_format = "%Y-%m-%d";
        break;
    case 'week':
        $group_by = "YEARWEEK(o.create_time, 1)";
        $date_format = "%Y-%u周";
        break;
    case 'month':
        $group_by = "DATE_FORMAT(o.create_time, '%Y-%m')";
        $date_format = "%Y-%m";
        break;
}

// 查询销售数据
try {
    $sql = "
        SELECT 
            DATE_FORMAT(o.create_time, '$date_format') AS period_label,
            $group_by AS period_value,
            COUNT(o.order_id) AS order_count,
            SUM(o.total_amount) AS total_revenue,
            AVG(o.total_amount) AS avg_order_value
        FROM orders o
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY period_value
        ORDER BY period_value
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$start_date, $end_date]);
    $sales_data = $stmt->fetchAll();

    // 计算总计
    $total_orders = 0;
    $total_revenue = 0;
    $data_points = [];
    $labels = [];
    $revenue_data = [];
    $order_count_data = [];
    $avg_order_data = [];

    foreach ($sales_data as $row) {
        $total_orders += $row['order_count'];
        $total_revenue += $row['total_revenue'];

        $labels[] = $row['period_label'];
        $revenue_data[] = round($row['total_revenue'], 2);
        $order_count_data[] = $row['order_count'];
        $avg_order_data[] = round($row['avg_order_value'], 2);
    }

    $avg_order_value = $total_orders > 0 ? $total_revenue / $total_orders : 0;
} catch (PDOException $e) {
    error_log("销售统计查询失败: " . $e->getMessage());
    $error_message = "数据查询失败，请稍后再试";
}

// 获取支付方式分布
try {
    $payment_sql = "
        SELECT 
            p.method,
            COUNT(p.payment_id) AS count,
            SUM(p.amount) AS total_amount
        FROM payments p
        JOIN orders o ON p.order_id = o.order_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY p.method
    ";

    $stmt = $pdo->prepare($payment_sql);
    $stmt->execute([$start_date, $end_date]);
    $payment_data = $stmt->fetchAll();

    $payment_labels = [];
    $payment_counts = [];
    $payment_amounts = [];

    foreach ($payment_data as $row) {
        $payment_labels[] = $row['method'];
        $payment_counts[] = $row['count'];
        $payment_amounts[] = round($row['total_amount'], 2);
    }
} catch (PDOException $e) {
    error_log("支付方式统计查询失败: " . $e->getMessage());
}

// 获取订单类型分布
try {
    $order_type_sql = "
        SELECT 
            o.type,
            COUNT(o.order_id) AS count,
            SUM(o.total_amount) AS total_amount
        FROM orders o
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY o.type
    ";

    $stmt = $pdo->prepare($order_type_sql);
    $stmt->execute([$start_date, $end_date]);
    $order_type_data = $stmt->fetchAll();

    $order_type_labels = [];
    $order_type_counts = [];
    $order_type_amounts = [];

    foreach ($order_type_data as $row) {
        $order_type_labels[] = $row['type'];
        $order_type_counts[] = $row['count'];
        $order_type_amounts[] = round($row['total_amount'], 2);
    }
} catch (PDOException $e) {
    error_log("订单类型统计查询失败: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>销售统计分析</title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <h2>销售统计分析</h2>

        <!-- 筛选条件 -->
        <div class="card">
            <h3>筛选条件</h3>
            <form method="GET" action="sales_statistics.php" class="filter-form">
                <div class="form-group">
                    <label>统计周期</label>
                    <select name="period">
                        <option value="day" <?= $period == 'day' ? 'selected' : '' ?>>按日</option>
                        <option value="week" <?= $period == 'week' ? 'selected' : '' ?>>按周</option>
                        <option value="month" <?= $period == 'month' ? 'selected' : '' ?>>按月</option>
                    </select>
                </div>

                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" value="<?= $start_date ?>">
                </div>

                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" value="<?= $end_date ?>">
                </div>

                <button type="submit" class="btn-primary">查询</button>
            </form>
        </div>

        <!-- 销售概览 -->
        <div class="card">
            <h3>销售概览</h3>
            <div class="stats-container">
                <div class="stat-box">
                    <div class="stat-value"><?= number_format($total_revenue, 2) ?></div>
                    <div class="stat-label">总营收（元）</div>
                </div>
                <div class="stat-box">
                    <div class="stat-value"><?= $total_orders ?></div>
                    <div class="stat-label">总订单数</div>
                </div>
                <div class="stat-box">
                    <div class="stat-value"><?= number_format($avg_order_value, 2) ?></div>
                    <div class="stat-label">平均客单价（元）</div>
                </div>
            </div>
        </div>

        <!-- 销售趋势图 -->
        <div class="card">
            <h3>销售趋势</h3>
            <div class="chart-container">
                <canvas id="salesChart"></canvas>
            </div>
        </div>

        <!-- 支付方式分布 -->
        <div class="card">
            <h3>支付方式分布</h3>
            <div class="chart-container half-width">
                <canvas id="paymentChart"></canvas>
            </div>
        </div>

        <!-- 订单类型分布 -->
        <div class="card">
            <h3>订单类型分布</h3>
            <div class="chart-container half-width">
                <canvas id="orderTypeChart"></canvas>
            </div>
        </div>

        <!-- 销售详细数据 -->
        <div class="card">
            <h3>销售详细数据</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>时间段</th>
                        <th>订单数</th>
                        <th>营收（元）</th>
                        <th>客单价（元）</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($sales_data) && is_array($sales_data)): ?>
                        <?php foreach ($sales_data as $row): ?>
                            <tr>
                                <td><?= $row['period_label'] ?></td>
                                <td><?= $row['order_count'] ?></td>
                                <td><?= number_format($row['total_revenue'], 2) ?></td>
                                <td><?= number_format($row['avg_order_value'], 2) ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="4" class="empty-state">暂无销售数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 销售趋势图
        const salesCtx = document.getElementById('salesChart').getContext('2d');
        const salesChart = new Chart(salesCtx, {
            type: 'line',
            data: {
                labels: <?= json_encode($labels) ?>,
                datasets: [{
                        label: '营收（元）',
                        data: <?= json_encode($revenue_data) ?>,
                        borderColor: 'rgba(54, 162, 235, 1)',
                        backgroundColor: 'rgba(54, 162, 235, 0.2)',
                        yAxisID: 'y',
                    },
                    {
                        label: '订单数',
                        data: <?= json_encode($order_count_data) ?>,
                        borderColor: 'rgba(255, 99, 132, 1)',
                        backgroundColor: 'rgba(255, 99, 132, 0.2)',
                        yAxisID: 'y1',
                    }
                ]
            },
            options: {
                responsive: true,
                interaction: {
                    mode: 'index',
                    intersect: false,
                },
                scales: {
                    y: {
                        type: 'linear',
                        display: true,
                        position: 'left',
                        title: {
                            display: true,
                            text: '营收（元）'
                        }
                    },
                    y1: {
                        type: 'linear',
                        display: true,
                        position: 'right',
                        title: {
                            display: true,
                            text: '订单数'
                        },
                        grid: {
                            drawOnChartArea: false,
                        },
                    }
                }
            }
        });

        // 支付方式分布图
        const paymentCtx = document.getElementById('paymentChart').getContext('2d');
        const paymentChart = new Chart(paymentCtx, {
            type: 'pie',
            data: {
                labels: <?= json_encode($payment_labels) ?>,
                datasets: [{
                    data: <?= json_encode($payment_amounts) ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: {
                        position: 'right',
                    },
                    title: {
                        display: true,
                        text: '支付方式金额分布'
                    }
                }
            }
        });

        // 订单类型分布图
        const orderTypeCtx = document.getElementById('orderTypeChart').getContext('2d');
        const orderTypeChart = new Chart(orderTypeCtx, {
            type: 'pie',
            data: {
                labels: <?= json_encode($order_type_labels) ?>,
                datasets: [{
                    data: <?= json_encode($order_type_counts) ?>,
                    backgroundColor: [
                        'rgba(255, 159, 64, 0.7)',
                        'rgba(153, 102, 255, 0.7)',
                        'rgba(201, 203, 207, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: {
                        position: 'right',
                    },
                    title: {
                        display: true,
                        text: '订单类型分布'
                    }
                }
            }
        });
    </script>

    <style>
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
        }

        .filter-form .form-group {
            margin-bottom: 0;
        }

        .stats-container {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
        }

        .stat-box {
            flex: 1;
            text-align: center;
            padding: 15px;
            background-color: #f8f9fa;
            border-radius: 5px;
            margin: 0 10px;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #2c3e50;
        }

        .stat-label {
            margin-top: 5px;
            color: #7f8c8d;
        }

        .chart-container {
            position: relative;
            margin: 20px auto;
            height: 300px;
        }

        .half-width {
            width: 50%;
        }

        @media (max-width: 768px) {
            .stats-container {
                flex-direction: column;
            }

            .stat-box {
                margin: 5px 0;
            }

            .half-width {
                width: 100%;
            }
        }
    </style>
</body>

</html>