<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-90 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 验证日期格式
if (!preg_match('/^\d{4}-\d{2}-\d{2}$/', $start_date) || !preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)) {
    $start_date = date('Y-m-d', strtotime('-90 days'));
    $end_date = date('Y-m-d');
}

// 获取会员等级
$member_level = isset($_GET['member_level']) ? (int)$_GET['member_level'] : 0;

// 查询用户消费习惯
try {
    $sql = "
        SELECT 
            u.user_id,
            u.phone,
            m.level,
            COUNT(DISTINCT o.order_id) AS order_count,
            SUM(o.total_amount) AS total_spent,
            AVG(o.total_amount) AS avg_order_value,
            MAX(o.create_time) AS last_order_date
        FROM users u
        JOIN members m ON u.user_id = m.user_id
        JOIN orders o ON u.user_id = o.user_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
    ";

    $params = [$start_date, $end_date];

    if ($member_level > 0) {
        $sql .= " AND m.level = ?";
        $params[] = $member_level;
    }

    $sql .= "
        GROUP BY u.user_id
        ORDER BY total_spent DESC
        LIMIT 100
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $user_data = $stmt->fetchAll();
} catch (PDOException $e) {
    error_log("用户消费习惯查询失败: " . $e->getMessage());
    $user_data = [];
}

// 查询用户偏好菜品
try {
    $preference_sql = "
        SELECT 
            u.user_id,
            u.phone,
            d.dish_id,
            d.name AS dish_name,
            d.category,
            COUNT(od.detail_id) AS order_count
        FROM users u
        JOIN orders o ON u.user_id = o.user_id
        JOIN order_details od ON o.order_id = od.order_id
        JOIN dishes d ON od.dish_id = d.dish_id
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY u.user_id, d.dish_id
        ORDER BY u.user_id, order_count DESC
    ";

    $stmt = $pdo->prepare($preference_sql);
    $stmt->execute([$start_date, $end_date]);
    $preference_data = $stmt->fetchAll();

    // 整理用户偏好数据
    $user_preferences = [];
    foreach ($preference_data as $row) {
        if (!isset($user_preferences[$row['user_id']])) {
            $user_preferences[$row['user_id']] = [
                'phone' => $row['phone'],
                'preferences' => []
            ];
        }

        if (count($user_preferences[$row['user_id']]['preferences']) < 3) {
            $user_preferences[$row['user_id']]['preferences'][] = [
                'dish_name' => $row['dish_name'],
                'category' => $row['category'],
                'order_count' => $row['order_count']
            ];
        }
    }
} catch (PDOException $e) {
    error_log("用户偏好查询失败: " . $e->getMessage());
    $user_preferences = [];
}

// 查询热门时段
try {
    $time_sql = "
        SELECT 
            HOUR(o.create_time) AS hour_of_day,
            COUNT(o.order_id) AS order_count
        FROM orders o
        WHERE o.status = '已完成'
            AND o.create_time BETWEEN ? AND DATE_ADD(?, INTERVAL 1 DAY)
        GROUP BY HOUR(o.create_time)
        ORDER BY hour_of_day
    ";

    $stmt = $pdo->prepare($time_sql);
    $stmt->execute([$start_date, $end_date]);
    $time_data = $stmt->fetchAll();

    $hours = [];
    $order_counts = [];

    foreach ($time_data as $row) {
        $hours[] = $row['hour_of_day'] . ':00';
        $order_counts[] = $row['order_count'];
    }
} catch (PDOException $e) {
    error_log("热门时段查询失败: " . $e->getMessage());
    $time_data = [];
}

// 查询会员等级分布
try {
    $level_sql = "
        SELECT 
            m.level,
            COUNT(m.member_id) AS member_count
        FROM members m
        GROUP BY m.level
        ORDER BY m.level
    ";

    $level_data = $pdo->query($level_sql)->fetchAll();

    $levels = [];
    $member_counts = [];

    foreach ($level_data as $row) {
        $levels[] = '等级' . $row['level'];
        $member_counts[] = $row['member_count'];
    }
} catch (PDOException $e) {
    error_log("会员等级查询失败: " . $e->getMessage());
    $level_data = [];
}

// 会员等级映射
$levelMap = [
    1 => '普通会员',
    2 => '银卡会员',
    3 => '金卡会员',
    4 => '钻石会员'
];

// 模拟数据（实际应用中应从数据库获取）
if (empty($time_data)) {
    $hours = ['7:00', '8:00', '9:00', '10:00', '11:00', '12:00', '13:00', '14:00', '15:00', '16:00', '17:00', '18:00', '19:00', '20:00', '21:00', '22:00'];
    $order_counts = [5, 12, 25, 30, 85, 120, 70, 35, 25, 30, 45, 95, 130, 90, 60, 25];
}

if (empty($level_data)) {
    $levels = ['等级1', '等级2', '等级3', '等级4'];
    $member_counts = [150, 80, 40, 15];
}

// 计算用户活跃度
$active_users = 0;
$inactive_users = 0;
$new_users = 0;

foreach ($user_data as $user) {
    $last_order = strtotime($user['last_order_date']);
    $thirty_days_ago = strtotime('-30 days');

    if ($last_order >= $thirty_days_ago) {
        $active_users++;
    } else {
        $inactive_users++;
    }

    if ($last_order >= strtotime('-7 days')) {
        $new_users++;
    }
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>用户行为分析</title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <h2>用户行为分析</h2>

        <!-- 筛选条件 -->
        <div class="card">
            <h3>筛选条件</h3>
            <form method="GET" action="user_behavior.php" class="filter-form">
                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" value="<?= $start_date ?>">
                </div>

                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" value="<?= $end_date ?>">
                </div>

                <div class="form-group">
                    <label>会员等级</label>
                    <select name="member_level">
                        <option value="0" <?= $member_level == 0 ? 'selected' : '' ?>>全部等级</option>
                        <?php foreach ($levelMap as $level => $name): ?>
                            <option value="<?= $level ?>" <?= $member_level == $level ? 'selected' : '' ?>><?= $name ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn-primary">查询</button>
            </form>
        </div>

        <!-- 用户活跃度概览 -->
        <div class="card">
            <h3>用户活跃度概览</h3>
            <div class="stats-container">
                <div class="stat-box active">
                    <div class="stat-value"><?= $active_users ?></div>
                    <div class="stat-label">活跃用户</div>
                    <div class="stat-desc">30天内有消费</div>
                </div>
                <div class="stat-box inactive">
                    <div class="stat-value"><?= $inactive_users ?></div>
                    <div class="stat-label">非活跃用户</div>
                    <div class="stat-desc">30天内无消费</div>
                </div>
                <div class="stat-box new">
                    <div class="stat-value"><?= $new_users ?></div>
                    <div class="stat-label">新增用户</div>
                    <div class="stat-desc">7天内首次消费</div>
                </div>
            </div>
        </div>

        <!-- 热门时段分析 -->
        <div class="card">
            <h3>热门时段分析</h3>
            <div class="chart-container">
                <canvas id="timeChart"></canvas>
            </div>
        </div>

        <!-- 会员等级分布 -->
        <div class="card">
            <h3>会员等级分布</h3>
            <div class="chart-container half-width">
                <canvas id="levelChart"></canvas>
            </div>
        </div>

        <!-- 用户消费习惯 -->
        <div class="card">
            <h3>用户消费习惯</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>用户手机</th>
                        <th>会员等级</th>
                        <th>订单数</th>
                        <th>总消费（元）</th>
                        <th>平均客单价（元）</th>
                        <th>最近消费日期</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($user_data) && is_array($user_data)): ?>
                        <?php foreach ($user_data as $user): ?>
                            <tr>
                                <td><?= htmlspecialchars($user['phone']) ?></td>
                                <td><?= $levelMap[$user['level']] ?? '未知等级' ?></td>
                                <td><?= $user['order_count'] ?></td>
                                <td><?= number_format($user['total_spent'], 2) ?></td>
                                <td><?= number_format($user['avg_order_value'], 2) ?></td>
                                <td><?= date('Y-m-d', strtotime($user['last_order_date'])) ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="6" class="empty-state">暂无用户消费数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- 用户偏好分析 -->
        <div class="card">
            <h3>用户偏好分析</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>用户手机</th>
                        <th>偏好菜品1</th>
                        <th>偏好菜品2</th>
                        <th>偏好菜品3</th>
                        <th>推荐菜品</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($user_preferences) && is_array($user_preferences)): ?>
                        <?php foreach ($user_preferences as $user_id => $data): ?>
                            <tr>
                                <td><?= htmlspecialchars($data['phone']) ?></td>
                                <?php
                                for ($i = 0; $i < 3; $i++) {
                                    if (isset($data['preferences'][$i])) {
                                        $pref = $data['preferences'][$i];
                                        echo "<td>{$pref['dish_name']} ({$pref['category']}, {$pref['order_count']}次)</td>";
                                    } else {
                                        echo "<td>-</td>";
                                    }
                                }

                                // 简单的推荐逻辑：根据用户最常点的菜品分类推荐
                                $recommendation = "暂无推荐";
                                if (!empty($data['preferences'])) {
                                    $category = $data['preferences'][0]['category'];
                                    $recommendation = "同类{$category}菜品";
                                }
                                ?>
                                <td><?= $recommendation ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="5" class="empty-state">暂无用户偏好数据</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 热门时段图
        const timeCtx = document.getElementById('timeChart').getContext('2d');
        const timeChart = new Chart(timeCtx, {
            type: 'bar',
            data: {
                labels: <?= json_encode($hours) ?>,
                datasets: [{
                    label: '订单数',
                    data: <?= json_encode($order_counts) ?>,
                    backgroundColor: 'rgba(54, 162, 235, 0.7)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '订单数'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '时间段'
                        }
                    }
                }
            }
        });

        // 会员等级分布图
        const levelCtx = document.getElementById('levelChart').getContext('2d');
        const levelChart = new Chart(levelCtx, {
            type: 'pie',
            data: {
                labels: <?= json_encode($levels) ?>,
                datasets: [{
                    data: <?= json_encode($member_counts) ?>,
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)',
                        'rgba(75, 192, 192, 0.7)'
                    ],
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                plugins: {
                    legend: {
                        position: 'right',
                    },
                    title: {
                        display: true,
                        text: '会员等级分布'
                    }
                }
            }
        });
    </script>

    <style>
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
        }

        .filter-form .form-group {
            margin-bottom: 0;
        }

        .stats-container {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
        }

        .stat-box {
            flex: 1;
            text-align: center;
            padding: 15px;
            border-radius: 5px;
            margin: 0 10px;
            color: white;
        }

        .stat-box.active {
            background-color: #27ae60;
        }

        .stat-box.inactive {
            background-color: #e74c3c;
        }

        .stat-box.new {
            background-color: #3498db;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
        }

        .stat-label {
            margin-top: 5px;
            font-weight: bold;
        }

        .stat-desc {
            font-size: 12px;
            margin-top: 5px;
            opacity: 0.8;
        }

        .chart-container {
            position: relative;
            margin: 20px auto;
            height: 300px;
        }

        .half-width {
            width: 50%;
        }

        @media (max-width: 768px) {
            .stats-container {
                flex-direction: column;
            }

            .stat-box {
                margin: 5px 0;
            }

            .half-width {
                width: 100%;
            }
        }
    </style>
</body>

</html>