<?php
require_once '../config.php';

// 创建配送员表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS couriers (
        courier_id INT AUTO_INCREMENT PRIMARY KEY,
        name VARCHAR(50) NOT NULL,
        phone VARCHAR(20) NOT NULL UNIQUE,
        status ENUM('空闲', '配送中', '休息') DEFAULT '空闲',
        current_orders INT DEFAULT 0,
        total_orders INT DEFAULT 0,
        rating DECIMAL(3,2) DEFAULT 5.00,
        join_date DATE,
        last_active DATETIME,
        is_active BOOLEAN DEFAULT TRUE
    )");
} catch (Exception $e) {
    $error_message = "创建配送员表失败: " . $e->getMessage();
}

// 创建配送订单表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS delivery_orders (
        delivery_id INT AUTO_INCREMENT PRIMARY KEY,
        order_id VARCHAR(20),
        courier_id INT,
        status ENUM('待分配', '已分配', '配送中', '已送达', '已取消') DEFAULT '待分配',
        assign_time DATETIME,
        pickup_time DATETIME,
        delivery_time DATETIME,
        estimated_time INT, -- 预计送达时间（分钟）
        actual_time INT,   -- 实际送达时间（分钟）
        distance DECIMAL(10,2), -- 配送距离（公里）
        customer_address TEXT,
        customer_phone VARCHAR(20),
        notes TEXT,
        FOREIGN KEY (order_id) REFERENCES orders(order_id),
        FOREIGN KEY (courier_id) REFERENCES couriers(courier_id)
    )");
} catch (Exception $e) {
    $error_message = "创建配送订单表失败: " . $e->getMessage();
}

// 处理订单分配
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        if ($_POST['action'] === 'assign_order') {
            $order_id = $_POST['order_id'] ?? '';
            $courier_id = $_POST['courier_id'] ?? '';

            try {
                $pdo->beginTransaction();

                // 更新配送订单状态
                $stmt = $pdo->prepare("UPDATE delivery_orders 
                                     SET courier_id = ?, status = '已分配', assign_time = NOW() 
                                     WHERE order_id = ?");
                $stmt->execute([$courier_id, $order_id]);

                // 更新配送员状态
                $stmt = $pdo->prepare("UPDATE couriers 
                                     SET status = '配送中', current_orders = current_orders + 1 
                                     WHERE courier_id = ?");
                $stmt->execute([$courier_id]);

                $pdo->commit();
                $success_message = "订单已成功分配给配送员";
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "分配订单失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'update_status') {
            $delivery_id = $_POST['delivery_id'] ?? '';
            $new_status = $_POST['new_status'] ?? '';
            $courier_id = $_POST['courier_id'] ?? '';

            try {
                $pdo->beginTransaction();

                // 更新配送订单状态
                $stmt = $pdo->prepare("UPDATE delivery_orders SET status = ? WHERE delivery_id = ?");
                $stmt->execute([$new_status, $delivery_id]);

                // 如果订单已送达，更新配送员状态
                if ($new_status === '已送达') {
                    $stmt = $pdo->prepare("UPDATE couriers 
                                         SET status = CASE WHEN current_orders <= 1 THEN '空闲' ELSE '配送中' END,
                                             current_orders = current_orders - 1,
                                             total_orders = total_orders + 1
                                         WHERE courier_id = ?");
                    $stmt->execute([$courier_id]);

                    // 计算实际配送时间
                    $stmt = $pdo->prepare("UPDATE delivery_orders 
                                         SET delivery_time = NOW(),
                                             actual_time = TIMESTAMPDIFF(MINUTE, pickup_time, NOW())
                                         WHERE delivery_id = ?");
                    $stmt->execute([$delivery_id]);
                }

                $pdo->commit();
                $success_message = "配送状态已更新";
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "更新状态失败: " . $e->getMessage();
            }
        }
    }
}

// 获取待分配的订单
try {
    $stmt = $pdo->query("SELECT do.*, o.total_amount, o.create_time as order_create_time,
                        (SELECT COUNT(*) FROM order_details WHERE order_id = do.order_id) as items_count
                        FROM delivery_orders do
                        JOIN orders o ON do.order_id = o.order_id
                        WHERE do.status = '待分配'
                        ORDER BY o.create_time ASC");
    $pending_orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取待分配订单失败: " . $e->getMessage();
    $pending_orders = [];
}

// 获取进行中的配送
try {
    $stmt = $pdo->query("SELECT do.*, o.total_amount, c.name as courier_name, c.phone as courier_phone
                        FROM delivery_orders do
                        JOIN orders o ON do.order_id = o.order_id
                        LEFT JOIN couriers c ON do.courier_id = c.courier_id
                        WHERE do.status IN ('已分配', '配送中')
                        ORDER BY do.assign_time DESC");
    $active_deliveries = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取进行中配送失败: " . $e->getMessage();
    $active_deliveries = [];
}

// 获取可用的配送员
try {
    $stmt = $pdo->query("SELECT * FROM couriers 
                        WHERE is_active = 1 AND status != '休息'
                        ORDER BY 
                            CASE status 
                                WHEN '空闲' THEN 1 
                                WHEN '配送中' THEN 2 
                                ELSE 3 
                            END,
                            current_orders ASC,
                            rating DESC");
    $available_couriers = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取配送员失败: " . $e->getMessage();
    $available_couriers = [];
}

// 获取今日配送统计
try {
    $stmt = $pdo->query("SELECT 
                            COUNT(*) as total_deliveries,
                            COUNT(CASE WHEN status = '已送达' THEN 1 END) as completed_deliveries,
                            AVG(CASE WHEN status = '已送达' THEN actual_time END) as avg_delivery_time,
                            COUNT(CASE WHEN status = '待分配' THEN 1 END) as pending_deliveries
                        FROM delivery_orders
                        WHERE DATE(assign_time) = CURRENT_DATE OR DATE(delivery_time) = CURRENT_DATE");
    $daily_stats = $stmt->fetch();
} catch (Exception $e) {
    $error_message = "获取统计数据失败: " . $e->getMessage();
    $daily_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>外卖配送管理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .dashboard {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .stat-card {
            background: #fff;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #2196F3;
            margin: 10px 0;
        }

        .stat-label {
            color: #666;
            font-size: 14px;
        }

        .delivery-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(350px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .delivery-card {
            background: #fff;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            position: relative;
        }

        .delivery-card.pending {
            border-left: 4px solid #ff9800;
        }

        .delivery-card.active {
            border-left: 4px solid #4caf50;
        }

        .delivery-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .delivery-id {
            font-weight: bold;
            font-size: 1.1em;
        }

        .delivery-status {
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-pending {
            background: #ff9800;
        }

        .status-assigned {
            background: #2196F3;
        }

        .status-delivering {
            background: #4caf50;
        }

        .delivery-info {
            margin-bottom: 15px;
        }

        .delivery-info p {
            margin: 5px 0;
            display: flex;
            justify-content: space-between;
        }

        .delivery-actions {
            display: flex;
            gap: 10px;
            margin-top: 15px;
        }

        .courier-select {
            width: 100%;
            padding: 8px;
            margin-bottom: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .section-title {
            margin: 30px 0 15px;
            padding-bottom: 10px;
            border-bottom: 2px solid #eee;
            font-size: 1.5em;
            color: #333;
        }

        .timer {
            color: #666;
            font-size: 0.9em;
            margin-top: 10px;
        }

        .timer.warning {
            color: #f44336;
        }

        .courier-info {
            background: #f5f5f5;
            padding: 10px;
            border-radius: 4px;
            margin-top: 10px;
        }

        .courier-info p {
            margin: 5px 0;
            font-size: 0.9em;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>外卖配送管理</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="dashboard">
            <div class="stat-card">
                <div class="stat-value"><?php echo $daily_stats['total_deliveries'] ?? 0; ?></div>
                <div class="stat-label">今日总配送</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $daily_stats['completed_deliveries'] ?? 0; ?></div>
                <div class="stat-label">已完成配送</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo round($daily_stats['avg_delivery_time'] ?? 0); ?>分钟</div>
                <div class="stat-label">平均配送时间</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $daily_stats['pending_deliveries'] ?? 0; ?></div>
                <div class="stat-label">待分配订单</div>
            </div>
        </div>

        <div class="section-title">待分配订单</div>
        <div class="delivery-grid">
            <?php if (empty($pending_orders)): ?>
                <p>当前没有待分配的订单</p>
            <?php else: ?>
                <?php foreach ($pending_orders as $order): ?>
                    <div class="delivery-card pending">
                        <div class="delivery-header">
                            <div class="delivery-id">订单号: <?php echo $order['order_id']; ?></div>
                            <div class="delivery-status status-pending">待分配</div>
                        </div>
                        <div class="delivery-info">
                            <p>
                                <span>商品数量:</span>
                                <span><?php echo $order['items_count']; ?>件</span>
                            </p>
                            <p>
                                <span>订单金额:</span>
                                <span>¥<?php echo number_format($order['total_amount'], 2); ?></span>
                            </p>
                            <p>
                                <span>配送地址:</span>
                                <span><?php echo $order['customer_address']; ?></span>
                            </p>
                            <p>
                                <span>预计用时:</span>
                                <span><?php echo $order['estimated_time']; ?>分钟</span>
                            </p>
                            <p>
                                <span>下单时间:</span>
                                <span><?php echo date('Y-m-d H:i', strtotime($order['order_create_time'])); ?></span>
                            </p>
                        </div>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="assign_order">
                            <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                            <select name="courier_id" class="courier-select" required>
                                <option value="">选择配送员</option>
                                <?php foreach ($available_couriers as $courier): ?>
                                    <option value="<?php echo $courier['courier_id']; ?>">
                                        <?php echo $courier['name']; ?>
                                        (<?php echo $courier['status']; ?>,
                                        当前订单: <?php echo $courier['current_orders']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <div class="delivery-actions">
                                <button type="submit" class="btn btn-primary">分配订单</button>
                            </div>
                        </form>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div class="section-title">进行中的配送</div>
        <div class="delivery-grid">
            <?php if (empty($active_deliveries)): ?>
                <p>当前没有进行中的配送</p>
            <?php else: ?>
                <?php foreach ($active_deliveries as $delivery): ?>
                    <div class="delivery-card active">
                        <div class="delivery-header">
                            <div class="delivery-id">订单号: <?php echo $delivery['order_id']; ?></div>
                            <div class="delivery-status status-<?php echo $delivery['status'] === '已分配' ? 'assigned' : 'delivering'; ?>">
                                <?php echo $delivery['status']; ?>
                            </div>
                        </div>
                        <div class="delivery-info">
                            <p>
                                <span>订单金额:</span>
                                <span>¥<?php echo number_format($delivery['total_amount'], 2); ?></span>
                            </p>
                            <p>
                                <span>配送地址:</span>
                                <span><?php echo $delivery['customer_address']; ?></span>
                            </p>
                            <div class="courier-info">
                                <p><strong>配送员信息:</strong></p>
                                <p>姓名: <?php echo $delivery['courier_name']; ?></p>
                                <p>电话: <?php echo $delivery['courier_phone']; ?></p>
                            </div>
                            <div class="timer <?php echo (time() - strtotime($delivery['assign_time'])) > $delivery['estimated_time'] * 60 ? 'warning' : ''; ?>"
                                data-time="<?php echo $delivery['assign_time']; ?>"
                                data-estimated="<?php echo $delivery['estimated_time']; ?>">
                                已用时: <?php
                                        $elapsed = time() - strtotime($delivery['assign_time']);
                                        echo floor($elapsed / 60) . '分' . ($elapsed % 60) . '秒';
                                        ?>
                            </div>
                        </div>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="update_status">
                            <input type="hidden" name="delivery_id" value="<?php echo $delivery['delivery_id']; ?>">
                            <input type="hidden" name="courier_id" value="<?php echo $delivery['courier_id']; ?>">
                            <div class="delivery-actions">
                                <?php if ($delivery['status'] === '已分配'): ?>
                                    <input type="hidden" name="new_status" value="配送中">
                                    <button type="submit" class="btn btn-primary">开始配送</button>
                                <?php elseif ($delivery['status'] === '配送中'): ?>
                                    <input type="hidden" name="new_status" value="已送达">
                                    <button type="submit" class="btn btn-success">确认送达</button>
                                <?php endif; ?>
                            </div>
                        </form>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 自动刷新页面
        setTimeout(function() {
            location.reload();
        }, 30000); // 每30秒刷新一次

        // 更新计时器
        function updateTimers() {
            document.querySelectorAll('.timer').forEach(timer => {
                const assignTime = new Date(timer.getAttribute('data-time'));
                const now = new Date();
                const elapsed = Math.floor((now - assignTime) / 1000);
                const minutes = Math.floor(elapsed / 60);
                const seconds = elapsed % 60;

                timer.textContent = `已用时: ${minutes}分${seconds}秒`;

                // 如果超过预计时间，添加警告样式
                const estimatedTime = parseInt(timer.getAttribute('data-estimated')) * 60;
                if (elapsed > estimatedTime) {
                    timer.classList.add('warning');
                }
            });
        }

        // 每秒更新计时器
        setInterval(updateTimers, 1000);
    </script>
</body>

</html>