<?php
require_once '../config.php';

// 创建system_settings表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS system_settings (
        setting_id INT AUTO_INCREMENT PRIMARY KEY,
        setting_key VARCHAR(50) NOT NULL UNIQUE,
        setting_value TEXT,
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        update_time DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    )");
} catch (Exception $e) {
    $error_message = "创建系统设置表失败: " . $e->getMessage();
}

// 创建voice_alerts表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS voice_alerts (
        id INT AUTO_INCREMENT PRIMARY KEY,
        order_id VARCHAR(20),
        dish_id INT,
        status VARCHAR(20),
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        is_played TINYINT(1) DEFAULT 0,
        FOREIGN KEY (order_id) REFERENCES orders(order_id)
    )");
} catch (Exception $e) {
    $error_message = "创建语音提醒表失败: " . $e->getMessage();
}

// 处理设置保存
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action']) && $_POST['action'] === 'save_settings') {
        try {
            // 保存语音设置
            $voice_type = $_POST['voice_type'] ?? 'female';
            $voice_speed = $_POST['voice_speed'] ?? '1.0';
            $voice_volume = $_POST['voice_volume'] ?? '1.0';
            $auto_play = isset($_POST['auto_play']) ? 1 : 0;
            $play_interval = $_POST['play_interval'] ?? '5';
            $repeat_times = $_POST['repeat_times'] ?? '2';

            // 更新或插入设置
            $settings = [
                'voice_type' => $voice_type,
                'voice_speed' => $voice_speed,
                'voice_volume' => $voice_volume,
                'auto_play' => $auto_play,
                'play_interval' => $play_interval,
                'repeat_times' => $repeat_times
            ];

            foreach ($settings as $key => $value) {
                $stmt = $pdo->prepare("INSERT INTO system_settings (setting_key, setting_value) 
                                      VALUES (?, ?) 
                                      ON DUPLICATE KEY UPDATE setting_value = ?");
                $stmt->execute([$key, $value, $value]);
            }

            $success_message = "语音设置已保存";
        } catch (Exception $e) {
            $error_message = "保存设置失败: " . $e->getMessage();
        }
    } elseif (isset($_POST['action']) && $_POST['action'] === 'mark_played') {
        $alert_id = $_POST['alert_id'] ?? 0;

        try {
            $stmt = $pdo->prepare("UPDATE voice_alerts SET is_played = 1 WHERE id = ?");
            $stmt->execute([$alert_id]);

            $success_message = "已标记为已播放";
        } catch (Exception $e) {
            $error_message = "更新状态失败: " . $e->getMessage();
        }
    } elseif (isset($_POST['action']) && $_POST['action'] === 'test_voice') {
        $test_text = $_POST['test_text'] ?? '测试语音播报';

        // 这里只是模拟测试，实际项目中可能需要调用语音API
        $success_message = "测试语音已播放: " . $test_text;
    }
}

// 获取语音设置
try {
    $voice_settings = [];
    $stmt = $pdo->query("SELECT setting_key, setting_value FROM system_settings 
                        WHERE setting_key IN ('voice_type', 'voice_speed', 'voice_volume', 
                                            'auto_play', 'play_interval', 'repeat_times')");
    while ($row = $stmt->fetch()) {
        $voice_settings[$row['setting_key']] = $row['setting_value'];
    }
} catch (Exception $e) {
    $error_message = "获取设置失败: " . $e->getMessage();
    $voice_settings = [];
}

// 设置默认值
$voice_settings = array_merge([
    'voice_type' => 'female',
    'voice_speed' => '1.0',
    'voice_volume' => '1.0',
    'auto_play' => '1',
    'play_interval' => '5',
    'repeat_times' => '2'
], $voice_settings);

// 获取待播放的语音提醒
try {
    $stmt = $pdo->query("SELECT v.id, v.order_id, v.status, v.create_time, v.is_played,
                        o.type, o.table_id
                        FROM voice_alerts v
                        JOIN orders o ON v.order_id = o.order_id
                        WHERE v.is_played = 0
                        ORDER BY v.create_time ASC");
    $pending_alerts = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取待播放提醒失败: " . $e->getMessage();
    $pending_alerts = [];
}

// 获取已播放的语音历史
try {
    $stmt = $pdo->query("SELECT v.id, v.order_id, v.status, v.create_time, v.is_played,
                        o.type, o.table_id
                        FROM voice_alerts v
                        JOIN orders o ON v.order_id = o.order_id
                        WHERE v.is_played = 1
                        ORDER BY v.create_time DESC
                        LIMIT 50");
    $played_history = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取播放历史失败: " . $e->getMessage();
    $played_history = [];
}

// 生成语音文本函数
function generateVoiceText($order_id, $status, $type, $table_id)
{
    $text = '';

    if ($status === '取餐通知') {
        if ($type === '堂食') {
            $text = "请{$table_id}号桌的顾客取餐，您的订单{$order_id}已准备好";
        } elseif ($type === '外带') {
            $text = "请取餐号{$order_id}的顾客取餐，您的外带订单已准备好";
        } else {
            $text = "订单{$order_id}已准备好，请配送员取餐";
        }
    } else {
        $text = "订单{$order_id}状态更新为{$status}";
    }

    return $text;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>语音播报管理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .settings-panel {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 30px;
        }

        .form-group {
            margin-bottom: 15px;
        }

        .form-row {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 15px;
        }

        .form-control {
            width: 100%;
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .form-check {
            display: flex;
            align-items: center;
            gap: 8px;
        }

        .alert-list {
            margin-top: 20px;
        }

        .alert-item {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            padding: 15px;
            margin-bottom: 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .alert-item.pending {
            border-left: 4px solid #ff9800;
        }

        .alert-item.played {
            border-left: 4px solid #4caf50;
            opacity: 0.8;
        }

        .alert-info {
            flex: 1;
        }

        .alert-text {
            font-size: 1.1em;
            margin-bottom: 5px;
        }

        .alert-meta {
            font-size: 0.9em;
            color: #666;
        }

        .alert-actions {
            display: flex;
            gap: 10px;
        }

        .voice-test {
            background: #f5f5f5;
            border-radius: 8px;
            padding: 15px;
            margin-top: 20px;
        }

        .voice-test-input {
            display: flex;
            gap: 10px;
        }

        .voice-test-input input {
            flex: 1;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tab-nav {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab-btn {
            padding: 10px 20px;
            background: none;
            border: none;
            border-bottom: 3px solid transparent;
            cursor: pointer;
            font-size: 1em;
            color: #666;
        }

        .tab-btn.active {
            border-bottom-color: #2196F3;
            color: #2196F3;
            font-weight: bold;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .range-control {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .range-control input[type="range"] {
            flex: 1;
        }

        .range-value {
            min-width: 40px;
            text-align: center;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>语音播报管理</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="tab-container">
            <div class="tab-nav">
                <button class="tab-btn active" data-tab="pending">待播放提醒</button>
                <button class="tab-btn" data-tab="settings">语音设置</button>
                <button class="tab-btn" data-tab="history">播放历史</button>
            </div>

            <div class="tab-content active" id="pending-tab">
                <h2>待播放语音提醒</h2>

                <?php if (empty($pending_alerts)): ?>
                    <p>当前没有待播放的语音提醒</p>
                <?php else: ?>
                    <div class="alert-list">
                        <?php foreach ($pending_alerts as $alert): ?>
                            <div class="alert-item pending">
                                <div class="alert-info">
                                    <div class="alert-text">
                                        <?php echo generateVoiceText($alert['order_id'], $alert['status'], $alert['type'], $alert['table_id']); ?>
                                    </div>
                                    <div class="alert-meta">
                                        订单号: <?php echo $alert['order_id']; ?> |
                                        类型: <?php echo $alert['type']; ?> |
                                        创建时间: <?php echo date('Y-m-d H:i:s', strtotime($alert['create_time'])); ?>
                                    </div>
                                </div>
                                <div class="alert-actions">
                                    <button class="btn btn-primary play-btn"
                                        data-text="<?php echo generateVoiceText($alert['order_id'], $alert['status'], $alert['type'], $alert['table_id']); ?>">
                                        播放
                                    </button>
                                    <form method="post" action="" style="display: inline;">
                                        <input type="hidden" name="alert_id" value="<?php echo $alert['id']; ?>">
                                        <input type="hidden" name="action" value="mark_played">
                                        <button type="submit" class="btn btn-success">标记已播放</button>
                                    </form>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <?php if ($voice_settings['auto_play'] == '1' && !empty($pending_alerts)): ?>
                        <div class="auto-play-info">
                            <p>自动播放已启用，每 <?php echo $voice_settings['play_interval']; ?> 秒播放一次，重复 <?php echo $voice_settings['repeat_times']; ?> 次</p>
                            <button class="btn btn-secondary" id="stop-auto-play">暂停自动播放</button>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
            </div>

            <div class="tab-content" id="settings-tab">
                <h2>语音播报设置</h2>

                <div class="settings-panel">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="save_settings">

                        <div class="form-group">
                            <label>语音类型</label>
                            <div class="form-row">
                                <label class="form-check">
                                    <input type="radio" name="voice_type" value="female" <?php echo $voice_settings['voice_type'] === 'female' ? 'checked' : ''; ?>>
                                    女声
                                </label>
                                <label class="form-check">
                                    <input type="radio" name="voice_type" value="male" <?php echo $voice_settings['voice_type'] === 'male' ? 'checked' : ''; ?>>
                                    男声
                                </label>
                            </div>
                        </div>

                        <div class="form-group">
                            <label>语速</label>
                            <div class="range-control">
                                <input type="range" name="voice_speed" min="0.5" max="2" step="0.1" value="<?php echo $voice_settings['voice_speed']; ?>" id="speed-range">
                                <span class="range-value" id="speed-value"><?php echo $voice_settings['voice_speed']; ?></span>
                            </div>
                        </div>

                        <div class="form-group">
                            <label>音量</label>
                            <div class="range-control">
                                <input type="range" name="voice_volume" min="0.1" max="1" step="0.1" value="<?php echo $voice_settings['voice_volume']; ?>" id="volume-range">
                                <span class="range-value" id="volume-value"><?php echo $voice_settings['voice_volume']; ?></span>
                            </div>
                        </div>

                        <div class="form-group">
                            <label class="form-check">
                                <input type="checkbox" name="auto_play" value="1" <?php echo $voice_settings['auto_play'] == '1' ? 'checked' : ''; ?>>
                                启用自动播放
                            </label>
                        </div>

                        <div class="form-row">
                            <div class="form-group" style="flex: 1;">
                                <label>播放间隔（秒）</label>
                                <input type="number" name="play_interval" class="form-control" value="<?php echo $voice_settings['play_interval']; ?>" min="1">
                            </div>

                            <div class="form-group" style="flex: 1;">
                                <label>重复次数</label>
                                <input type="number" name="repeat_times" class="form-control" value="<?php echo $voice_settings['repeat_times']; ?>" min="1" max="5">
                            </div>
                        </div>

                        <div class="form-group">
                            <button type="submit" class="btn btn-primary">保存设置</button>
                        </div>
                    </form>

                    <div class="voice-test">
                        <h3>测试语音播报</h3>
                        <form method="post" action="" class="voice-test-input">
                            <input type="hidden" name="action" value="test_voice">
                            <input type="text" name="test_text" class="form-control" placeholder="输入测试文本" value="请1号桌的顾客取餐，您的订单已准备好">
                            <button type="submit" class="btn btn-primary">测试播放</button>
                        </form>
                    </div>
                </div>
            </div>

            <div class="tab-content" id="history-tab">
                <h2>播放历史记录</h2>

                <?php if (empty($played_history)): ?>
                    <p>暂无播放历史记录</p>
                <?php else: ?>
                    <div class="alert-list">
                        <?php foreach ($played_history as $alert): ?>
                            <div class="alert-item played">
                                <div class="alert-info">
                                    <div class="alert-text">
                                        <?php echo generateVoiceText($alert['order_id'], $alert['status'], $alert['type'], $alert['table_id']); ?>
                                    </div>
                                    <div class="alert-meta">
                                        订单号: <?php echo $alert['order_id']; ?> |
                                        类型: <?php echo $alert['type']; ?> |
                                        播放时间: <?php echo date('Y-m-d H:i:s', strtotime($alert['create_time'])); ?>
                                    </div>
                                </div>
                                <div class="alert-actions">
                                    <button class="btn btn-outline-primary play-btn"
                                        data-text="<?php echo generateVoiceText($alert['order_id'], $alert['status'], $alert['type'], $alert['table_id']); ?>">
                                        重新播放
                                    </button>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <script>
        // 标签页切换
        document.querySelectorAll('.tab-btn').forEach(button => {
            button.addEventListener('click', function() {
                // 更新按钮状态
                document.querySelectorAll('.tab-btn').forEach(btn => {
                    btn.classList.remove('active');
                });
                this.classList.add('active');

                // 更新内容显示
                const tabId = this.getAttribute('data-tab');
                document.querySelectorAll('.tab-content').forEach(content => {
                    content.classList.remove('active');
                });
                document.getElementById(tabId + '-tab').classList.add('active');
            });
        });

        // 范围滑块值更新
        document.getElementById('speed-range').addEventListener('input', function() {
            document.getElementById('speed-value').textContent = this.value;
        });

        document.getElementById('volume-range').addEventListener('input', function() {
            document.getElementById('volume-value').textContent = this.value;
        });

        // 播放按钮点击事件
        document.querySelectorAll('.play-btn').forEach(button => {
            button.addEventListener('click', function() {
                const text = this.getAttribute('data-text');
                // 在实际项目中，这里应该调用语音API
                alert('播放语音: ' + text);

                // 如果是待播放列表中的项目，可以自动标记为已播放
                if (this.closest('.alert-item.pending')) {
                    const form = this.nextElementSibling;
                    if (form && form.tagName === 'FORM') {
                        form.submit();
                    }
                }
            });
        });

        // 自动播放控制
        <?php if ($voice_settings['auto_play'] == '1' && !empty($pending_alerts)): ?>
            let autoPlayInterval;
            let currentRepeat = 0;
            let currentAlertIndex = 0;
            const pendingAlerts = document.querySelectorAll('.alert-item.pending');

            function startAutoPlay() {
                autoPlayInterval = setInterval(() => {
                    if (currentAlertIndex >= pendingAlerts.length) {
                        currentAlertIndex = 0;
                        currentRepeat++;

                        if (currentRepeat >= <?php echo $voice_settings['repeat_times']; ?>) {
                            clearInterval(autoPlayInterval);
                            return;
                        }
                    }

                    const playBtn = pendingAlerts[currentAlertIndex].querySelector('.play-btn');
                    if (playBtn) {
                        playBtn.click();
                    }

                    currentAlertIndex++;
                }, <?php echo $voice_settings['play_interval'] * 1000; ?>);
            }

            // 启动自动播放
            startAutoPlay();

            // 停止自动播放
            document.getElementById('stop-auto-play').addEventListener('click', function() {
                clearInterval(autoPlayInterval);
                this.textContent = '已停止自动播放';
                this.disabled = true;
            });
        <?php endif; ?>
    </script>
</body>

</html>