<?php
// home.php
declare(strict_types=1);
require_once './config.php';
session_start();

// 登录验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ./login.php");
    exit;
}

// 获取员工信息（适配employees表）
try {
    $stmt = $pdo->prepare("
        SELECT 
            username,
            role           
        FROM employees 
        WHERE employee_id = ?
    ");
    $stmt->execute([$_SESSION['employee_id']]);
    $userInfo = $stmt->fetch(PDO::FETCH_ASSOC);

    // 角色映射配置（根据数据库ENUM值）
    $roleMap = [
        'admin'    => '系统管理员',
        'cashier'  => '收银员',
        'chef'     => '主厨',
        'manager'  => '门店经理'
    ];
    $displayRole = $roleMap[$userInfo['role']] ?? '未授权用户';
} catch (PDOException $e) {
    die("用户信息获取失败: " . $e->getMessage());
}

// 系统核心模块（根据实际功能调整）
$modules = [
    [
        'name' => '点餐管理',
        'url' => './order/index.php',
        'features' => [
            '✓ 扫码点餐（桌码绑定/多人同步）',
            '✓ 自助机点餐（支付一体化）',
            '✓ APP/小程序点餐（预点餐）',
            '✓ 前台录单（多终端同步）'
        ]
    ],
    [
        'name' => '订单管理',
        'url' => './order_manage/index.php',
        'features' => [
            '✓ 实时订单状态跟踪',
            '✓ 订单修改/合并/拆单',
            '✓ 历史订单查询',
            '✓ 自动分单逻辑'
        ]
    ],
    [
        'name' => '厨房管理',
        'url' => './kitchen/index.php',
        'features' => [
            '✓ 后厨显示系统（KDS）',
            '✓ 智能分区调度',
            '✓ 菜品进度可视化',
            '✓ 语音播报提醒'
        ]
    ],
    [
        'name' => '配送管理',
        'url' => './delivery/index.php',
        'features' => [
            '✓ 智能叫号系统',
            '✓ 外卖订单对接',
            '✓ 配送员自动匹配',
            '✓ 多渠道取餐通知'
        ]
    ],
    [
        'name' => '支付结算',
        'url' => './payment/index.php',
        'features' => [
            '✓ 全渠道支付接入',
            '✓ 定金预支付',
            '✓ 电子发票系统',
            '✓ 分账结算支持'
        ]
    ],
    [
        'name' => '会员营销',
        'url' => './member/index.php',
        'features' => [
            '✓ 会员体系管理',
            '✓ 智能优惠券发放',
            '✓ 消费行为分析',
            '✓ 裂变营销工具'
        ]
    ],
    [
        'name' => '数据智能',
        'url' => './bi/index.php',
        'features' => [
            '✓ 实时销售看板',
            '✓ 菜品热度分析',
            '✓ 库存消耗预测',
            '✓ 用户画像系统'
        ]
    ],
    [
        'name' => '系统设置',
        'url' => './system/index.php',
        'features' => [
            '✓ 角色权限管理',
            '✓ 操作日志审计',
            '✓ 数据备份恢复',
            '✓ 系统健康监控'
        ]
    ]
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>点餐易（OrderEase）管理系统</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/5.1.3/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .dashboard-container {
            background: #f8f9fa;
            min-height: 100vh;
            padding: 2rem;
        }

        .header-bar {
            background: linear-gradient(135deg, #2c3e50, #3498db);
            color: white;
            padding: 1.5rem;
            margin: -2rem -2rem 2rem -2rem;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            position: relative;
        }

        .module-card {
            border: none;
            border-radius: 12px;
            transition: all 0.3s cubic-bezier(.25, .8, .25, 1);
            background: white;
            height: 100%;
        }

        .module-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 20px rgba(44, 62, 80, 0.15);
        }

        .module-title {
            color: #2c3e50;
            font-weight: 600;
            font-size: 1.25rem;
            border-left: 4px solid #3498db;
            padding-left: 1rem;
            margin: 1rem 0;
        }

        .feature-list li {
            color: #666;
            padding: 8px 0;
            border-bottom: 1px solid #eee;
        }

        .feature-list li:last-child {
            border-bottom: none;
        }

        .user-info-badge {
            background: rgba(255, 255, 255, 0.1);
            border-radius: 20px;
            padding: 8px 20px;
            backdrop-filter: blur(5px);
        }
    </style>
</head>

<body>
    <div class="dashboard-container">
        <!-- 头部信息栏 -->
        <div class="header-bar">
            <div class="d-flex justify-content-between align-items-center">
                <div class="user-info">
                    <div class="h5 mb-0"><?= htmlspecialchars($userInfo['username']) ?></div>
                    <small class="text-light">角色：<?= htmlspecialchars($displayRole) ?></small>
                </div>
                <h1 class="header-title mb-0 fs-4">点餐易智能管理系统</h1>
                <div>
                    <a href="./logout.php" class="btn btn-sm btn-light">
                        <i class="fas fa-sign-out-alt"></i> 退出登录
                    </a>
                </div>
            </div>
        </div>

        <!-- 功能模块网格 -->
        <div class="container-fluid">
            <div class="row row-cols-1 row-cols-md-2 row-cols-lg-3 row-cols-xl-4 g-4">
                <?php foreach ($modules as $module): ?>
                    <div class="col">
                        <a href="<?= htmlspecialchars($module['url']) ?>" class="text-decoration-none">
                            <div class="card module-card h-100">
                                <div class="card-body">
                                    <h5 class="module-title text-center mb-3"><?= htmlspecialchars($module['name']) ?></h5>
                                    <ul class="feature-list list-unstyled mb-0">
                                        <?php foreach ($module['features'] as $feature): ?>
                                            <li><?= htmlspecialchars($feature) ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.4/js/all.min.js"></script>
</body>

</html>