<?php
require_once '../config.php';

// 处理菜品状态更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $order_id = $_POST['order_id'] ?? '';
    $dish_id = $_POST['dish_id'] ?? '';
    $new_status = $_POST['new_status'] ?? '';

    try {
        $pdo->beginTransaction();

        if ($_POST['action'] === 'update_dish_status') {
            // 更新订单详情状态
            $stmt = $pdo->prepare("UPDATE order_details SET status = ? WHERE order_id = ? AND dish_id = ?");
            $stmt->execute([$new_status, $order_id, $dish_id]);

            // 检查该订单的所有菜品是否都已完成
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details WHERE order_id = ? AND status != '已完成'");
            $stmt->execute([$order_id]);
            $pending_count = $stmt->fetchColumn();

            // 如果所有菜品都已完成，更新订单状态为已完成
            if ($pending_count == 0) {
                $stmt = $pdo->prepare("UPDATE orders SET status = '已完成' WHERE order_id = ?");
                $stmt->execute([$order_id]);

                $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '已完成' WHERE order_id = ?");
                $stmt->execute([$order_id]);
            } else if ($new_status === '制作中') {
                // 如果有菜品状态变为制作中，更新订单状态为进行中
                $stmt = $pdo->prepare("UPDATE orders SET status = '进行中' WHERE order_id = ?");
                $stmt->execute([$order_id]);

                $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '制作中' WHERE order_id = ?");
                $stmt->execute([$order_id]);
            }

            // 记录状态变更，用于语音播报
            $stmt = $pdo->prepare("INSERT INTO voice_alerts (order_id, dish_id, status, create_time) VALUES (?, ?, ?, NOW())");
            $stmt->execute([$order_id, $dish_id, $new_status]);

            $success_message = "菜品状态已更新为: " . htmlspecialchars($new_status);
        } else if ($_POST['action'] === 'batch_update') {
            $dish_ids = $_POST['dish_ids'] ?? [];
            $order_ids = $_POST['order_ids'] ?? [];
            $batch_status = $_POST['batch_status'] ?? '';

            if (!empty($dish_ids) && !empty($order_ids) && !empty($batch_status)) {
                for ($i = 0; $i < count($dish_ids); $i++) {
                    $stmt = $pdo->prepare("UPDATE order_details SET status = ? WHERE order_id = ? AND dish_id = ?");
                    $stmt->execute([$batch_status, $order_ids[$i], $dish_ids[$i]]);

                    // 记录状态变更，用于语音播报
                    try {
                        // 确保voice_alerts表存在
                        $pdo->exec("CREATE TABLE IF NOT EXISTS voice_alerts (
                            id INT AUTO_INCREMENT PRIMARY KEY,
                            order_id VARCHAR(20),
                            dish_id INT,
                            status VARCHAR(20),
                            create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
                            is_played TINYINT(1) DEFAULT 0,
                            FOREIGN KEY (order_id) REFERENCES orders(order_id),
                            FOREIGN KEY (dish_id) REFERENCES dishes(dish_id)
                        )");

                        $stmt = $pdo->prepare("INSERT INTO voice_alerts (order_id, dish_id, status, create_time) VALUES (?, ?, ?, NOW())");
                        $stmt->execute([$order_ids[$i], $dish_ids[$i], $batch_status]);
                    } catch (Exception $e) {
                        // 如果voice_alerts表不存在或插入失败，忽略错误
                    }
                }

                // 更新相关订单的状态
                foreach (array_unique($order_ids) as $oid) {
                    // 检查该订单的所有菜品是否都已完成
                    $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details WHERE order_id = ? AND status != '已完成'");
                    $stmt->execute([$oid]);
                    $pending_count = $stmt->fetchColumn();

                    if ($pending_count == 0) {
                        $stmt = $pdo->prepare("UPDATE orders SET status = '已完成' WHERE order_id = ?");
                        $stmt->execute([$oid]);

                        $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '已完成' WHERE order_id = ?");
                        $stmt->execute([$oid]);
                    } else if ($batch_status === '制作中') {
                        $stmt = $pdo->prepare("UPDATE orders SET status = '进行中' WHERE order_id = ?");
                        $stmt->execute([$oid]);

                        $stmt = $pdo->prepare("UPDATE kitchen_orders SET status = '制作中' WHERE order_id = ?");
                        $stmt->execute([$oid]);
                    }
                }

                $success_message = "已批量更新 " . count($dish_ids) . " 个菜品状态为: " . htmlspecialchars($batch_status);
            }
        }

        $pdo->commit();
    } catch (Exception $e) {
        $pdo->rollBack();
        $error_message = "更新失败: " . $e->getMessage();
    }
}

// 获取所有进行中的订单及其菜品
$stmt = $pdo->query("SELECT o.order_id, o.type, o.table_id, o.status, o.create_time, o.total_amount
                FROM orders o
                WHERE o.status IN ('待支付', '进行中')
                ORDER BY o.create_time DESC");
$orders = $stmt->fetchAll();

// 获取所有菜品类别
$stmt = $pdo->query("SELECT DISTINCT category FROM dishes ORDER BY category");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 获取所有菜品状态统计
$stmt = $pdo->query("SELECT status, COUNT(*) as count FROM order_details 
                WHERE order_id IN (SELECT order_id FROM orders WHERE status IN ('待支付', '进行中'))
                GROUP BY status");
$status_stats = [];
while ($row = $stmt->fetch()) {
    $status_stats[$row['status']] = $row['count'];
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>菜品进度更新</title>
    <link rel="stylesheet" href="../order_manage/style.css">
    <style>
        .progress-container {
            display: grid;
            grid-template-columns: 1fr 300px;
            gap: 20px;
        }

        @media (max-width: 992px) {
            .progress-container {
                grid-template-columns: 1fr;
            }
        }

        .dishes-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 15px;
        }

        .dish-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 15px;
            position: relative;
        }

        .dish-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 10px;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        .dish-name {
            font-weight: bold;
            font-size: 16px;
        }

        .dish-quantity {
            background-color: #f1f1f1;
            padding: 2px 8px;
            border-radius: 12px;
            font-size: 14px;
        }

        .dish-info {
            margin-bottom: 10px;
        }

        .dish-info p {
            margin: 5px 0;
            font-size: 14px;
        }

        .dish-actions {
            display: flex;
            gap: 10px;
        }

        .btn-action {
            padding: 5px 10px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 12px;
            color: white;
        }

        .btn-start {
            background-color: #3498db;
        }

        .btn-complete {
            background-color: #2ecc71;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
        }

        .等待中 {
            background-color: #f39c12;
        }

        .制作中 {
            background-color: #3498db;
        }

        .已完成 {
            background-color: #2ecc71;
        }

        .order-type {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
            margin-left: 10px;
        }

        .order-type-堂食 {
            background-color: #3498db;
        }

        .order-type-外带 {
            background-color: #e67e22;
        }

        .order-type-外卖 {
            background-color: #9b59b6;
        }

        .category-title {
            font-size: 18px;
            font-weight: bold;
            margin: 20px 0 10px;
            padding-bottom: 5px;
            border-bottom: 2px solid #3498db;
        }

        .stats-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 15px;
            margin-bottom: 20px;
        }

        .stats-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 15px;
            padding-bottom: 5px;
            border-bottom: 1px solid #eee;
        }

        .stats-item {
            display: flex;
            justify-content: space-between;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .stats-item:last-child {
            border-bottom: none;
        }

        .stats-label {
            display: flex;
            align-items: center;
        }

        .stats-value {
            font-weight: bold;
        }

        .batch-actions {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 15px;
            margin-bottom: 20px;
        }

        .batch-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 15px;
            padding-bottom: 5px;
            border-bottom: 1px solid #eee;
        }

        .batch-form {
            display: flex;
            flex-direction: column;
            gap: 10px;
        }

        .batch-form select {
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .batch-form button {
            padding: 8px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .batch-form button:hover {
            background-color: #2980b9;
        }

        .selected-dishes {
            margin-top: 10px;
        }

        .selected-dish-item {
            display: flex;
            justify-content: space-between;
            padding: 5px 0;
            border-bottom: 1px dashed #eee;
            font-size: 14px;
        }

        .selected-dish-item:last-child {
            border-bottom: none;
        }

        .checkbox-container {
            position: absolute;
            top: 10px;
            right: 10px;
        }

        .checkbox-container input[type="checkbox"] {
            width: 18px;
            height: 18px;
        }

        .filters {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 20px;
        }

        .filter-group {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .filter-group label {
            font-weight: bold;
        }

        .filter-group select {
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .empty-state {
            text-align: center;
            padding: 30px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
    </style>
</head>

<body>
    <h1>菜品进度更新</h1>

    <?php if (isset($success_message)): ?>
        <div class="alert"><?= htmlspecialchars($success_message); ?></div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert error"><?= htmlspecialchars($error_message); ?></div>
    <?php endif; ?>

    <div class="filters">
        <div class="filter-group">
            <label for="category-filter">菜品类别:</label>
            <select id="category-filter">
                <option value="">全部类别</option>
                <?php foreach ($categories as $category): ?>
                    <option value="<?= htmlspecialchars($category); ?>"><?= htmlspecialchars($category); ?></option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="filter-group">
            <label for="status-filter">状态:</label>
            <select id="status-filter">
                <option value="">全部状态</option>
                <option value="等待中">等待中</option>
                <option value="制作中">制作中</option>
                <option value="已完成">已完成</option>
            </select>
        </div>

        <div class="filter-group">
            <label for="order-type-filter">订单类型:</label>
            <select id="order-type-filter">
                <option value="">全部类型</option>
                <option value="堂食">堂食</option>
                <option value="外带">外带</option>
                <option value="外卖">外卖</option>
            </select>
        </div>

        <div class="filter-group">
            <button type="button" class="btn-action btn-start" onclick="location.reload()">刷新数据</button>
        </div>
    </div>

    <div class="progress-container">
        <div class="left-column">
            <?php if (empty($orders)): ?>
                <div class="empty-state">
                    <h3>当前没有进行中的订单</h3>
                    <p>所有订单已完成或尚未有新订单</p>
                </div>
            <?php else: ?>
                <form id="batch-form" method="post" style="display: none;">
                    <input type="hidden" name="action" value="batch_update">
                    <input type="hidden" name="batch_status" id="batch_status">
                    <div id="batch-inputs"></div>
                </form>

                <?php foreach ($categories as $category): ?>
                    <?php
                    // 检查是否有该类别的菜品
                    $has_category_dishes = false;
                    foreach ($orders as $order) {
                        $stmt = $pdo->prepare("SELECT COUNT(*) FROM order_details od 
                                             JOIN dishes d ON od.dish_id = d.dish_id 
                                             WHERE od.order_id = ? AND d.category = ?");
                        $stmt->execute([$order['order_id'], $category]);
                        if ($stmt->fetchColumn() > 0) {
                            $has_category_dishes = true;
                            break;
                        }
                    }

                    if (!$has_category_dishes) continue;
                    ?>

                    <div class="category-section" data-category="<?= htmlspecialchars($category); ?>">
                        <h2 class="category-title"><?= htmlspecialchars($category); ?></h2>

                        <div class="dishes-container">
                            <?php foreach ($orders as $order): ?>
                                <?php
                                // 获取该订单中该类别的菜品
                                $stmt = $pdo->prepare("SELECT od.*, d.name, d.category 
                                             FROM order_details od 
                                             JOIN dishes d ON od.dish_id = d.dish_id 
                                             WHERE od.order_id = ? AND d.category = ?
                                             ORDER BY od.status, d.name");
                                $stmt->execute([$order['order_id'], $category]);
                                $dishes = $stmt->fetchAll();

                                if (empty($dishes)) continue;

                                foreach ($dishes as $dish):
                                ?>
                                    <div class="dish-card"
                                        data-status="<?= htmlspecialchars($dish['status']); ?>"
                                        data-order-type="<?= htmlspecialchars($order['type']); ?>">
                                        <div class="checkbox-container">
                                            <input type="checkbox" class="dish-checkbox"
                                                data-dish-id="<?= $dish['dish_id']; ?>"
                                                data-order-id="<?= $order['order_id']; ?>"
                                                data-dish-name="<?= htmlspecialchars($dish['name']); ?>">
                                        </div>

                                        <div class="dish-header">
                                            <div class="dish-name"><?= htmlspecialchars($dish['name']); ?></div>
                                            <div class="dish-quantity">x<?= htmlspecialchars($dish['quantity']); ?></div>
                                        </div>

                                        <div class="dish-info">
                                            <p>
                                                <strong>订单:</strong> <?= htmlspecialchars($order['order_id']); ?>
                                                <span class="order-type order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                                            </p>
                                            <?php if ($order['table_id']): ?>
                                                <p><strong>餐桌:</strong> <?= htmlspecialchars($order['table_id']); ?></p>
                                            <?php endif; ?>
                                            <p>
                                                <strong>状态:</strong>
                                                <span class="status-tag <?= htmlspecialchars($dish['status']); ?>"><?= htmlspecialchars($dish['status']); ?></span>
                                            </p>
                                        </div>

                                        <div class="dish-actions">
                                            <form method="post" style="display: inline;">
                                                <input type="hidden" name="action" value="update_dish_status">
                                                <input type="hidden" name="order_id" value="<?= htmlspecialchars($order['order_id']); ?>">
                                                <input type="hidden" name="dish_id" value="<?= htmlspecialchars($dish['dish_id']); ?>">

                                                <?php if ($dish['status'] === '等待中'): ?>
                                                    <input type="hidden" name="new_status" value="制作中">
                                                    <button type="submit" class="btn-action btn-start">开始制作</button>
                                                <?php elseif ($dish['status'] === '制作中'): ?>
                                                    <input type="hidden" name="new_status" value="已完成">
                                                    <button type="submit" class="btn-action btn-complete">完成</button>
                                                <?php endif; ?>
                                            </form>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>

        <div class="right-column">
            <div class="stats-card">
                <div class="stats-title">菜品状态统计</div>

                <div class="stats-item">
                    <div class="stats-label">
                        <span class="status-tag 等待中">等待中</span>
                    </div>
                    <div class="stats-value"><?= $status_stats['等待中'] ?? 0; ?></div>
                </div>

                <div class="stats-item">
                    <div class="stats-label">
                        <span class="status-tag 制作中">制作中</span>
                    </div>
                    <div class="stats-value"><?= $status_stats['制作中'] ?? 0; ?></div>
                </div>

                <div class="stats-item">
                    <div class="stats-label">
                        <span class="status-tag 已完成">已完成</span>
                    </div>
                    <div class="stats-value"><?= $status_stats['已完成'] ?? 0; ?></div>
                </div>
            </div>

            <div class="batch-actions">
                <div class="batch-title">批量操作</div>

                <div class="batch-form">
                    <div>
                        <label for="batch-status-select">选择状态:</label>
                        <select id="batch-status-select">
                            <option value="">请选择状态</option>
                            <option value="制作中">制作中</option>
                            <option value="已完成">已完成</option>
                        </select>
                    </div>

                    <button type="button" onclick="batchUpdate()">批量更新</button>

                    <div class="selected-dishes">
                        <div id="selected-dishes-count">已选择: 0 个菜品</div>
                        <div id="selected-dishes-list"></div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 筛选功能
        function applyFilters() {
            const categoryFilter = document.getElementById('category-filter').value;
            const statusFilter = document.getElementById('status-filter').value;
            const orderTypeFilter = document.getElementById('order-type-filter').value;

            // 筛选类别
            const categorySections = document.querySelectorAll('.category-section');
            categorySections.forEach(section => {
                const sectionCategory = section.getAttribute('data-category');
                if (categoryFilter && sectionCategory !== categoryFilter) {
                    section.style.display = 'none';
                } else {
                    section.style.display = '';
                }
            });

            // 筛选菜品状态和订单类型
            const dishCards = document.querySelectorAll('.dish-card');
            dishCards.forEach(card => {
                const cardStatus = card.getAttribute('data-status');
                const cardOrderType = card.getAttribute('data-order-type');

                let visible = true;

                if (statusFilter && cardStatus !== statusFilter) {
                    visible = false;
                }

                if (orderTypeFilter && cardOrderType !== orderTypeFilter) {
                    visible = false;
                }

                card.style.display = visible ? '' : 'none';
            });
        }

        // 添加筛选事件监听器
        document.getElementById('category-filter').addEventListener('change', applyFilters);
        document.getElementById('status-filter').addEventListener('change', applyFilters);
        document.getElementById('order-type-filter').addEventListener('change', applyFilters);

        // 批量选择功能
        const checkboxes = document.querySelectorAll('.dish-checkbox');
        const selectedDishesCount = document.getElementById('selected-dishes-count');
        const selectedDishesList = document.getElementById('selected-dishes-list');

        checkboxes.forEach(checkbox => {
            checkbox.addEventListener('change', updateSelectedDishes);
        });

        function updateSelectedDishes() {
            const selectedCheckboxes = document.querySelectorAll('.dish-checkbox:checked');
            selectedDishesCount.textContent = `已选择: ${selectedCheckboxes.length} 个菜品`;

            selectedDishesList.innerHTML = '';
            selectedCheckboxes.forEach(checkbox => {
                const dishName = checkbox.getAttribute('data-dish-name');
                const dishItem = document.createElement('div');
                dishItem.className = 'selected-dish-item';
                dishItem.textContent = dishName;
                selectedDishesList.appendChild(dishItem);
            });
        }

        // 批量更新功能
        function batchUpdate() {
            const selectedCheckboxes = document.querySelectorAll('.dish-checkbox:checked');
            if (selectedCheckboxes.length === 0) {
                alert('请至少选择一个菜品');
                return;
            }

            const batchStatus = document.getElementById('batch-status-select').value;
            if (!batchStatus) {
                alert('请选择要更新的状态');
                return;
            }

            // 确认操作
            if (!confirm(`确定要将选中的 ${selectedCheckboxes.length} 个菜品状态更新为 "${batchStatus}" 吗？`)) {
                return;
            }

            // 准备表单数据
            document.getElementById('batch_status').value = batchStatus;
            const batchInputs = document.getElementById('batch-inputs');
            batchInputs.innerHTML = '';

            selectedCheckboxes.forEach((checkbox, index) => {
                const dishId = checkbox.getAttribute('data-dish-id');
                const orderId = checkbox.getAttribute('data-order-id');

                const dishIdInput = document.createElement('input');
                dishIdInput.type = 'hidden';
                dishIdInput.name = `dish_ids[]`;
                dishIdInput.value = dishId;

                const orderIdInput = document.createElement('input');
                orderIdInput.type = 'hidden';
                orderIdInput.name = `order_ids[]`;
                orderIdInput.value = orderId;

                batchInputs.appendChild(dishIdInput);
                batchInputs.appendChild(orderIdInput);
            });

            // 提交表单
            document.getElementById('batch-form').submit();
        }
    </script>
</body>

</html>