<?php
require_once '../config.php';

// 创建voice_alerts表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS voice_alerts (
        id INT AUTO_INCREMENT PRIMARY KEY,
        order_id VARCHAR(20),
        dish_id INT,
        status VARCHAR(20),
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        is_played TINYINT(1) DEFAULT 0,
        FOREIGN KEY (order_id) REFERENCES orders(order_id),
        FOREIGN KEY (dish_id) REFERENCES dishes(dish_id)
    )");
} catch (Exception $e) {
    $error_message = "创建语音提醒表失败: " . $e->getMessage();
}

// 创建system_settings表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS system_settings (
        setting_id INT AUTO_INCREMENT PRIMARY KEY,
        setting_key VARCHAR(50) NOT NULL UNIQUE,
        setting_value TEXT,
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        update_time DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    )");
} catch (Exception $e) {
    $error_message = "创建系统设置表失败: " . $e->getMessage();
}

// 获取语音设置
$voice_settings = [];
try {
    $stmt = $pdo->query("SELECT * FROM system_settings WHERE setting_key LIKE 'voice_%'");
    while ($row = $stmt->fetch()) {
        $voice_settings[$row['setting_key']] = $row['setting_value'];
    }
} catch (Exception $e) {
    // 如果查询失败，使用默认设置
}

// 默认设置
$voice_enabled = $voice_settings['voice_enabled'] ?? '1';
$voice_volume = $voice_settings['voice_volume'] ?? '80';
$voice_type = $voice_settings['voice_type'] ?? 'female';
$voice_interval = $voice_settings['voice_interval'] ?? '5';

// 处理设置更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] === 'update_settings') {
        try {
            $pdo->beginTransaction();

            $new_voice_enabled = isset($_POST['voice_enabled']) ? '1' : '0';
            $new_voice_volume = $_POST['voice_volume'] ?? '80';
            $new_voice_type = $_POST['voice_type'] ?? 'female';
            $new_voice_interval = $_POST['voice_interval'] ?? '5';

            // 更新设置
            $stmt = $pdo->prepare("INSERT INTO system_settings (setting_key, setting_value) 
                                  VALUES (?, ?) 
                                  ON DUPLICATE KEY UPDATE setting_value = VALUES(setting_value)");

            $stmt->execute(['voice_enabled', $new_voice_enabled]);
            $stmt->execute(['voice_volume', $new_voice_volume]);
            $stmt->execute(['voice_type', $new_voice_type]);
            $stmt->execute(['voice_interval', $new_voice_interval]);

            $pdo->commit();

            // 更新当前设置
            $voice_enabled = $new_voice_enabled;
            $voice_volume = $new_voice_volume;
            $voice_type = $new_voice_type;
            $voice_interval = $new_voice_interval;

            $success_message = "语音设置已更新";
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = "更新设置失败: " . $e->getMessage();
        }
    } else if ($_POST['action'] === 'test_voice') {
        $success_message = "测试语音已播放";
    } else if ($_POST['action'] === 'mark_all_played') {
        try {
            $stmt = $pdo->prepare("UPDATE voice_alerts SET is_played = 1 WHERE is_played = 0");
            $stmt->execute();
            $success_message = "所有提醒已标记为已播放";
        } catch (Exception $e) {
            $error_message = "标记失败: " . $e->getMessage();
        }
    }
}

// 获取未播放的语音提醒
$alerts = [];
try {
    $stmt = $pdo->query("SELECT va.*, d.name as dish_name, o.type as order_type, o.table_id 
                        FROM voice_alerts va
                        JOIN dishes d ON va.dish_id = d.dish_id
                        JOIN orders o ON va.order_id = o.order_id
                        WHERE va.is_played = 0
                        ORDER BY va.create_time ASC
                        LIMIT 10");
    $alerts = $stmt->fetchAll();
} catch (Exception $e) {
    // 如果查询失败，使用空数组
}

// 获取最近的语音提醒历史
$history = [];
try {
    $stmt = $pdo->query("SELECT va.*, d.name as dish_name, o.type as order_type, o.table_id 
                        FROM voice_alerts va
                        JOIN dishes d ON va.dish_id = d.dish_id
                        JOIN orders o ON va.order_id = o.order_id
                        WHERE va.is_played = 1
                        ORDER BY va.create_time DESC
                        LIMIT 20");
    $history = $stmt->fetchAll();
} catch (Exception $e) {
    // 如果查询失败，使用空数组
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>语音播报系统</title>
    <link rel="stylesheet" href="../order_manage/style.css">
    <style>
        .voice-container {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        @media (max-width: 992px) {
            .voice-container {
                grid-template-columns: 1fr;
            }
        }

        .settings-card,
        .alerts-card,
        .history-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 20px;
        }

        .settings-title,
        .alerts-title,
        .history-title {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .settings-form {
            display: grid;
            grid-template-columns: 1fr 2fr;
            gap: 15px;
            align-items: center;
        }

        .settings-form label {
            font-weight: bold;
        }

        .settings-form input[type="range"] {
            width: 100%;
        }

        .settings-form select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .settings-form .volume-value {
            display: inline-block;
            width: 40px;
            text-align: right;
        }

        .settings-actions {
            grid-column: span 2;
            display: flex;
            justify-content: flex-end;
            gap: 10px;
            margin-top: 15px;
        }

        .btn {
            padding: 8px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
        }

        .btn-secondary {
            background-color: #95a5a6;
            color: white;
        }

        .btn-warning {
            background-color: #e67e22;
            color: white;
        }

        .alert-item {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px;
            border-bottom: 1px solid #eee;
            margin-bottom: 10px;
        }

        .alert-info {
            flex: 1;
        }

        .alert-time {
            color: #7f8c8d;
            font-size: 14px;
        }

        .alert-status {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
            margin-left: 10px;
        }

        .alert-status-等待中 {
            background-color: #f39c12;
        }

        .alert-status-制作中 {
            background-color: #3498db;
        }

        .alert-status-已完成 {
            background-color: #2ecc71;
        }

        .alert-actions {
            display: flex;
            gap: 10px;
        }

        .empty-state {
            text-align: center;
            padding: 20px;
            color: #7f8c8d;
        }

        .volume-control {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .order-type {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
            margin-left: 10px;
        }

        .order-type-堂食 {
            background-color: #3498db;
        }

        .order-type-外带 {
            background-color: #e67e22;
        }

        .order-type-外卖 {
            background-color: #9b59b6;
        }
    </style>
</head>

<body>
    <h1>语音播报系统</h1>

    <?php if (isset($success_message)): ?>
        <div class="alert"><?= htmlspecialchars($success_message); ?></div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert error"><?= htmlspecialchars($error_message); ?></div>
    <?php endif; ?>

    <div class="voice-container">
        <div class="left-column">
            <div class="settings-card">
                <div class="settings-title">语音设置</div>
                <form method="post" class="settings-form">
                    <input type="hidden" name="action" value="update_settings">

                    <label for="voice_enabled">启用语音播报</label>
                    <div>
                        <input type="checkbox" id="voice_enabled" name="voice_enabled" <?= $voice_enabled == '1' ? 'checked' : ''; ?>>
                    </div>

                    <label for="voice_volume">音量</label>
                    <div class="volume-control">
                        <input type="range" id="voice_volume" name="voice_volume" min="0" max="100" value="<?= htmlspecialchars($voice_volume); ?>" oninput="updateVolumeValue(this.value)">
                        <span id="volume_value" class="volume-value"><?= htmlspecialchars($voice_volume); ?></span>%
                    </div>

                    <label for="voice_type">语音类型</label>
                    <select id="voice_type" name="voice_type">
                        <option value="female" <?= $voice_type == 'female' ? 'selected' : ''; ?>>女声</option>
                        <option value="male" <?= $voice_type == 'male' ? 'selected' : ''; ?>>男声</option>
                    </select>

                    <label for="voice_interval">播报间隔 (秒)</label>
                    <select id="voice_interval" name="voice_interval">
                        <option value="3" <?= $voice_interval == '3' ? 'selected' : ''; ?>>3秒</option>
                        <option value="5" <?= $voice_interval == '5' ? 'selected' : ''; ?>>5秒</option>
                        <option value="10" <?= $voice_interval == '10' ? 'selected' : ''; ?>>10秒</option>
                        <option value="15" <?= $voice_interval == '15' ? 'selected' : ''; ?>>15秒</option>
                    </select>

                    <div class="settings-actions">
                        <button type="submit" class="btn btn-primary">保存设置</button>
                        <button type="button" class="btn btn-secondary" onclick="testVoice()">测试语音</button>
                    </div>
                </form>
            </div>

            <div class="alerts-card">
                <div class="alerts-title">
                    待播报提醒
                    <?php if (!empty($alerts)): ?>
                        <form method="post" style="display: inline; float: right;">
                            <input type="hidden" name="action" value="mark_all_played">
                            <button type="submit" class="btn btn-warning" style="font-size: 12px; padding: 4px 8px;">标记全部已播放</button>
                        </form>
                    <?php endif; ?>
                </div>

                <?php if (empty($alerts)): ?>
                    <div class="empty-state">
                        <p>当前没有待播报的提醒</p>
                    </div>
                <?php else: ?>
                    <div id="alerts-list">
                        <?php foreach ($alerts as $alert): ?>
                            <div class="alert-item" data-id="<?= $alert['id']; ?>" data-text="<?= htmlspecialchars($alert['order_type'] . ($alert['table_id'] ? '，餐桌' . $alert['table_id'] . '号' : '') . '，' . $alert['dish_name'] . '，' . $alert['status']); ?>">
                                <div class="alert-info">
                                    <div>
                                        <strong>订单: <?= htmlspecialchars($alert['order_id']); ?></strong>
                                        <span class="order-type order-type-<?= htmlspecialchars($alert['order_type']); ?>"><?= htmlspecialchars($alert['order_type']); ?></span>
                                        <?php if ($alert['table_id']): ?>
                                            <span>餐桌: <?= htmlspecialchars($alert['table_id']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                    <div>
                                        <span><?= htmlspecialchars($alert['dish_name']); ?></span>
                                        <span class="alert-status alert-status-<?= htmlspecialchars($alert['status']); ?>"><?= htmlspecialchars($alert['status']); ?></span>
                                    </div>
                                    <div class="alert-time"><?= htmlspecialchars($alert['create_time']); ?></div>
                                </div>
                                <div class="alert-actions">
                                    <button class="btn btn-secondary play-btn" onclick="playAlert(<?= $alert['id']; ?>)">播放</button>
                                    <button class="btn btn-warning mark-btn" onclick="markAsPlayed(<?= $alert['id']; ?>)">标记已播放</button>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <div class="right-column">
            <div class="history-card">
                <div class="history-title">播报历史</div>

                <?php if (empty($history)): ?>
                    <div class="empty-state">
                        <p>没有播报历史记录</p>
                    </div>
                <?php else: ?>
                    <div id="history-list">
                        <?php foreach ($history as $item): ?>
                            <div class="alert-item">
                                <div class="alert-info">
                                    <div>
                                        <strong>订单: <?= htmlspecialchars($item['order_id']); ?></strong>
                                        <span class="order-type order-type-<?= htmlspecialchars($item['order_type']); ?>"><?= htmlspecialchars($item['order_type']); ?></span>
                                        <?php if ($item['table_id']): ?>
                                            <span>餐桌: <?= htmlspecialchars($item['table_id']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                    <div>
                                        <span><?= htmlspecialchars($item['dish_name']); ?></span>
                                        <span class="alert-status alert-status-<?= htmlspecialchars($item['status']); ?>"><?= htmlspecialchars($item['status']); ?></span>
                                    </div>
                                    <div class="alert-time"><?= htmlspecialchars($item['create_time']); ?></div>
                                </div>
                                <div class="alert-actions">
                                    <button class="btn btn-secondary" onclick="replayAlert('<?= htmlspecialchars($item['order_type'] . ($item['table_id'] ? '，餐桌' . $item['table_id'] . '号' : '') . '，' . $item['dish_name'] . '，' . $item['status']); ?>')">重播</button>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <form id="test-form" method="post" style="display: none;">
        <input type="hidden" name="action" value="test_voice">
    </form>

    <script>
        // 更新音量显示值
        function updateVolumeValue(value) {
            document.getElementById('volume_value').textContent = value;
        }

        // 测试语音
        function testVoice() {
            const text = "这是一条测试语音，订单12345，餐桌8号，红烧肉，制作中";
            speakText(text);
            document.getElementById('test-form').submit();
        }

        // 播放提醒
        function playAlert(id) {
            const alertItem = document.querySelector(`.alert-item[data-id="${id}"]`);
            const text = alertItem.getAttribute('data-text');
            speakText(text);

            // 视觉反馈
            alertItem.style.backgroundColor = '#f0f9ff';
            setTimeout(() => {
                alertItem.style.backgroundColor = '';
            }, 3000);
        }

        // 重播历史提醒
        function replayAlert(text) {
            speakText(text);
        }

        // 标记为已播放
        function markAsPlayed(id) {
            fetch('mark_played.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `id=${id}`
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        const alertItem = document.querySelector(`.alert-item[data-id="${id}"]`);
                        alertItem.remove();

                        // 如果没有更多提醒，显示空状态
                        const alertsList = document.getElementById('alerts-list');
                        if (alertsList && alertsList.children.length === 0) {
                            alertsList.innerHTML = '<div class="empty-state"><p>当前没有待播报的提醒</p></div>';
                        }

                        // 刷新页面以更新历史记录
                        setTimeout(() => {
                            location.reload();
                        }, 1000);
                    }
                });
        }

        // 文字转语音
        function speakText(text) {
            // 获取语音设置
            const voiceType = document.getElementById('voice_type').value;
            const voiceVolume = document.getElementById('voice_volume').value / 100;

            // 创建语音合成实例
            const synth = window.speechSynthesis;
            const utterance = new SpeechSynthesisUtterance(text);

            // 设置语音参数
            utterance.volume = voiceVolume;
            utterance.rate = 1.0;
            utterance.pitch = 1.0;
            utterance.lang = 'zh-CN';

            // 选择声音
            let voices = synth.getVoices();
            if (voices.length > 0) {
                // 尝试找到中文女声或男声
                let voice = null;
                if (voiceType === 'female') {
                    voice = voices.find(v => v.lang.includes('zh') && v.name.includes('女'));
                } else {
                    voice = voices.find(v => v.lang.includes('zh') && v.name.includes('男'));
                }

                // 如果没找到特定性别的声音，使用任何中文声音
                if (!voice) {
                    voice = voices.find(v => v.lang.includes('zh'));
                }

                // 如果还是没找到，使用默认声音
                if (voice) {
                    utterance.voice = voice;
                }
            }

            // 播放语音
            synth.speak(utterance);
        }

        // 自动播放功能
        let isPlaying = false;
        let currentAlertIndex = 0;
        const alertInterval = <?= $voice_interval; ?> * 1000; // 转换为毫秒

        function startAutoPlay() {
            if (!document.getElementById('voice_enabled').checked) return;

            const alerts = document.querySelectorAll('#alerts-list .alert-item');
            if (alerts.length === 0 || isPlaying) return;

            isPlaying = true;

            function playNext() {
                if (currentAlertIndex >= alerts.length) {
                    currentAlertIndex = 0;
                    isPlaying = false;
                    return;
                }

                const alert = alerts[currentAlertIndex];
                const alertId = alert.getAttribute('data-id');

                playAlert(alertId);

                // 标记为已播放
                setTimeout(() => {
                    markAsPlayed(alertId);
                    currentAlertIndex++;

                    // 延迟播放下一条
                    setTimeout(playNext, alertInterval);
                }, 2000);
            }

            playNext();
        }

        // 每隔一段时间检查是否有新提醒需要播放
        setInterval(startAutoPlay, 15000);

        // 页面加载后开始自动播放
        document.addEventListener('DOMContentLoaded', function() {
            // 确保语音合成API已加载
            window.speechSynthesis.getVoices();

            // 延迟几秒开始自动播放，给页面加载时间
            setTimeout(startAutoPlay, 3000);
        });

        // 确保语音合成API已加载
        if (speechSynthesis.onvoiceschanged !== undefined) {
            speechSynthesis.onvoiceschanged = function() {
                window.speechSynthesis.getVoices();
            };
        }
    </script>
</body>

</html>