<?php
require_once '../config.php';

// 创建kitchen_zones表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS kitchen_zones (
        zone_id INT AUTO_INCREMENT PRIMARY KEY,
        zone_name VARCHAR(50) NOT NULL,
        description TEXT,
        is_active TINYINT(1) DEFAULT 1,
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP
    )");

    $pdo->exec("CREATE TABLE IF NOT EXISTS zone_categories (
        id INT AUTO_INCREMENT PRIMARY KEY,
        zone_id INT,
        category VARCHAR(50) NOT NULL,
        FOREIGN KEY (zone_id) REFERENCES kitchen_zones(zone_id),
        UNIQUE KEY (zone_id, category)
    )");
} catch (Exception $e) {
    $error_message = "创建分区表失败: " . $e->getMessage();
}

// 处理分区操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        try {
            $pdo->beginTransaction();

            if ($_POST['action'] === 'add_zone') {
                $zone_name = $_POST['zone_name'] ?? '';
                $description = $_POST['description'] ?? '';
                $categories = $_POST['categories'] ?? [];

                if (empty($zone_name)) {
                    throw new Exception("分区名称不能为空");
                }

                if (empty($categories)) {
                    throw new Exception("请至少选择一个菜品类别");
                }

                // 检查分区名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM kitchen_zones WHERE zone_name = ?");
                $stmt->execute([$zone_name]);
                if ($stmt->fetchColumn() > 0) {
                    throw new Exception("分区名称 '$zone_name' 已存在");
                }

                // 添加新分区
                $stmt = $pdo->prepare("INSERT INTO kitchen_zones (zone_name, description) VALUES (?, ?)");
                $stmt->execute([$zone_name, $description]);
                $zone_id = $pdo->lastInsertId();

                // 添加分区类别关联
                $stmt = $pdo->prepare("INSERT INTO zone_categories (zone_id, category) VALUES (?, ?)");
                foreach ($categories as $category) {
                    $stmt->execute([$zone_id, $category]);
                }

                $success_message = "分区 '$zone_name' 已成功创建";
            } else if ($_POST['action'] === 'edit_zone') {
                $zone_id = $_POST['zone_id'] ?? 0;
                $zone_name = $_POST['zone_name'] ?? '';
                $description = $_POST['description'] ?? '';
                $categories = $_POST['categories'] ?? [];
                $is_active = isset($_POST['is_active']) ? 1 : 0;

                if (empty($zone_name)) {
                    throw new Exception("分区名称不能为空");
                }

                if (empty($categories)) {
                    throw new Exception("请至少选择一个菜品类别");
                }

                // 检查分区名称是否已存在（排除当前分区）
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM kitchen_zones WHERE zone_name = ? AND zone_id != ?");
                $stmt->execute([$zone_name, $zone_id]);
                if ($stmt->fetchColumn() > 0) {
                    throw new Exception("分区名称 '$zone_name' 已存在");
                }

                // 更新分区信息
                $stmt = $pdo->prepare("UPDATE kitchen_zones SET zone_name = ?, description = ?, is_active = ? WHERE zone_id = ?");
                $stmt->execute([$zone_name, $description, $is_active, $zone_id]);

                // 删除旧的分区类别关联
                $stmt = $pdo->prepare("DELETE FROM zone_categories WHERE zone_id = ?");
                $stmt->execute([$zone_id]);

                // 添加新的分区类别关联
                $stmt = $pdo->prepare("INSERT INTO zone_categories (zone_id, category) VALUES (?, ?)");
                foreach ($categories as $category) {
                    $stmt->execute([$zone_id, $category]);
                }

                $success_message = "分区 '$zone_name' 已成功更新";
            } else if ($_POST['action'] === 'delete_zone') {
                $zone_id = $_POST['zone_id'] ?? 0;

                // 获取分区名称
                $stmt = $pdo->prepare("SELECT zone_name FROM kitchen_zones WHERE zone_id = ?");
                $stmt->execute([$zone_id]);
                $zone_name = $stmt->fetchColumn();

                // 删除分区类别关联
                $stmt = $pdo->prepare("DELETE FROM zone_categories WHERE zone_id = ?");
                $stmt->execute([$zone_id]);

                // 删除分区
                $stmt = $pdo->prepare("DELETE FROM kitchen_zones WHERE zone_id = ?");
                $stmt->execute([$zone_id]);

                $success_message = "分区 '$zone_name' 已成功删除";
            }

            $pdo->commit();
        } catch (Exception $e) {
            $pdo->rollBack();
            $error_message = $e->getMessage();
        }
    }
}

// 获取所有分区
$stmt = $pdo->query("SELECT * FROM kitchen_zones ORDER BY zone_name");
$zones = $stmt->fetchAll();

// 获取所有分区的类别关联
$zone_categories = [];
if (!empty($zones)) {
    $zone_ids = array_column($zones, 'zone_id');
    $placeholders = str_repeat('?,', count($zone_ids) - 1) . '?';

    $stmt = $pdo->prepare("SELECT zone_id, category FROM zone_categories WHERE zone_id IN ($placeholders)");
    $stmt->execute($zone_ids);

    while ($row = $stmt->fetch()) {
        $zone_categories[$row['zone_id']][] = $row['category'];
    }
}

// 获取所有菜品类别
$stmt = $pdo->query("SELECT DISTINCT category FROM dishes ORDER BY category");
$categories = $stmt->fetchAll(PDO::FETCH_COLUMN);

// 获取未分配的类别
$unassigned_categories = [];
foreach ($categories as $category) {
    $is_assigned = false;
    foreach ($zone_categories as $zone_id => $zone_cats) {
        if (in_array($category, $zone_cats)) {
            $is_assigned = true;
            break;
        }
    }

    if (!$is_assigned) {
        $unassigned_categories[] = $category;
    }
}

// 获取各分区的订单统计
$zone_stats = [];
foreach ($zones as $zone) {
    if (empty($zone_categories[$zone['zone_id']])) continue;

    $zone_cats = $zone_categories[$zone['zone_id']];
    $placeholders = str_repeat('?,', count($zone_cats) - 1) . '?';

    // 获取待处理和进行中的订单数量
    $stmt = $pdo->prepare("SELECT COUNT(DISTINCT od.order_id) 
                          FROM order_details od 
                          JOIN dishes d ON od.dish_id = d.dish_id 
                          JOIN orders o ON od.order_id = o.order_id 
                          WHERE d.category IN ($placeholders) 
                          AND od.status IN ('等待中', '制作中')
                          AND o.status IN ('待支付', '进行中')");
    $stmt->execute($zone_cats);
    $pending_orders = $stmt->fetchColumn();

    // 获取待处理和进行中的菜品数量
    $stmt = $pdo->prepare("SELECT COUNT(*) 
                          FROM order_details od 
                          JOIN dishes d ON od.dish_id = d.dish_id 
                          JOIN orders o ON od.order_id = o.order_id 
                          WHERE d.category IN ($placeholders) 
                          AND od.status IN ('等待中', '制作中')
                          AND o.status IN ('待支付', '进行中')");
    $stmt->execute($zone_cats);
    $pending_dishes = $stmt->fetchColumn();

    $zone_stats[$zone['zone_id']] = [
        'pending_orders' => $pending_orders,
        'pending_dishes' => $pending_dishes
    ];
}

// 获取各分区的最近订单
$zone_orders = [];
foreach ($zones as $zone) {
    if (empty($zone_categories[$zone['zone_id']])) continue;

    $zone_cats = $zone_categories[$zone['zone_id']];
    $placeholders = str_repeat('?,', count($zone_cats) - 1) . '?';

    $stmt = $pdo->prepare("SELECT DISTINCT o.order_id, o.type, o.table_id, o.status, o.create_time 
                          FROM orders o 
                          JOIN order_details od ON o.order_id = od.order_id 
                          JOIN dishes d ON od.dish_id = d.dish_id 
                          WHERE d.category IN ($placeholders) 
                          AND o.status IN ('待支付', '进行中')
                          ORDER BY o.create_time DESC 
                          LIMIT 5");
    $stmt->execute($zone_cats);
    $zone_orders[$zone['zone_id']] = $stmt->fetchAll();
}
?>

<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>分区管理</title>
    <link rel="stylesheet" href="../order_manage/style.css">
    <style>
        .zone-container {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        @media (max-width: 992px) {
            .zone-container {
                grid-template-columns: 1fr;
            }
        }

        .zone-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
            overflow: hidden;
        }

        .zone-header {
            padding: 15px;
            background-color: #f8f9fa;
            border-bottom: 1px solid #eee;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .zone-name {
            font-size: 18px;
            font-weight: bold;
        }

        .zone-actions {
            display: flex;
            gap: 10px;
        }

        .zone-body {
            padding: 15px;
        }

        .zone-description {
            margin-bottom: 15px;
            color: #666;
        }

        .zone-categories {
            display: flex;
            flex-wrap: wrap;
            gap: 8px;
            margin-bottom: 15px;
        }

        .category-tag {
            background-color: #e1f5fe;
            color: #0288d1;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 12px;
        }

        .zone-stats {
            display: flex;
            gap: 20px;
            margin-bottom: 15px;
        }

        .stat-item {
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #3498db;
        }

        .stat-label {
            font-size: 12px;
            color: #666;
        }

        .zone-orders {
            margin-top: 15px;
        }

        .zone-orders h4 {
            margin-bottom: 10px;
            padding-bottom: 5px;
            border-bottom: 1px solid #eee;
        }

        .order-item {
            display: flex;
            justify-content: space-between;
            padding: 8px 0;
            border-bottom: 1px dashed #eee;
        }

        .order-item:last-child {
            border-bottom: none;
        }

        .order-id {
            font-weight: bold;
        }

        .order-type {
            display: inline-block;
            padding: 2px 6px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
            margin-left: 5px;
        }

        .order-type-堂食 {
            background-color: #3498db;
        }

        .order-type-外带 {
            background-color: #e67e22;
        }

        .order-type-外卖 {
            background-color: #9b59b6;
        }

        .order-time {
            color: #666;
            font-size: 12px;
        }

        .form-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 20px;
        }

        .form-title {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-group input[type="text"],
        .form-group textarea {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .form-group textarea {
            height: 100px;
            resize: vertical;
        }

        .category-checkboxes {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(150px, 1fr));
            gap: 10px;
        }

        .category-checkbox {
            display: flex;
            align-items: center;
        }

        .category-checkbox input[type="checkbox"] {
            margin-right: 5px;
        }

        .form-actions {
            display: flex;
            justify-content: flex-end;
            gap: 10px;
            margin-top: 20px;
        }

        .btn {
            padding: 8px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
        }

        .btn-danger {
            background-color: #e74c3c;
            color: white;
        }

        .btn-secondary {
            background-color: #95a5a6;
            color: white;
        }

        .btn-edit {
            background-color: #2ecc71;
            color: white;
            padding: 4px 8px;
            font-size: 12px;
        }

        .btn-delete {
            background-color: #e74c3c;
            color: white;
            padding: 4px 8px;
            font-size: 12px;
        }

        .status-tag {
            display: inline-block;
            padding: 2px 6px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
        }

        .status-active {
            background-color: #2ecc71;
        }

        .status-inactive {
            background-color: #e74c3c;
        }

        .unassigned-card {
            background-color: #fff3cd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .unassigned-title {
            font-weight: bold;
            margin-bottom: 10px;
            color: #856404;
        }
    </style>
</head>

<body>
    <h1>分区管理</h1>

    <?php if (isset($success_message)): ?>
        <div class="alert"><?= htmlspecialchars($success_message); ?></div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert error"><?= htmlspecialchars($error_message); ?></div>
    <?php endif; ?>

    <div class="form-card">
        <div class="form-title">添加新分区</div>
        <form method="post">
            <input type="hidden" name="action" value="add_zone">

            <div class="form-group">
                <label for="zone_name">分区名称</label>
                <input type="text" id="zone_name" name="zone_name" required placeholder="例如：热菜区、凉菜区、饮品区">
            </div>

            <div class="form-group">
                <label for="description">分区描述</label>
                <textarea id="description" name="description" placeholder="描述该分区的职责和特点"></textarea>
            </div>

            <div class="form-group">
                <label>分配菜品类别</label>
                <div class="category-checkboxes">
                    <?php foreach ($categories as $category): ?>
                        <div class="category-checkbox">
                            <input type="checkbox" name="categories[]" value="<?= htmlspecialchars($category); ?>" id="cat_<?= htmlspecialchars($category); ?>">
                            <label for="cat_<?= htmlspecialchars($category); ?>"><?= htmlspecialchars($category); ?></label>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">创建分区</button>
            </div>
        </form>
    </div>

    <?php if (!empty($unassigned_categories)): ?>
        <div class="unassigned-card">
            <div class="unassigned-title">未分配的菜品类别</div>
            <div class="zone-categories">
                <?php foreach ($unassigned_categories as $category): ?>
                    <span class="category-tag"><?= htmlspecialchars($category); ?></span>
                <?php endforeach; ?>
            </div>
        </div>
    <?php endif; ?>

    <?php if (empty($zones)): ?>
        <div class="empty-state">
            <p>当前没有定义的厨房分区</p>
            <p>请使用上方表单创建新的分区</p>
        </div>
    <?php else: ?>
        <div class="zone-container">
            <?php foreach ($zones as $zone): ?>
                <div class="zone-card">
                    <div class="zone-header">
                        <div>
                            <span class="zone-name"><?= htmlspecialchars($zone['zone_name']); ?></span>
                            <?php if ($zone['is_active']): ?>
                                <span class="status-tag status-active">活跃</span>
                            <?php else: ?>
                                <span class="status-tag status-inactive">停用</span>
                            <?php endif; ?>
                        </div>
                        <div class="zone-actions">
                            <button class="btn btn-edit" onclick="editZone(<?= $zone['zone_id']; ?>)">编辑</button>
                            <button class="btn btn-delete" onclick="deleteZone(<?= $zone['zone_id']; ?>, '<?= htmlspecialchars($zone['zone_name']); ?>')">删除</button>
                        </div>
                    </div>

                    <div class="zone-body">
                        <?php if (!empty($zone['description'])): ?>
                            <div class="zone-description"><?= nl2br(htmlspecialchars($zone['description'])); ?></div>
                        <?php endif; ?>

                        <div>
                            <strong>菜品类别:</strong>
                            <div class="zone-categories">
                                <?php if (isset($zone_categories[$zone['zone_id']])): ?>
                                    <?php foreach ($zone_categories[$zone['zone_id']] as $category): ?>
                                        <span class="category-tag"><?= htmlspecialchars($category); ?></span>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <span>未分配菜品类别</span>
                                <?php endif; ?>
                            </div>
                        </div>

                        <?php if (isset($zone_stats[$zone['zone_id']])): ?>
                            <div class="zone-stats">
                                <div class="stat-item">
                                    <div class="stat-value"><?= $zone_stats[$zone['zone_id']]['pending_orders']; ?></div>
                                    <div class="stat-label">待处理订单</div>
                                </div>
                                <div class="stat-item">
                                    <div class="stat-value"><?= $zone_stats[$zone['zone_id']]['pending_dishes']; ?></div>
                                    <div class="stat-label">待处理菜品</div>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if (isset($zone_orders[$zone['zone_id']]) && !empty($zone_orders[$zone['zone_id']])): ?>
                            <div class="zone-orders">
                                <h4>最近订单</h4>
                                <?php foreach ($zone_orders[$zone['zone_id']] as $order): ?>
                                    <div class="order-item">
                                        <div>
                                            <span class="order-id"><?= htmlspecialchars($order['order_id']); ?></span>
                                            <span class="order-type order-type-<?= htmlspecialchars($order['type']); ?>"><?= htmlspecialchars($order['type']); ?></span>
                                            <?php if ($order['table_id']): ?>
                                                <span>餐桌: <?= htmlspecialchars($order['table_id']); ?></span>
                                            <?php endif; ?>
                                        </div>
                                        <span class="order-time"><?= htmlspecialchars($order['create_time']); ?></span>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>

    <!-- 编辑分区表单（隐藏） -->
    <div id="edit-form-container" style="display: none; position: fixed; top: 0; left: 0; width: 100%; height: 100%; background-color: rgba(0,0,0,0.5); z-index: 1000;">
        <div style="position: absolute; top: 50%; left: 50%; transform: translate(-50%, -50%); width: 80%; max-width: 600px; background-color: white; border-radius: 8px; padding: 20px; max-height: 90vh; overflow-y: auto;">
            <h3>编辑分区</h3>
            <form method="post" id="edit-form">
                <input type="hidden" name="action" value="edit_zone">
                <input type="hidden" name="zone_id" id="edit_zone_id">

                <div class="form-group">
                    <label for="edit_zone_name">分区名称</label>
                    <input type="text" id="edit_zone_name" name="zone_name" required>
                </div>

                <div class="form-group">
                    <label for="edit_description">分区描述</label>
                    <textarea id="edit_description" name="description"></textarea>
                </div>

                <div class="form-group">
                    <label>分配菜品类别</label>
                    <div class="category-checkboxes" id="edit_categories">
                        <?php foreach ($categories as $category): ?>
                            <div class="category-checkbox">
                                <input type="checkbox" name="categories[]" value="<?= htmlspecialchars($category); ?>" id="edit_cat_<?= htmlspecialchars($category); ?>">
                                <label for="edit_cat_<?= htmlspecialchars($category); ?>"><?= htmlspecialchars($category); ?></label>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>

                <div class="form-group">
                    <label>
                        <input type="checkbox" name="is_active" id="edit_is_active" checked>
                        分区活跃状态
                    </label>
                </div>

                <div class="form-actions">
                    <button type="button" class="btn btn-secondary" onclick="closeEditForm()">取消</button>
                    <button type="submit" class="btn btn-primary">保存更改</button>
                </div>
            </form>
        </div>
    </div>

    <!-- 删除分区表单（隐藏） -->
    <form id="delete-form" method="post" style="display: none;">
        <input type="hidden" name="action" value="delete_zone">
        <input type="hidden" name="zone_id" id="delete_zone_id">
    </form>

    <script>
        // 编辑分区
        function editZone(zoneId) {
            // 获取分区数据
            const zones = <?= json_encode($zones); ?>;
            const zoneCategories = <?= json_encode($zone_categories); ?>;

            // 查找当前分区
            const zone = zones.find(z => z.zone_id == zoneId);
            if (!zone) return;

            // 填充表单
            document.getElementById('edit_zone_id').value = zone.zone_id;
            document.getElementById('edit_zone_name').value = zone.zone_name;
            document.getElementById('edit_description').value = zone.description || '';
            document.getElementById('edit_is_active').checked = zone.is_active == 1;

            // 重置所有类别复选框
            const categoryCheckboxes = document.querySelectorAll('#edit_categories input[type="checkbox"]');
            categoryCheckboxes.forEach(checkbox => {
                checkbox.checked = false;
            });

            // 选中分区的类别
            if (zoneCategories[zone.zone_id]) {
                zoneCategories[zone.zone_id].forEach(category => {
                    const checkbox = document.querySelector(`#edit_cat_${category}`);
                    if (checkbox) checkbox.checked = true;
                });
            }

            // 显示编辑表单
            document.getElementById('edit-form-container').style.display = 'block';
        }

        // 关闭编辑表单
        function closeEditForm() {
            document.getElementById('edit-form-container').style.display = 'none';
        }

        // 删除分区
        function deleteZone(zoneId, zoneName) {
            if (confirm(`确定要删除分区 "${zoneName}" 吗？此操作不可撤销。`)) {
                document.getElementById('delete_zone_id').value = zoneId;
                document.getElementById('delete-form').submit();
            }
        }

        // 点击编辑表单外部关闭
        document.getElementById('edit-form-container').addEventListener('click', function(event) {
            if (event.target === this) {
                closeEditForm();
            }
        });
    </script>
</body>

</html>