<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取会员ID
$member_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if (!$member_id) {
    $_SESSION['error'] = "无效的会员ID";
    header("Location: member_management.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $phone = $_POST['phone'] ?? '';
    $wechat_id = $_POST['wechat_id'] ?? null;
    $level = (int)($_POST['level'] ?? 1);
    $points = (int)($_POST['points'] ?? 0);

    // 验证手机号
    if (!preg_match('/^1[3-9]\d{9}$/', $phone)) {
        $_SESSION['error'] = "手机号格式不正确";
        header("Location: member_edit.php?id=$member_id");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 获取用户ID
        $stmt = $pdo->prepare("SELECT user_id FROM members WHERE member_id = ?");
        $stmt->execute([$member_id]);
        $user_id = $stmt->fetchColumn();

        if (!$user_id) {
            throw new Exception("找不到该会员");
        }

        // 更新用户信息
        $stmt = $pdo->prepare("
            UPDATE users 
            SET phone = ?, wechat_id = ?
            WHERE user_id = ?
        ");
        $stmt->execute([$phone, $wechat_id, $user_id]);

        // 更新会员信息
        $stmt = $pdo->prepare("
            UPDATE members 
            SET level = ?, points = ?
            WHERE member_id = ?
        ");
        $stmt->execute([$level, $points, $member_id]);

        $pdo->commit();

        // 记录日志
        log_action('action', '更新会员', "更新会员ID: $member_id", 'update');

        $_SESSION['success'] = "会员信息更新成功";
        header("Location: member_management.php");
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "会员更新失败: " . $e->getMessage();
        header("Location: member_edit.php?id=$member_id");
        exit;
    }
}

// 获取会员信息
try {
    $stmt = $pdo->prepare("
        SELECT 
            m.member_id,
            u.phone,
            u.wechat_id,
            m.level,
            m.points,
            DATE_FORMAT(m.join_date, '%Y-%m-%d') AS join_date
        FROM members m
        JOIN users u ON m.user_id = u.user_id
        WHERE m.member_id = ?
    ");
    $stmt->execute([$member_id]);
    $member = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$member) {
        $_SESSION['error'] = "找不到该会员";
        header("Location: member_management.php");
        exit;
    }
} catch (PDOException $e) {
    $_SESSION['error'] = "获取会员信息失败: " . $e->getMessage();
    header("Location: member_management.php");
    exit;
}

// 会员等级映射
$levelMap = [
    1 => '普通会员',
    2 => '银卡会员',
    3 => '金卡会员',
    4 => '钻石会员'
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>编辑会员</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>编辑会员信息</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="card">
            <h3>会员信息</h3>
            <form method="POST" action="member_edit.php?id=<?= $member_id ?>">
                <div class="form-group">
                    <label>会员ID</label>
                    <input type="text" value="<?= $member['member_id'] ?>" readonly>
                </div>

                <div class="form-group">
                    <label>注册日期</label>
                    <input type="text" value="<?= $member['join_date'] ?>" readonly>
                </div>

                <div class="form-group">
                    <label>手机号</label>
                    <input type="text" name="phone" value="<?= htmlspecialchars($member['phone']) ?>" required
                        pattern="1[3-9]\d{9}"
                        title="请输入正确的手机号码">
                </div>

                <div class="form-group">
                    <label>微信ID</label>
                    <input type="text" name="wechat_id" value="<?= htmlspecialchars($member['wechat_id'] ?? '') ?>">
                </div>

                <div class="form-group">
                    <label>会员等级</label>
                    <select name="level" required>
                        <?php foreach ($levelMap as $value => $label): ?>
                            <option value="<?= $value ?>" <?= $member['level'] == $value ? 'selected' : '' ?>>
                                <?= $label ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>积分</label>
                    <input type="number" name="points" value="<?= $member['points'] ?>" min="0">
                </div>

                <div class="form-group">
                    <button type="submit" class="btn-primary">保存更改</button>
                    <a href="member_management.php" class="btn-cancel">取消</a>
                </div>
            </form>
        </div>
    </div>
</body>

</html>