<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理积分调整
if (isset($_POST['adjust_points'])) {
    $member_id = (int)$_POST['member_id'];
    $points = (int)$_POST['points'];
    $reason = $_POST['reason'];

    if ($points == 0) {
        $_SESSION['error'] = "积分调整值不能为0";
        header("Location: points_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 获取当前积分
        $stmt = $pdo->prepare("SELECT points FROM members WHERE member_id = ?");
        $stmt->execute([$member_id]);
        $current_points = (int)$stmt->fetchColumn();

        // 计算新积分
        $new_points = $current_points + $points;

        // 确保积分不为负数
        if ($new_points < 0) {
            throw new Exception("积分调整后不能为负数");
        }

        // 更新积分
        $stmt = $pdo->prepare("UPDATE members SET points = ? WHERE member_id = ?");
        $stmt->execute([$new_points, $member_id]);

        // 记录积分变动
        $action = $points > 0 ? '增加积分' : '扣减积分';
        log_action('action', $action, "会员ID: $member_id, 变动: $points, 原因: $reason", 'update');

        $pdo->commit();
        $_SESSION['success'] = "积分调整成功";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "积分调整失败: " . $e->getMessage();
    }

    header("Location: points_management.php");
    exit;
}

// 获取所有会员及其积分
$members = $pdo->query("
    SELECT 
        m.member_id,
        u.phone,
        u.wechat_id,
        m.level,
        m.points,
        DATE_FORMAT(m.join_date, '%Y-%m-%d') AS join_date
    FROM members m
    JOIN users u ON m.user_id = u.user_id
    ORDER BY m.points DESC
")->fetchAll();

// 会员等级映射
$levelMap = [
    1 => '普通会员',
    2 => '银卡会员',
    3 => '金卡会员',
    4 => '钻石会员'
];

// 积分规则（实际应用中可能从数据库获取）
$pointRules = [
    ['action' => '消费', 'rule' => '每消费1元获得1积分'],
    ['action' => '评价', 'rule' => '评价订单获得10积分'],
    ['action' => '分享', 'rule' => '分享到朋友圈获得5积分'],
    ['action' => '生日', 'rule' => '生日当月额外获得100积分'],
    ['action' => '推荐', 'rule' => '推荐新用户注册获得50积分']
];

// 积分兑换项目（实际应用中可能从数据库获取）
$exchangeItems = [
    ['name' => '5元代金券', 'points' => 500, 'description' => '可用于抵扣任意消费'],
    ['name' => '10元代金券', 'points' => 900, 'description' => '可用于抵扣任意消费'],
    ['name' => '免费甜点', 'points' => 300, 'description' => '可兑换指定甜点一份'],
    ['name' => '免费饮料', 'points' => 200, 'description' => '可兑换指定饮料一杯'],
    ['name' => '生日特权', 'points' => 1000, 'description' => '生日当天消费享受额外9折优惠']
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>积分管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>会员积分管理</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 积分规则 -->
        <div class="card">
            <h3>积分规则</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>行为</th>
                        <th>积分规则</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($pointRules as $rule): ?>
                        <tr>
                            <td><?= htmlspecialchars($rule['action']) ?></td>
                            <td><?= htmlspecialchars($rule['rule']) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 积分兑换项目 -->
        <div class="card">
            <h3>积分兑换项目</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>兑换项目</th>
                        <th>所需积分</th>
                        <th>说明</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($exchangeItems as $item): ?>
                        <tr>
                            <td><?= htmlspecialchars($item['name']) ?></td>
                            <td><?= $item['points'] ?></td>
                            <td><?= htmlspecialchars($item['description']) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 积分调整 -->
        <div class="card">
            <h3>积分调整</h3>
            <form method="POST" action="points_management.php">
                <div class="form-group">
                    <label>选择会员</label>
                    <select name="member_id" required>
                        <?php foreach ($members as $member): ?>
                            <option value="<?= $member['member_id'] ?>">
                                <?= htmlspecialchars($member['phone']) ?>
                                (<?= $levelMap[$member['level']] ?>, 当前积分: <?= $member['points'] ?>)
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>积分变动</label>
                    <input type="number" name="points" required>
                    <small>正数表示增加积分，负数表示扣减积分</small>
                </div>

                <div class="form-group">
                    <label>调整原因</label>
                    <input type="text" name="reason" required>
                </div>

                <button type="submit" name="adjust_points" class="btn-primary">提交调整</button>
            </form>
        </div>

        <!-- 会员积分列表 -->
        <div class="card">
            <h3>会员积分列表</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>会员ID</th>
                        <th>手机号</th>
                        <th>会员等级</th>
                        <th>当前积分</th>
                        <th>注册日期</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($members as $member): ?>
                        <tr>
                            <td><?= $member['member_id'] ?></td>
                            <td><?= htmlspecialchars($member['phone']) ?></td>
                            <td><?= $levelMap[$member['level']] ?? '未知等级' ?></td>
                            <td><?= $member['points'] ?></td>
                            <td><?= $member['join_date'] ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>