<?php
session_start();
require_once '../config.php';

// 权限验证
if (!isset($_SESSION['employee_id'])) {
    header("Location: ../login.php");
    exit;
}

// 创建推荐记录表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS referrals (
        referral_id INT AUTO_INCREMENT PRIMARY KEY,
        referrer_id INT NOT NULL,
        referred_id INT NOT NULL,
        status ENUM('待消费', '已奖励', '已取消') DEFAULT '待消费',
        points_awarded INT DEFAULT 0,
        created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
        completed_at DATETIME,
        FOREIGN KEY (referrer_id) REFERENCES members(member_id),
        FOREIGN KEY (referred_id) REFERENCES members(member_id)
    )");
} catch (PDOException $e) {
    error_log("创建推荐记录表失败: " . $e->getMessage());
}

// 处理推荐奖励发放
if (isset($_GET['reward'])) {
    $referral_id = (int)$_GET['reward'];

    try {
        $pdo->beginTransaction();

        // 获取推荐记录
        $stmt = $pdo->prepare("
            SELECT referrer_id, status FROM referrals WHERE referral_id = ?
        ");
        $stmt->execute([$referral_id]);
        $referral = $stmt->fetch();

        if (!$referral) {
            throw new Exception("找不到该推荐记录");
        }

        if ($referral['status'] != '待消费') {
            throw new Exception("该推荐记录已处理");
        }

        // 奖励积分（假设奖励50积分）
        $reward_points = 50;

        // 更新会员积分
        $stmt = $pdo->prepare("
            UPDATE members 
            SET points = points + ? 
            WHERE member_id = ?
        ");
        $stmt->execute([$reward_points, $referral['referrer_id']]);

        // 更新推荐记录状态
        $stmt = $pdo->prepare("
            UPDATE referrals 
            SET status = '已奖励', 
                points_awarded = ?,
                completed_at = NOW()
            WHERE referral_id = ?
        ");
        $stmt->execute([$reward_points, $referral_id]);

        $pdo->commit();

        // 记录日志
        log_action('action', '发放推荐奖励', "推荐ID: $referral_id, 奖励积分: $reward_points", 'update');

        $_SESSION['success'] = "推荐奖励发放成功";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "奖励发放失败: " . $e->getMessage();
    }

    header("Location: referral_program.php");
    exit;
}

// 处理推荐记录取消
if (isset($_GET['cancel'])) {
    $referral_id = (int)$_GET['cancel'];

    try {
        $pdo->beginTransaction();

        // 获取推荐记录
        $stmt = $pdo->prepare("
            SELECT status FROM referrals WHERE referral_id = ?
        ");
        $stmt->execute([$referral_id]);
        $status = $stmt->fetchColumn();

        if (!$status) {
            throw new Exception("找不到该推荐记录");
        }

        if ($status != '待消费') {
            throw new Exception("只能取消待消费状态的推荐记录");
        }

        // 更新推荐记录状态
        $stmt = $pdo->prepare("
            UPDATE referrals 
            SET status = '已取消',
                completed_at = NOW()
            WHERE referral_id = ?
        ");
        $stmt->execute([$referral_id]);

        $pdo->commit();

        // 记录日志
        log_action('action', '取消推荐记录', "推荐ID: $referral_id", 'update');

        $_SESSION['success'] = "推荐记录已取消";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "取消失败: " . $e->getMessage();
    }

    header("Location: referral_program.php");
    exit;
}

// 获取所有推荐记录
try {
    $referrals = $pdo->query("
        SELECT 
            r.referral_id,
            r.referrer_id,
            r.referred_id,
            r.status,
            r.points_awarded,
            DATE_FORMAT(r.created_at, '%Y-%m-%d') AS created_date,
            DATE_FORMAT(r.completed_at, '%Y-%m-%d') AS completed_date,
            u1.phone AS referrer_phone,
            u2.phone AS referred_phone
        FROM referrals r
        JOIN members m1 ON r.referrer_id = m1.member_id
        JOIN members m2 ON r.referred_id = m2.member_id
        JOIN users u1 ON m1.user_id = u1.user_id
        JOIN users u2 ON m2.user_id = u2.user_id
        ORDER BY r.created_at DESC
    ")->fetchAll();
} catch (PDOException $e) {
    $referrals = [];
    $_SESSION['error'] = "获取推荐记录失败: " . $e->getMessage();
}

// 获取所有会员
$members = $pdo->query("
    SELECT 
        m.member_id,
        u.phone
    FROM members m
    JOIN users u ON m.user_id = u.user_id
    ORDER BY u.phone
")->fetchAll();

// 推荐状态映射
$statusMap = [
    '待消费' => '<span class="status-tag pending">待消费</span>',
    '已奖励' => '<span class="status-tag completed">已奖励</span>',
    '已取消' => '<span class="status-tag cancelled">已取消</span>'
];

// 推荐规则（实际应用中可能从数据库获取）
$referralRules = [
    ['rule' => '推荐好友注册成为会员，获得50积分奖励'],
    ['rule' => '被推荐好友首次消费后，推荐人获得奖励'],
    ['rule' => '每月推荐3位以上好友，额外获得100积分'],
    ['rule' => '推荐好友消费满100元，推荐人获得10元代金券'],
    ['rule' => '被推荐好友也可获得新人优惠券一张']
];
?>

<!DOCTYPE html>
<html>

<head>
    <title>推荐有奖计划</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>推荐有奖计划</h2>

        <!-- 消息提示 -->
        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert error"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 推荐规则 -->
        <div class="card">
            <h3>推荐规则</h3>
            <ul class="rule-list">
                <?php foreach ($referralRules as $rule): ?>
                    <li><?= htmlspecialchars($rule['rule']) ?></li>
                <?php endforeach; ?>
            </ul>
        </div>

        <!-- 添加推荐记录 -->
        <div class="card">
            <h3>添加推荐记录</h3>
            <form method="POST" action="referral_create.php">
                <div class="form-group">
                    <label>推荐人</label>
                    <select name="referrer_id" required>
                        <?php foreach ($members as $member): ?>
                            <option value="<?= $member['member_id'] ?>">
                                <?= htmlspecialchars($member['phone']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>被推荐人</label>
                    <select name="referred_id" required>
                        <?php foreach ($members as $member): ?>
                            <option value="<?= $member['member_id'] ?>">
                                <?= htmlspecialchars($member['phone']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn-primary">添加推荐记录</button>
            </form>
        </div>

        <!-- 推荐记录列表 -->
        <div class="card">
            <h3>推荐记录</h3>
            <?php if (empty($referrals)): ?>
                <p class="empty-state">暂无推荐记录</p>
            <?php else: ?>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>推荐人</th>
                            <th>被推荐人</th>
                            <th>状态</th>
                            <th>奖励积分</th>
                            <th>创建日期</th>
                            <th>完成日期</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($referrals as $referral): ?>
                            <tr>
                                <td><?= $referral['referral_id'] ?></td>
                                <td><?= htmlspecialchars($referral['referrer_phone']) ?></td>
                                <td><?= htmlspecialchars($referral['referred_phone']) ?></td>
                                <td><?= $statusMap[$referral['status']] ?? $referral['status'] ?></td>
                                <td><?= $referral['points_awarded'] ?></td>
                                <td><?= $referral['created_date'] ?></td>
                                <td><?= $referral['completed_date'] ?? '-' ?></td>
                                <td>
                                    <?php if ($referral['status'] == '待消费'): ?>
                                        <a href="referral_program.php?reward=<?= $referral['referral_id'] ?>"
                                            class="btn-edit">发放奖励</a>
                                        <a href="referral_program.php?cancel=<?= $referral['referral_id'] ?>"
                                            onclick="return confirm('确认取消该推荐记录？')"
                                            class="btn-delete">取消</a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <style>
        .rule-list {
            padding-left: 20px;
            margin: 15px 0;
        }

        .rule-list li {
            margin-bottom: 10px;
            line-height: 1.5;
        }

        .status-tag {
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 12px;
            color: white;
        }

        .pending {
            background-color: #f39c12;
        }

        .completed {
            background-color: #27ae60;
        }

        .cancelled {
            background-color: #e74c3c;
        }
    </style>
</body>

</html>