<?php
require '../config.php';

// 获取用户常点菜品（基于所有历史订单统计，取前 5 个）
$stmt = $pdo->query("SELECT d.dish_id, d.name, d.price, d.stock, COUNT(od.dish_id) AS order_count 
                     FROM dishes d 
                     LEFT JOIN order_details od ON d.dish_id = od.dish_id 
                     GROUP BY d.dish_id 
                     ORDER BY order_count DESC 
                     LIMIT 5");
$recommended_dishes = $stmt->fetchAll();

// 获取所有可用菜品（库存大于 0）
$stmt = $pdo->query("SELECT dish_id, name, price, stock FROM dishes WHERE stock > 0 ORDER BY name");
$dishes = $stmt->fetchAll();

// 获取所有空闲的餐桌
$stmt = $pdo->query("SELECT table_id FROM dining_tables WHERE status = '空闲' ORDER BY table_id");
$tables = $stmt->fetchAll();

$message = "";

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $user_id = $_POST['user_id'] ?? null;
    $items = $_POST['items'] ?? [];
    $pickup_option = $_POST['pickup_option'] ?? '';  // immediate 或 scheduled
    $pickup_time_input = $_POST['pickup_time'] ?? '';
    $payment_method = $_POST['payment_method'] ?? '';
    $order_type = $_POST['order_type'] ?? '外卖';  // 新增：订单类型
    $table_id = ($order_type === '堂食') ? ($_POST['table_id'] ?? null) : null;
    $address = ($order_type === '外卖') ? ($_POST['address'] ?? '') : '';

    // 根据取餐方式确定取餐时间
    if ($pickup_option === 'immediate') {
        $pickup_time = date('Y-m-d H:i:s');
    } else {
        if (empty($pickup_time_input)) {
            $message = "<div class='alert alert-danger'>请选择预约取餐时间</div>";
        }
        $pickup_time = $pickup_time_input;
    }

    // 验证必填字段
    if (!$user_id || empty($items) || !$payment_method || empty($pickup_time)) {
        $message = "<div class='alert alert-danger'>请填写所有必要信息（用户ID、取餐时间、支付方式）并至少点一道菜</div>";
    } else if ($order_type === '堂食' && !$table_id) {
        $message = "<div class='alert alert-danger'>堂食请选择餐桌</div>";
    } else if ($order_type === '外卖' && empty($address)) {
        $message = "<div class='alert alert-danger'>外卖请填写配送地址</div>";
    } else {
        try {
            $pdo->beginTransaction();

            // 生成唯一订单ID
            $order_id = date('YmdHis') . rand(1000, 9999);

            // 计算订单总价
            $total_amount = 0;
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();
                    $total_amount += $dish['price'] * $qty;
                }
            }

            // 生成支付记录（状态直接置为 '已支付'，模拟支付成功）
            // 为防止超长，这里生成的支付ID格式调整为：P+ymdHis+随机3位
            $payment_id = "P" . date('ymdHis') . rand(100, 999);
            $stmt = $pdo->prepare("INSERT INTO payments (payment_id, order_id, amount, method, status, pay_time) VALUES (?, ?, ?, ?, '已支付', NOW())");
            $stmt->execute([$payment_id, $order_id, $total_amount, $payment_method]);

            // 创建订单
            // 数据库 orders 表的 type 字段用于存放用餐类型
            // 订单状态更新为 '进行中' 表示订单已在处理中（符合 ENUM 定义：'待支付','进行中','已完成','已取消'）
            if ($order_type === '堂食') {
                $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, table_id, type, status, total_amount, create_time, payment_time) VALUES (?, ?, ?, ?, '进行中', ?, NOW(), NOW())");
                $stmt->execute([$order_id, $user_id, $table_id, $order_type, $total_amount]);

                // 更新餐桌状态为用餐中
                $stmt = $pdo->prepare("UPDATE dining_tables SET status = '用餐中' WHERE table_id = ?");
                $stmt->execute([$table_id]);
            } else {
                $stmt = $pdo->prepare("INSERT INTO orders (order_id, user_id, type, status, total_amount, create_time, payment_time) VALUES (?, ?, ?, '进行中', ?, NOW(), NOW())");
                $stmt->execute([$order_id, $user_id, $order_type, $total_amount]);
            }

            // 创建订单详情并更新库存
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();

                    $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                    $stmt->execute([$order_id, $dish_id, $qty, $dish['price']]);

                    // 更新库存
                    $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                    $stmt->execute([$qty, $dish_id]);
                }
            }

            $pdo->commit();
            $log_message = "用户ID: $user_id, 订单ID: $order_id, 取餐时间: $pickup_time, 支付方式: $payment_method, 订单类型: $order_type";
            if ($order_type === '堂食') {
                $log_message .= ", 餐桌ID: $table_id";
            } else if ($order_type === '外卖') {
                $log_message .= ", 配送地址: $address";
            }
            log_action('订单', 'APP预点餐', $log_message);
            $message = "<div class='alert alert-success'>支付成功，订单已提交！3 秒后返回...</div>";
            header("refresh:3;url=" . $_SERVER['PHP_SELF']);
            exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $message = "<div class='alert alert-danger'>提交失败: " . htmlspecialchars($e->getMessage()) . "</div>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>APP 预点餐</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 单选按钮与标签对齐的样式 */
        .radio-group {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
        }

        .radio-group label {
            display: flex;
            align-items: center;
            margin-right: 15px;
        }

        .radio-group input[type="radio"] {
            margin-right: 5px;
            vertical-align: middle;
        }

        .option-label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
        }
    </style>
    <script>
        // 切换取餐方式的显示
        function togglePickupTime() {
            var pickupOption = document.querySelector('input[name=\"pickup_option\"]:checked').value;
            var pickupTimeDiv = document.getElementById('pickup_time_div');
            if (pickupOption === 'scheduled') {
                pickupTimeDiv.style.display = 'block';
            } else {
                pickupTimeDiv.style.display = 'none';
            }
        }

        // 切换订单类型的显示
        function toggleOrderType() {
            var orderType = document.querySelector('input[name=\"order_type\"]:checked').value;
            var tableDiv = document.getElementById('table_id_div');
            var addressDiv = document.getElementById('address_div');

            if (orderType === '堂食') {
                tableDiv.style.display = 'block';
                addressDiv.style.display = 'none';
            } else if (orderType === '外卖') {
                tableDiv.style.display = 'none';
                addressDiv.style.display = 'block';
            } else { // 外带
                tableDiv.style.display = 'none';
                addressDiv.style.display = 'none';
            }
        }

        window.onload = function() {
            togglePickupTime();
            toggleOrderType();
        };
    </script>
</head>

<body>
    <div class="container">
        <h2>APP 预点餐</h2>
        <?= $message; ?>
        <form method="post">
            <?= csrf_field(); ?>
            <div class="form-group">
                <label for="user_id">用户 ID</label>
                <input type="text" name="user_id" id="user_id" required>
            </div>

            <div class="form-group">
                <label class="option-label">取餐方式</label>
                <div class="radio-group">
                    <label><input type="radio" name="pickup_option" value="immediate" onclick="togglePickupTime()" checked> 立即取餐</label>
                    <label><input type="radio" name="pickup_option" value="scheduled" onclick="togglePickupTime()"> 预约取餐</label>
                </div>
            </div>

            <div class="form-group">
                <label class="option-label">订单类型</label>
                <div class="radio-group">
                    <label><input type="radio" name="order_type" value="堂食" onclick="toggleOrderType()" checked> 堂食</label>
                    <label><input type="radio" name="order_type" value="外带" onclick="toggleOrderType()"> 外带</label>
                    <label><input type="radio" name="order_type" value="外卖" onclick="toggleOrderType()"> 外卖</label>
                </div>
            </div>

            <div class="form-group" id="table_id_div">
                <label for="table_id">选择餐桌</label>
                <select name="table_id" id="table_id">
                    <option value="">请选择餐桌</option>
                    <?php foreach ($tables as $table): ?>
                        <option value="<?= $table['table_id']; ?>">餐桌 <?= $table['table_id']; ?></option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group" id="address_div" style="display:none;">
                <label for="address">配送地址</label>
                <input type="text" name="address" id="address" placeholder="请输入详细配送地址">
            </div>

            <div class="form-group" id="pickup_time_div" style="display:none;">
                <label for="pickup_time">选择预约取餐时间</label>
                <input type="datetime-local" name="pickup_time" id="pickup_time">
            </div>

            <div class="form-group">
                <label>推荐菜品</label>
                <div class="menu-grid">
                    <?php foreach ($recommended_dishes as $dish): ?>
                        <div class="dish-card">
                            <p><strong><?= htmlspecialchars($dish['name']); ?></strong></p>
                            <p>￥<?= number_format($dish['price'], 2); ?> / 份</p>
                            <p>库存: <?= $dish['stock']; ?> 份</p>
                            <input type="number" name="items[<?= $dish['dish_id']; ?>]" min="0" max="<?= $dish['stock']; ?>" value="0">
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-group">
                <label>选择其他菜品</label>
                <div class="menu-grid">
                    <?php foreach ($dishes as $dish): ?>
                        <div class="dish-card">
                            <p><strong><?= htmlspecialchars($dish['name']); ?></strong></p>
                            <p>￥<?= number_format($dish['price'], 2); ?> / 份</p>
                            <p>库存: <?= $dish['stock']; ?> 份</p>
                            <input type="number" name="items[<?= $dish['dish_id']; ?>]" min="0" max="<?= $dish['stock']; ?>" value="0">
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-group">
                <label for="payment_method">选择支付方式</label>
                <select name="payment_method" id="payment_method" required>
                    <option value="">请选择</option>
                    <option value="支付宝">支付宝</option>
                    <option value="微信">微信</option>
                    <option value="会员卡">会员卡</option>
                </select>
            </div>

            <div class="form-group">
                <button type="submit">支付并提交订单</button>
            </div>
        </form>
    </div>
</body>

</html>