<?php
require '../config.php';

// 获取桌号列表
$stmt = $pdo->query("SELECT table_id FROM dining_tables ORDER BY table_id");
$tables = $stmt->fetchAll();

// 获取菜品列表（库存大于 0）
$stmt = $pdo->query("SELECT dish_id, name, price, stock FROM dishes WHERE stock > 0 ORDER BY name");
$dishes = $stmt->fetchAll();

$message = "";

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $table_id = $_POST['table_id'] ?? null;
    $items = $_POST['items'] ?? [];
    $dining_type = $_POST['dining_type'] ?? '堂食';  // 这里取值应为“堂食”或“外带”
    $payment_method = $_POST['payment_method'] ?? '';

    if (!$table_id || empty($items) || !$payment_method) {
        $message = "<div class='alert alert-danger'>请选择桌号、支付方式，并至少点一道菜</div>";
    } else {
        try {
            $pdo->beginTransaction();

            // 生成唯一订单ID
            $order_id = date('YmdHis') . rand(1000, 9999);

            // 计算订单总价
            $total_amount = 0;
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();
                    $total_amount += $dish['price'] * $qty;
                }
            }

            // 模拟支付成功：创建支付记录（状态直接置为 '已支付'）
            // 为防止超长，这里生成的支付ID格式调整为：P+ymdHis+随机3位
            $payment_id = "P" . date('ymdHis') . rand(100, 999);
            $stmt = $pdo->prepare("INSERT INTO payments (payment_id, order_id, amount, method, status, pay_time) VALUES (?, ?, ?, ?, '已支付', NOW())");
            $stmt->execute([$payment_id, $order_id, $total_amount, $payment_method]);

            // 创建订单，状态设为 '待处理'
            // 注意：数据库中的订单表使用字段名 type 来表示用餐方式
            $stmt = $pdo->prepare("INSERT INTO orders (order_id, table_id, type, status, total_amount, create_time, payment_time) VALUES (?, ?, ?, '待支付', ?, NOW(), NOW())");
            $stmt->execute([$order_id, $table_id, $dining_type, $total_amount]);

            // 创建订单详情并更新库存
            foreach ($items as $dish_id => $qty) {
                if ($qty > 0) {
                    // 获取菜品价格
                    $stmt = $pdo->prepare("SELECT price FROM dishes WHERE dish_id = ?");
                    $stmt->execute([$dish_id]);
                    $dish = $stmt->fetch();

                    $stmt = $pdo->prepare("INSERT INTO order_details (order_id, dish_id, quantity, price, status) VALUES (?, ?, ?, ?, '等待中')");
                    $stmt->execute([$order_id, $dish_id, $qty, $dish['price']]);

                    // 更新库存
                    $stmt = $pdo->prepare("UPDATE dishes SET stock = stock - ? WHERE dish_id = ?");
                    $stmt->execute([$qty, $dish_id]);
                }
            }

            $pdo->commit();
            log_action('订单', '支付并创建订单', "桌号ID: $table_id, 订单ID: $order_id, 支付方式: $payment_method, 用餐方式: $dining_type");
            $message = "<div class='alert alert-success'>支付成功，订单提交成功！3 秒后返回...</div>";
            header("refresh:3;url=" . $_SERVER['PHP_SELF']);
            exit;
        } catch (Exception $e) {
            $pdo->rollBack();
            $message = "<div class='alert alert-danger'>提交失败: " . htmlspecialchars($e->getMessage()) . "</div>";
            header("refresh:3;url=" . $_SERVER['PHP_SELF']);
            exit;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>自助机点餐</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>自助机点餐</h2>
        <?= $message; ?>
        <form method="post">
            <?= csrf_field(); ?>
            <div class="form-group">
                <label for="table_id">选择桌号</label>
                <select name="table_id" id="table_id" required>
                    <option value="">请选择</option>
                    <?php foreach ($tables as $table): ?>
                        <option value="<?= $table['table_id']; ?>">
                            <?= "桌号 " . htmlspecialchars($table['table_id']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label>选择菜品</label>
                <div class="menu-grid">
                    <?php foreach ($dishes as $dish): ?>
                        <div class="dish-card">
                            <p><strong><?= htmlspecialchars($dish['name']); ?></strong></p>
                            <p>￥<?= number_format($dish['price'], 2); ?> / 份</p>
                            <p>库存: <?= $dish['stock']; ?> 份</p>
                            <input type="number" name="items[<?= $dish['dish_id']; ?>]" min="0" max="<?= $dish['stock']; ?>" value="0">
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-group">
                <label>选择用餐方式</label>
                <select name="dining_type" required>
                    <option value="堂食">堂食</option>
                    <option value="外带">外带</option>
                </select>
            </div>

            <div class="form-group">
                <label for="payment_method">选择支付方式</label>
                <select name="payment_method" id="payment_method" required>
                    <option value="">请选择</option>
                    <option value="支付宝">支付宝</option>
                    <option value="微信">微信</option>
                    <option value="会员卡">会员卡</option>
                </select>
            </div>

            <div class="form-group">
                <button type="submit">支付并提交订单</button>
            </div>
        </form>
    </div>
</body>

</html>