<?php
require_once '../config.php';

// 创建预付定金表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS deposits (
        deposit_id VARCHAR(20) PRIMARY KEY,
        user_id INT,
        amount DECIMAL(10,2) NOT NULL,
        payment_method ENUM('微信','支付宝','银行卡','会员卡','现金') NOT NULL,
        status ENUM('已支付','已使用','已退款') DEFAULT '已支付',
        reservation_time DATETIME NOT NULL,
        table_id INT,
        people_count INT,
        notes TEXT,
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        update_time DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (user_id) REFERENCES users(user_id),
        FOREIGN KEY (table_id) REFERENCES dining_tables(table_id)
    )");
} catch (Exception $e) {
    $error_message = "创建预付定金表失败: " . $e->getMessage();
}

// 处理定金操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        if ($_POST['action'] === 'add_deposit') {
            $user_id = $_POST['user_id'] ?? null;
            $phone = $_POST['phone'] ?? '';
            $amount = $_POST['amount'] ?? 0;
            $payment_method = $_POST['payment_method'] ?? '';
            $reservation_time = $_POST['reservation_time'] ?? '';
            $table_id = $_POST['table_id'] ?? null;
            $people_count = $_POST['people_count'] ?? 1;
            $notes = $_POST['notes'] ?? '';

            try {
                $pdo->beginTransaction();

                // 如果只提供了手机号，尝试查找或创建用户
                if (!$user_id && $phone) {
                    $stmt = $pdo->prepare("SELECT user_id FROM users WHERE phone = ?");
                    $stmt->execute([$phone]);
                    $user = $stmt->fetch();

                    if ($user) {
                        $user_id = $user['user_id'];
                    } else {
                        // 创建新用户
                        $stmt = $pdo->prepare("INSERT INTO users (phone, reg_date) VALUES (?, NOW())");
                        $stmt->execute([$phone]);
                        $user_id = $pdo->lastInsertId();
                    }
                }

                // 生成定金ID
                $deposit_id = 'DEP' . date('YmdHis') . rand(100, 999);

                // 添加定金记录
                $stmt = $pdo->prepare("INSERT INTO deposits (deposit_id, user_id, amount, payment_method, reservation_time, table_id, people_count, notes) 
                                      VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$deposit_id, $user_id, $amount, $payment_method, $reservation_time, $table_id, $people_count, $notes]);

                // 更新桌台状态为已预订
                if ($table_id) {
                    $stmt = $pdo->prepare("UPDATE dining_tables SET status = '已预订' WHERE table_id = ?");
                    $stmt->execute([$table_id]);
                }

                // 记录系统日志
                $stmt = $pdo->prepare("INSERT INTO system_logs (log_type, related_id, action_type, description) 
                                      VALUES ('payment', ?, '预付定金', ?)");
                $stmt->execute([$deposit_id, "用户ID {$user_id} 支付了 {$amount} 元定金，预约时间: {$reservation_time}"]);

                $pdo->commit();
                $success_message = "定金支付成功！定金ID: " . $deposit_id;
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "定金处理失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'use_deposit') {
            $deposit_id = $_POST['deposit_id'] ?? '';
            $order_id = $_POST['order_id'] ?? '';

            try {
                $pdo->beginTransaction();

                // 获取定金信息
                $stmt = $pdo->prepare("SELECT * FROM deposits WHERE deposit_id = ? AND status = '已支付'");
                $stmt->execute([$deposit_id]);
                $deposit = $stmt->fetch();

                if (!$deposit) {
                    throw new Exception("未找到有效的定金记录");
                }

                // 更新定金状态
                $stmt = $pdo->prepare("UPDATE deposits SET status = '已使用', update_time = NOW() WHERE deposit_id = ?");
                $stmt->execute([$deposit_id]);

                // 如果提供了订单ID，将定金应用到订单
                if ($order_id) {
                    // 获取订单金额
                    $stmt = $pdo->prepare("SELECT total_amount FROM orders WHERE order_id = ?");
                    $stmt->execute([$order_id]);
                    $order = $stmt->fetch();

                    if ($order) {
                        // 计算实际支付金额（订单金额减去定金）
                        $actual_amount = max(0, $order['total_amount'] - $deposit['amount']);

                        // 添加支付记录
                        $payment_id = 'PAY' . date('YmdHis') . rand(100, 999);
                        $stmt = $pdo->prepare("INSERT INTO payments (payment_id, order_id, amount, method, status, pay_time) 
                                              VALUES (?, ?, ?, ?, '已支付', NOW())");
                        $stmt->execute([$payment_id, $order_id, $actual_amount, $deposit['payment_method']]);

                        // 更新订单状态
                        $stmt = $pdo->prepare("UPDATE orders SET status = '进行中', payment_time = NOW() WHERE order_id = ?");
                        $stmt->execute([$order_id]);
                    }
                }

                // 如果有桌台，更新桌台状态
                if ($deposit['table_id']) {
                    $stmt = $pdo->prepare("UPDATE dining_tables SET status = '用餐中' WHERE table_id = ?");
                    $stmt->execute([$deposit['table_id']]);
                }

                // 记录系统日志
                $stmt = $pdo->prepare("INSERT INTO system_logs (log_type, related_id, action_type, description) 
                                      VALUES ('payment', ?, '使用定金', ?)");
                $stmt->execute([$deposit_id, "定金 {$deposit_id} 已使用" . ($order_id ? "，应用到订单 {$order_id}" : "")]);

                $pdo->commit();
                $success_message = "定金已成功使用！";
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "使用定金失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'refund_deposit') {
            $deposit_id = $_POST['deposit_id'] ?? '';

            try {
                $pdo->beginTransaction();

                // 获取定金信息
                $stmt = $pdo->prepare("SELECT * FROM deposits WHERE deposit_id = ? AND status = '已支付'");
                $stmt->execute([$deposit_id]);
                $deposit = $stmt->fetch();

                if (!$deposit) {
                    throw new Exception("未找到有效的定金记录");
                }

                // 更新定金状态
                $stmt = $pdo->prepare("UPDATE deposits SET status = '已退款', update_time = NOW() WHERE deposit_id = ?");
                $stmt->execute([$deposit_id]);

                // 如果有桌台，更新桌台状态
                if ($deposit['table_id']) {
                    $stmt = $pdo->prepare("UPDATE dining_tables SET status = '空闲' WHERE table_id = ?");
                    $stmt->execute([$deposit['table_id']]);
                }

                // 记录系统日志
                $stmt = $pdo->prepare("INSERT INTO system_logs (log_type, related_id, action_type, description) 
                                      VALUES ('payment', ?, '退款定金', ?)");
                $stmt->execute([$deposit_id, "定金 {$deposit_id} 已退款，金额: {$deposit['amount']} 元"]);

                $pdo->commit();
                $success_message = "定金已成功退款！";
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "退款定金失败: " . $e->getMessage();
            }
        }
    }
}

// 获取可用桌台
try {
    $stmt = $pdo->query("SELECT * FROM dining_tables WHERE status = '空闲' ORDER BY table_id");
    $available_tables = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取桌台失败: " . $e->getMessage();
    $available_tables = [];
}

// 获取有效定金记录
try {
    $stmt = $pdo->query("SELECT d.*, u.phone, t.status as table_status
                        FROM deposits d
                        LEFT JOIN users u ON d.user_id = u.user_id
                        LEFT JOIN dining_tables t ON d.table_id = t.table_id
                        WHERE d.status = '已支付'
                        ORDER BY d.reservation_time ASC");
    $active_deposits = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取定金记录失败: " . $e->getMessage();
    $active_deposits = [];
}

// 获取历史定金记录
try {
    $stmt = $pdo->query("SELECT d.*, u.phone
                        FROM deposits d
                        LEFT JOIN users u ON d.user_id = u.user_id
                        WHERE d.status IN ('已使用', '已退款')
                        ORDER BY d.update_time DESC
                        LIMIT 50");
    $history_deposits = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取历史记录失败: " . $e->getMessage();
    $history_deposits = [];
}

// 获取待支付订单（用于应用定金）
try {
    $stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.total_amount, o.create_time,
                        u.phone
                        FROM orders o
                        LEFT JOIN users u ON o.user_id = u.user_id
                        WHERE o.status = '待支付'
                        ORDER BY o.create_time DESC");
    $pending_orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取待支付订单失败: " . $e->getMessage();
    $pending_orders = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>预付定金管理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .deposit-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(350px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .deposit-card {
            background: #fff;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            position: relative;
        }

        .deposit-card.active {
            border-left: 4px solid #2196F3;
        }

        .deposit-card.used {
            border-left: 4px solid #4caf50;
        }

        .deposit-card.refunded {
            border-left: 4px solid #f44336;
        }

        .deposit-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .deposit-id {
            font-weight: bold;
            font-size: 1.1em;
        }

        .deposit-status {
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-active {
            background: #2196F3;
        }

        .status-used {
            background: #4caf50;
        }

        .status-refunded {
            background: #f44336;
        }

        .deposit-info {
            margin-bottom: 15px;
        }

        .deposit-info p {
            margin: 5px 0;
            display: flex;
            justify-content: space-between;
        }

        .deposit-actions {
            display: flex;
            gap: 10px;
            margin-top: 15px;
        }

        .form-panel {
            background: #fff;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            margin-bottom: 30px;
        }

        .form-row {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 15px;
        }

        .form-group {
            flex: 1;
            min-width: 200px;
        }

        .form-control {
            width: 100%;
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .section-title {
            margin: 30px 0 15px;
            padding-bottom: 10px;
            border-bottom: 2px solid #eee;
            font-size: 1.5em;
            color: #333;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tab-nav {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab-btn {
            padding: 10px 20px;
            background: none;
            border: none;
            border-bottom: 3px solid transparent;
            cursor: pointer;
            font-size: 1em;
            color: #666;
        }

        .tab-btn.active {
            border-bottom-color: #2196F3;
            color: #2196F3;
            font-weight: bold;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .countdown {
            color: #f44336;
            font-weight: bold;
        }

        .order-select {
            width: 100%;
            padding: 8px;
            margin-bottom: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>预付定金管理</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="tab-container">
            <div class="tab-nav">
                <button class="tab-btn active" data-tab="new">添加定金</button>
                <button class="tab-btn" data-tab="active">有效定金</button>
                <button class="tab-btn" data-tab="history">历史记录</button>
            </div>

            <div class="tab-content active" id="new-tab">
                <h2>添加预付定金</h2>

                <div class="form-panel">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add_deposit">

                        <div class="form-row">
                            <div class="form-group">
                                <label>手机号码</label>
                                <input type="text" name="phone" class="form-control" required>
                            </div>
                            <div class="form-group">
                                <label>定金金额</label>
                                <input type="number" name="amount" class="form-control" min="1" step="0.01" required>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <label>支付方式</label>
                                <select name="payment_method" class="form-control" required>
                                    <option value="">选择支付方式</option>
                                    <option value="微信">微信支付</option>
                                    <option value="支付宝">支付宝</option>
                                    <option value="银行卡">银行卡</option>
                                    <option value="会员卡">会员余额</option>
                                    <option value="现金">现金</option>
                                </select>
                            </div>
                            <div class="form-group">
                                <label>预约时间</label>
                                <input type="datetime-local" name="reservation_time" class="form-control" required>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <label>桌台选择</label>
                                <select name="table_id" class="form-control">
                                    <option value="">不指定桌台</option>
                                    <?php foreach ($available_tables as $table): ?>
                                        <option value="<?php echo $table['table_id']; ?>">
                                            <?php echo $table['table_id']; ?>号桌
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="form-group">
                                <label>用餐人数</label>
                                <input type="number" name="people_count" class="form-control" min="1" value="2">
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <label>备注</label>
                                <textarea name="notes" class="form-control" rows="3"></textarea>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <button type="submit" class="btn btn-primary">确认收款</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>

            <div class="tab-content" id="active-tab">
                <h2>有效定金记录</h2>

                <?php if (empty($active_deposits)): ?>
                    <p>当前没有有效的定金记录</p>
                <?php else: ?>
                    <div class="deposit-grid">
                        <?php foreach ($active_deposits as $deposit): ?>
                            <div class="deposit-card active">
                                <div class="deposit-header">
                                    <div class="deposit-id">定金ID: <?php echo $deposit['deposit_id']; ?></div>
                                    <div class="deposit-status status-active">已支付</div>
                                </div>
                                <div class="deposit-info">
                                    <p>
                                        <span>手机号码:</span>
                                        <span><?php echo $deposit['phone']; ?></span>
                                    </p>
                                    <p>
                                        <span>定金金额:</span>
                                        <span>¥<?php echo number_format($deposit['amount'], 2); ?></span>
                                    </p>
                                    <p>
                                        <span>支付方式:</span>
                                        <span><?php echo $deposit['payment_method']; ?></span>
                                    </p>
                                    <p>
                                        <span>预约时间:</span>
                                        <span><?php echo date('Y-m-d H:i', strtotime($deposit['reservation_time'])); ?></span>
                                    </p>
                                    <p>
                                        <span>桌台:</span>
                                        <span><?php echo $deposit['table_id'] ? $deposit['table_id'] . '号桌' : '未指定'; ?></span>
                                    </p>
                                    <p>
                                        <span>用餐人数:</span>
                                        <span><?php echo $deposit['people_count']; ?>人</span>
                                    </p>
                                    <?php if ($deposit['notes']): ?>
                                        <p>
                                            <span>备注:</span>
                                            <span><?php echo $deposit['notes']; ?></span>
                                        </p>
                                    <?php endif; ?>

                                    <?php
                                    $now = new DateTime();
                                    $reservationTime = new DateTime($deposit['reservation_time']);
                                    $interval = $now->diff($reservationTime);
                                    $isPast = $now > $reservationTime;
                                    ?>

                                    <p>
                                        <span>状态:</span>
                                        <span class="<?php echo $isPast ? 'countdown' : ''; ?>">
                                            <?php
                                            if ($isPast) {
                                                echo "已过期 " . $interval->format('%a天%h小时%i分钟');
                                            } else {
                                                echo "距离预约还有 " . $interval->format('%a天%h小时%i分钟');
                                            }
                                            ?>
                                        </span>
                                    </p>
                                </div>

                                <div class="deposit-actions">
                                    <button type="button" class="btn btn-primary" onclick="showUseDepositForm('<?php echo $deposit['deposit_id']; ?>')">使用定金</button>
                                    <form method="post" action="" style="display: inline;">
                                        <input type="hidden" name="action" value="refund_deposit">
                                        <input type="hidden" name="deposit_id" value="<?php echo $deposit['deposit_id']; ?>">
                                        <button type="submit" class="btn btn-danger" onclick="return confirm('确定要退款吗？')">退款</button>
                                    </form>
                                </div>

                                <div id="use-form-<?php echo $deposit['deposit_id']; ?>" style="display: none; margin-top: 15px;">
                                    <form method="post" action="">
                                        <input type="hidden" name="action" value="use_deposit">
                                        <input type="hidden" name="deposit_id" value="<?php echo $deposit['deposit_id']; ?>">
                                        <div class="form-group">
                                            <label>选择应用到的订单（可选）</label>
                                            <select name="order_id" class="order-select">
                                                <option value="">不应用到订单</option>
                                                <?php foreach ($pending_orders as $order): ?>
                                                    <option value="<?php echo $order['order_id']; ?>">
                                                        <?php echo $order['order_id']; ?> -
                                                        ¥<?php echo number_format($order['total_amount'], 2); ?> -
                                                        <?php echo $order['phone']; ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <button type="submit" class="btn btn-success">确认使用</button>
                                        <button type="button" class="btn btn-secondary" onclick="hideUseDepositForm('<?php echo $deposit['deposit_id']; ?>')">取消</button>
                                    </form>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>

            <div class="tab-content" id="history-tab">
                <h2>历史定金记录</h2>

                <?php if (empty($history_deposits)): ?>
                    <p>暂无历史定金记录</p>
                <?php else: ?>
                    <div class="deposit-grid">
                        <?php foreach ($history_deposits as $deposit): ?>
                            <div class="deposit-card <?php echo $deposit['status'] === '已使用' ? 'used' : 'refunded'; ?>">
                                <div class="deposit-header">
                                    <div class="deposit-id">定金ID: <?php echo $deposit['deposit_id']; ?></div>
                                    <div class="deposit-status status-<?php echo $deposit['status'] === '已使用' ? 'used' : 'refunded'; ?>">
                                        <?php echo $deposit['status']; ?>
                                    </div>
                                </div>
                                <div class="deposit-info">
                                    <p>
                                        <span>手机号码:</span>
                                        <span><?php echo $deposit['phone']; ?></span>
                                    </p>
                                    <p>
                                        <span>定金金额:</span>
                                        <span>¥<?php echo number_format($deposit['amount'], 2); ?></span>
                                    </p>
                                    <p>
                                        <span>支付方式:</span>
                                        <span><?php echo $deposit['payment_method']; ?></span>
                                    </p>
                                    <p>
                                        <span>预约时间:</span>
                                        <span><?php echo date('Y-m-d H:i', strtotime($deposit['reservation_time'])); ?></span>
                                    </p>
                                    <p>
                                        <span>桌台:</span>
                                        <span><?php echo $deposit['table_id'] ? $deposit['table_id'] . '号桌' : '未指定'; ?></span>
                                    </p>
                                    <p>
                                        <span>更新时间:</span>
                                        <span><?php echo date('Y-m-d H:i', strtotime($deposit['update_time'])); ?></span>
                                    </p>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <script>
        // 标签页切换
        document.querySelectorAll('.tab-btn').forEach(button => {
            button.addEventListener('click', function() {
                // 更新按钮状态
                document.querySelectorAll('.tab-btn').forEach(btn => {
                    btn.classList.remove('active');
                });
                this.classList.add('active');

                // 更新内容显示
                const tabId = this.getAttribute('data-tab');
                document.querySelectorAll('.tab-content').forEach(content => {
                    content.classList.remove('active');
                });
                document.getElementById(tabId + '-tab').classList.add('active');
            });
        });

        // 显示使用定金表单
        function showUseDepositForm(depositId) {
            document.getElementById('use-form-' + depositId).style.display = 'block';
        }

        // 隐藏使用定金表单
        function hideUseDepositForm(depositId) {
            document.getElementById('use-form-' + depositId).style.display = 'none';
        }

        // 设置默认预约时间为当前时间后2小时
        window.onload = function() {
            const reservationInput = document.querySelector('input[name="reservation_time"]');
            if (reservationInput) {
                const now = new Date();
                now.setHours(now.getHours() + 2);
                const dateString = now.toISOString().slice(0, 16);
                reservationInput.value = dateString;
            }
        };

        // 自动刷新页面
        setTimeout(function() {
            location.reload();
        }, 60000); // 每60秒刷新一次
    </script>
</body>

</html>