<?php
require_once '../config.php';

// 创建发票表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS invoices (
        invoice_id VARCHAR(20) PRIMARY KEY,
        order_id VARCHAR(20),
        user_id INT,
        company_name VARCHAR(100),
        tax_number VARCHAR(50),
        amount DECIMAL(10,2),
        status ENUM('待开具', '已开具', '已作废') DEFAULT '待开具',
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        issue_time DATETIME,
        FOREIGN KEY (order_id) REFERENCES orders(order_id),
        FOREIGN KEY (user_id) REFERENCES users(user_id)
    )");
} catch (PDOException $e) {
    error_log("创建发票表失败: " . $e->getMessage());
}

// 处理发票申请
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'apply':
                $orderId = $_POST['order_id'];
                $companyName = $_POST['company_name'];
                $taxNumber = $_POST['tax_number'];

                try {
                    // 生成发票ID
                    $invoiceId = 'INV' . date('YmdHis') . rand(1000, 9999);

                    // 获取订单金额
                    $stmt = $pdo->prepare("SELECT total_amount, user_id FROM orders WHERE order_id = ?");
                    $stmt->execute([$orderId]);
                    $order = $stmt->fetch();

                    if ($order) {
                        $stmt = $pdo->prepare("INSERT INTO invoices (invoice_id, order_id, user_id, company_name, tax_number, amount) 
                                            VALUES (?, ?, ?, ?, ?, ?)");
                        $stmt->execute([$invoiceId, $orderId, $order['user_id'], $companyName, $taxNumber, $order['total_amount']]);

                        // 记录系统日志
                        log_action('invoice', $invoiceId, '申请发票', "订单号: $orderId");
                        echo json_encode(['status' => 'success', 'message' => '发票申请成功']);
                    }
                } catch (PDOException $e) {
                    echo json_encode(['status' => 'error', 'message' => '发票申请失败']);
                }
                break;

            case 'issue':
                $invoiceId = $_POST['invoice_id'];
                try {
                    $stmt = $pdo->prepare("UPDATE invoices SET status = '已开具', issue_time = NOW() WHERE invoice_id = ?");
                    $stmt->execute([$invoiceId]);

                    log_action('invoice', $invoiceId, '开具发票', null);
                    echo json_encode(['status' => 'success', 'message' => '发票开具成功']);
                } catch (PDOException $e) {
                    echo json_encode(['status' => 'error', 'message' => '发票开具失败']);
                }
                break;

            case 'void':
                $invoiceId = $_POST['invoice_id'];
                try {
                    $stmt = $pdo->prepare("UPDATE invoices SET status = '已作废' WHERE invoice_id = ?");
                    $stmt->execute([$invoiceId]);

                    log_action('invoice', $invoiceId, '作废发票', null);
                    echo json_encode(['status' => 'success', 'message' => '发票作废成功']);
                } catch (PDOException $e) {
                    echo json_encode(['status' => 'error', 'message' => '发票作废失败']);
                }
                break;
        }
        exit;
    }
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>电子发票管理</title>
    <link rel="stylesheet" href="style.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
</head>

<body>
    <div class="container">
        <h2>电子发票管理</h2>

        <!-- 发票申请表单 -->
        <div class="card">
            <h3>申请发票</h3>
            <form id="invoiceForm" class="form-container">
                <div class="form-group">
                    <label>订单号</label>
                    <select name="order_id" required>
                        <?php
                        $stmt = $pdo->query("SELECT order_id, total_amount FROM orders WHERE status = '已完成' 
                                          AND order_id NOT IN (SELECT order_id FROM invoices WHERE status != '已作废')");
                        while ($row = $stmt->fetch()) {
                            echo "<option value='{$row['order_id']}'>{$row['order_id']} (金额: ￥{$row['total_amount']})</option>";
                        }
                        ?>
                    </select>
                </div>
                <div class="form-group">
                    <label>公司名称</label>
                    <input type="text" name="company_name" required>
                </div>
                <div class="form-group">
                    <label>税号</label>
                    <input type="text" name="tax_number" required>
                </div>
                <button type="submit" class="btn-primary">申请发票</button>
            </form>
        </div>

        <!-- 发票列表 -->
        <div class="card">
            <h3>发票记录</h3>
            <table>
                <thead>
                    <tr>
                        <th>发票号</th>
                        <th>订单号</th>
                        <th>公司名称</th>
                        <th>金额</th>
                        <th>状态</th>
                        <th>申请时间</th>
                        <th>开具时间</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $stmt = $pdo->query("SELECT * FROM invoices ORDER BY create_time DESC");
                    while ($row = $stmt->fetch()) {
                        echo "<tr>";
                        echo "<td>{$row['invoice_id']}</td>";
                        echo "<td>{$row['order_id']}</td>";
                        echo "<td>{$row['company_name']}</td>";
                        echo "<td>￥{$row['amount']}</td>";
                        echo "<td>{$row['status']}</td>";
                        echo "<td>{$row['create_time']}</td>";
                        echo "<td>" . (isset($row['issue_time']) ? $row['issue_time'] : '-') . "</td>";
                        echo "<td>";
                        if ($row['status'] === '待开具') {
                            echo "<button onclick='issueInvoice(\"{$row['invoice_id']}\")'>开具</button>";
                            echo "<button onclick='voidInvoice(\"{$row['invoice_id']}\")'>作废</button>";
                        }
                        echo "</td>";
                        echo "</tr>";
                    }
                    ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        $(document).ready(function() {
            $('#invoiceForm').on('submit', function(e) {
                e.preventDefault();
                $.ajax({
                    url: 'invoice_management.php',
                    method: 'POST',
                    data: $(this).serialize() + '&action=apply',
                    success: function(response) {
                        const result = JSON.parse(response);
                        alert(result.message);
                        if (result.status === 'success') {
                            location.reload();
                        }
                    }
                });
            });
        });

        function issueInvoice(invoiceId) {
            if (confirm('确定要开具此发票吗？')) {
                $.ajax({
                    url: 'invoice_management.php',
                    method: 'POST',
                    data: {
                        action: 'issue',
                        invoice_id: invoiceId
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        alert(result.message);
                        if (result.status === 'success') {
                            location.reload();
                        }
                    }
                });
            }
        }

        function voidInvoice(invoiceId) {
            if (confirm('确定要作废此发票吗？')) {
                $.ajax({
                    url: 'invoice_management.php',
                    method: 'POST',
                    data: {
                        action: 'void',
                        invoice_id: invoiceId
                    },
                    success: function(response) {
                        const result = JSON.parse(response);
                        alert(result.message);
                        if (result.status === 'success') {
                            location.reload();
                        }
                    }
                });
            }
        }
    </script>
</body>

</html>