<?php
require_once '../config.php';

// 创建银行卡表（如果不存在）
try {
    $pdo->exec("CREATE TABLE IF NOT EXISTS bank_cards (
        card_id INT AUTO_INCREMENT PRIMARY KEY,
        user_id INT,
        card_number VARCHAR(20) NOT NULL,
        bank_name VARCHAR(50) NOT NULL,
        card_holder VARCHAR(50) NOT NULL,
        expiry_date VARCHAR(7),
        is_default BOOLEAN DEFAULT FALSE,
        create_time DATETIME DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (user_id) REFERENCES users(user_id)
    )");
} catch (Exception $e) {
    $error_message = "创建银行卡表失败: " . $e->getMessage();
}

// 处理支付操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        if ($_POST['action'] === 'process_payment') {
            $order_id = $_POST['order_id'] ?? '';
            $payment_method = $_POST['payment_method'] ?? '';
            $amount = $_POST['amount'] ?? 0;

            try {
                $pdo->beginTransaction();

                // 生成支付ID
                $payment_id = 'PAY' . date('YmdHis') . rand(100, 999);

                // 添加支付记录
                $stmt = $pdo->prepare("INSERT INTO payments (payment_id, order_id, amount, method, status, pay_time) 
                                      VALUES (?, ?, ?, ?, '已支付', NOW())");
                $stmt->execute([$payment_id, $order_id, $amount, $payment_method]);

                // 更新订单状态
                $stmt = $pdo->prepare("UPDATE orders SET status = '进行中', payment_time = NOW() WHERE order_id = ?");
                $stmt->execute([$order_id]);

                // 记录系统日志
                $stmt = $pdo->prepare("INSERT INTO system_logs (log_type, related_id, action_type, description) 
                                      VALUES ('payment', ?, '支付完成', ?)");
                $stmt->execute([$payment_id, "订单 {$order_id} 通过 {$payment_method} 支付了 {$amount} 元"]);

                $pdo->commit();
                $success_message = "支付成功！支付ID: " . $payment_id;
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "支付处理失败: " . $e->getMessage();
            }
        } elseif ($_POST['action'] === 'refund_payment') {
            $payment_id = $_POST['payment_id'] ?? '';

            try {
                $pdo->beginTransaction();

                // 获取支付信息
                $stmt = $pdo->prepare("SELECT order_id, amount, method FROM payments WHERE payment_id = ?");
                $stmt->execute([$payment_id]);
                $payment = $stmt->fetch();

                if (!$payment) {
                    throw new Exception("未找到支付记录");
                }

                // 更新支付状态
                $stmt = $pdo->prepare("UPDATE payments SET status = '已退款' WHERE payment_id = ?");
                $stmt->execute([$payment_id]);

                // 更新订单状态
                $stmt = $pdo->prepare("UPDATE orders SET status = '已取消' WHERE order_id = ?");
                $stmt->execute([$payment['order_id']]);

                // 记录系统日志
                $stmt = $pdo->prepare("INSERT INTO system_logs (log_type, related_id, action_type, description) 
                                      VALUES ('payment', ?, '退款', ?)");
                $stmt->execute([$payment_id, "订单 {$payment['order_id']} 的 {$payment['amount']} 元支付已退款"]);

                $pdo->commit();
                $success_message = "退款成功！";
            } catch (Exception $e) {
                $pdo->rollBack();
                $error_message = "退款处理失败: " . $e->getMessage();
            }
        }
    }
}

// 获取待支付订单
try {
    $stmt = $pdo->query("SELECT o.order_id, o.user_id, o.table_id, o.type, o.total_amount, o.create_time,
                        (SELECT COUNT(*) FROM order_details WHERE order_id = o.order_id) as items_count,
                        u.phone
                        FROM orders o
                        LEFT JOIN users u ON o.user_id = u.user_id
                        WHERE o.status = '待支付'
                        ORDER BY o.create_time DESC");
    $pending_orders = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取待支付订单失败: " . $e->getMessage();
    $pending_orders = [];
}

// 获取最近支付记录
try {
    $stmt = $pdo->query("SELECT p.payment_id, p.order_id, p.amount, p.method, p.status, p.pay_time,
                        o.type, o.table_id, u.phone
                        FROM payments p
                        JOIN orders o ON p.order_id = o.order_id
                        LEFT JOIN users u ON o.user_id = u.user_id
                        ORDER BY p.pay_time DESC
                        LIMIT 50");
    $recent_payments = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取支付记录失败: " . $e->getMessage();
    $recent_payments = [];
}

// 获取支付统计
try {
    $stmt = $pdo->query("SELECT 
                            COUNT(*) as total_payments,
                            SUM(CASE WHEN status = '已支付' THEN amount ELSE 0 END) as total_amount,
                            SUM(CASE WHEN status = '已退款' THEN amount ELSE 0 END) as refund_amount,
                            COUNT(CASE WHEN DATE(pay_time) = CURRENT_DATE THEN 1 END) as today_count,
                            SUM(CASE WHEN DATE(pay_time) = CURRENT_DATE AND status = '已支付' THEN amount ELSE 0 END) as today_amount
                        FROM payments");
    $payment_stats = $stmt->fetch();
} catch (Exception $e) {
    $error_message = "获取支付统计失败: " . $e->getMessage();
    $payment_stats = [];
}

// 获取支付方式统计
try {
    $stmt = $pdo->query("SELECT 
                            method,
                            COUNT(*) as count,
                            SUM(amount) as total_amount
                        FROM payments
                        WHERE status = '已支付'
                        GROUP BY method
                        ORDER BY total_amount DESC");
    $method_stats = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = "获取支付方式统计失败: " . $e->getMessage();
    $method_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>支付管理</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .dashboard {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .stat-card {
            background: #fff;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #2196F3;
            margin: 10px 0;
        }

        .stat-label {
            color: #666;
            font-size: 14px;
        }

        .payment-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(350px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .payment-card {
            background: #fff;
            border-radius: 8px;
            padding: 15px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            position: relative;
        }

        .payment-card.pending {
            border-left: 4px solid #ff9800;
        }

        .payment-card.completed {
            border-left: 4px solid #4caf50;
        }

        .payment-card.refunded {
            border-left: 4px solid #f44336;
        }

        .payment-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .payment-id {
            font-weight: bold;
            font-size: 1.1em;
        }

        .payment-status {
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-pending {
            background: #ff9800;
        }

        .status-paid {
            background: #4caf50;
        }

        .status-refunded {
            background: #f44336;
        }

        .payment-info {
            margin-bottom: 15px;
        }

        .payment-info p {
            margin: 5px 0;
            display: flex;
            justify-content: space-between;
        }

        .payment-actions {
            display: flex;
            gap: 10px;
            margin-top: 15px;
        }

        .payment-method-select {
            width: 100%;
            padding: 8px;
            margin-bottom: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .section-title {
            margin: 30px 0 15px;
            padding-bottom: 10px;
            border-bottom: 2px solid #eee;
            font-size: 1.5em;
            color: #333;
        }

        .method-stats {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-top: 20px;
        }

        .method-item {
            background: #f5f5f5;
            border-radius: 8px;
            padding: 10px 15px;
            flex: 1;
            min-width: 150px;
            text-align: center;
        }

        .method-name {
            font-weight: bold;
            margin-bottom: 5px;
        }

        .method-value {
            color: #2196F3;
            font-size: 1.2em;
        }

        .method-count {
            color: #666;
            font-size: 0.9em;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tab-nav {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab-btn {
            padding: 10px 20px;
            background: none;
            border: none;
            border-bottom: 3px solid transparent;
            cursor: pointer;
            font-size: 1em;
            color: #666;
        }

        .tab-btn.active {
            border-bottom-color: #2196F3;
            color: #2196F3;
            font-weight: bold;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>支付管理</h1>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <div class="dashboard">
            <div class="stat-card">
                <div class="stat-value">¥<?php echo number_format($payment_stats['total_amount'] ?? 0, 2); ?></div>
                <div class="stat-label">总收入</div>
            </div>
            <div class="stat-card">
                <div class="stat-value">¥<?php echo number_format($payment_stats['refund_amount'] ?? 0, 2); ?></div>
                <div class="stat-label">总退款</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?php echo $payment_stats['total_payments'] ?? 0; ?></div>
                <div class="stat-label">总交易数</div>
            </div>
            <div class="stat-card">
                <div class="stat-value">¥<?php echo number_format($payment_stats['today_amount'] ?? 0, 2); ?></div>
                <div class="stat-label">今日收入</div>
            </div>
        </div>

        <div class="method-stats">
            <?php foreach ($method_stats as $method): ?>
                <div class="method-item">
                    <div class="method-name"><?php echo $method['method']; ?></div>
                    <div class="method-value">¥<?php echo number_format($method['total_amount'], 2); ?></div>
                    <div class="method-count"><?php echo $method['count']; ?>笔交易</div>
                </div>
            <?php endforeach; ?>
        </div>

        <div class="tab-container">
            <div class="tab-nav">
                <button class="tab-btn active" data-tab="pending">待支付订单</button>
                <button class="tab-btn" data-tab="history">支付记录</button>
            </div>

            <div class="tab-content active" id="pending-tab">
                <h2>待支付订单</h2>

                <?php if (empty($pending_orders)): ?>
                    <p>当前没有待支付的订单</p>
                <?php else: ?>
                    <div class="payment-grid">
                        <?php foreach ($pending_orders as $order): ?>
                            <div class="payment-card pending">
                                <div class="payment-header">
                                    <div class="payment-id">订单号: <?php echo $order['order_id']; ?></div>
                                    <div class="payment-status status-pending">待支付</div>
                                </div>
                                <div class="payment-info">
                                    <p>
                                        <span>订单类型:</span>
                                        <span><?php echo $order['type']; ?></span>
                                    </p>
                                    <p>
                                        <span>桌号/手机:</span>
                                        <span><?php echo $order['table_id'] ? $order['table_id'] . '号桌' : $order['phone']; ?></span>
                                    </p>
                                    <p>
                                        <span>商品数量:</span>
                                        <span><?php echo $order['items_count']; ?>件</span>
                                    </p>
                                    <p>
                                        <span>订单金额:</span>
                                        <span>¥<?php echo number_format($order['total_amount'], 2); ?></span>
                                    </p>
                                    <p>
                                        <span>下单时间:</span>
                                        <span><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></span>
                                    </p>
                                </div>
                                <form method="post" action="">
                                    <input type="hidden" name="action" value="process_payment">
                                    <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                                    <input type="hidden" name="amount" value="<?php echo $order['total_amount']; ?>">
                                    <select name="payment_method" class="payment-method-select" required>
                                        <option value="">选择支付方式</option>
                                        <option value="微信">微信支付</option>
                                        <option value="支付宝">支付宝</option>
                                        <option value="银行卡">银行卡</option>
                                        <option value="会员卡">会员余额</option>
                                        <option value="现金">现金</option>
                                    </select>
                                    <div class="payment-actions">
                                        <button type="submit" class="btn btn-primary">确认支付</button>
                                    </div>
                                </form>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>

            <div class="tab-content" id="history-tab">
                <h2>支付记录</h2>

                <?php if (empty($recent_payments)): ?>
                    <p>暂无支付记录</p>
                <?php else: ?>
                    <div class="payment-grid">
                        <?php foreach ($recent_payments as $payment): ?>
                            <div class="payment-card <?php echo $payment['status'] === '已支付' ? 'completed' : 'refunded'; ?>">
                                <div class="payment-header">
                                    <div class="payment-id">支付ID: <?php echo $payment['payment_id']; ?></div>
                                    <div class="payment-status status-<?php echo $payment['status'] === '已支付' ? 'paid' : 'refunded'; ?>">
                                        <?php echo $payment['status']; ?>
                                    </div>
                                </div>
                                <div class="payment-info">
                                    <p>
                                        <span>订单号:</span>
                                        <span><?php echo $payment['order_id']; ?></span>
                                    </p>
                                    <p>
                                        <span>支付金额:</span>
                                        <span>¥<?php echo number_format($payment['amount'], 2); ?></span>
                                    </p>
                                    <p>
                                        <span>支付方式:</span>
                                        <span><?php echo $payment['method']; ?></span>
                                    </p>
                                    <p>
                                        <span>订单类型:</span>
                                        <span><?php echo $payment['type']; ?></span>
                                    </p>
                                    <p>
                                        <span>桌号/手机:</span>
                                        <span><?php echo $payment['table_id'] ? $payment['table_id'] . '号桌' : $payment['phone']; ?></span>
                                    </p>
                                    <p>
                                        <span>支付时间:</span>
                                        <span><?php echo date('Y-m-d H:i', strtotime($payment['pay_time'])); ?></span>
                                    </p>
                                </div>
                                <?php if ($payment['status'] === '已支付'): ?>
                                    <form method="post" action="">
                                        <input type="hidden" name="action" value="refund_payment">
                                        <input type="hidden" name="payment_id" value="<?php echo $payment['payment_id']; ?>">
                                        <div class="payment-actions">
                                            <button type="submit" class="btn btn-danger" onclick="return confirm('确定要退款吗？')">申请退款</button>
                                            <button type="button" class="btn btn-secondary" onclick="printReceipt('<?php echo $payment['payment_id']; ?>')">打印小票</button>
                                        </div>
                                    </form>
                                <?php endif; ?>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <script>
        // 标签页切换
        document.querySelectorAll('.tab-btn').forEach(button => {
            button.addEventListener('click', function() {
                // 更新按钮状态
                document.querySelectorAll('.tab-btn').forEach(btn => {
                    btn.classList.remove('active');
                });
                this.classList.add('active');

                // 更新内容显示
                const tabId = this.getAttribute('data-tab');
                document.querySelectorAll('.tab-content').forEach(content => {
                    content.classList.remove('active');
                });
                document.getElementById(tabId + '-tab').classList.add('active');
            });
        });

        // 打印小票函数
        function printReceipt(paymentId) {
            // 在实际项目中，这里应该调用打印API或打开打印预览窗口
            alert('正在打印支付ID为 ' + paymentId + ' 的小票');
        }

        // 自动刷新页面
        setTimeout(function() {
            location.reload();
        }, 60000); // 每60秒刷新一次
    </script>
</body>

</html>