<?php
session_start();
require '../config.php';

// 权限验证
if ($_SESSION['role'] !== 'admin') {
    header("Location: ../home.php");
    exit;
}

$error = '';
$employee = [];

// 获取员工信息
if (isset($_GET['id'])) {
    $employee_id = (int)$_GET['id'];
    $stmt = $pdo->prepare("
        SELECT 
            employee_id,
            username,
            role,
            DATE_FORMAT(created_at, '%Y-%m-%d') AS reg_date,
            last_login
        FROM employees 
        WHERE employee_id = ?
    ");
    $stmt->execute([$employee_id]);
    $employee = $stmt->fetch();

    if (!$employee) {
        $error = "员工不存在";
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $employee) {
    $username = trim($_POST['username']);
    $role = $_POST['role'];
    $new_password = $_POST['new_password'];

    try {
        // 基础验证
        if (empty($username)) {
            throw new Exception("用户名不能为空");
        }

        // 验证角色有效性
        $allowed_roles = ['admin', 'cashier', 'chef', 'manager'];
        if (!in_array($role, $allowed_roles)) {
            throw new Exception("无效的角色类型");
        }

        // 构建更新字段
        $update_fields = [
            'username = ?' => $username,
            'role = ?' => $role
        ];

        // 密码更新逻辑
        if (!empty($new_password)) {
            $update_fields['password_hash = ?'] = hash('sha256', $new_password);
        }

        // 准备SQL语句
        $set_clause = implode(', ', array_keys($update_fields));
        $values = array_values($update_fields);
        $values[] = $employee['employee_id'];

        $stmt = $pdo->prepare("
            UPDATE employees 
            SET $set_clause
            WHERE employee_id = ?
        ");
        $stmt->execute($values);

        $_SESSION['success'] = "员工信息更新成功" . (!empty($new_password) ? "（密码已更新）" : "");
        log_action('action', '更新员工信息', "更新员工ID: $employee_id", 'update');
        header("Location: user_management.php");
        exit;
    } catch (PDOException $e) {
        $error = "操作失败：" . ($e->getCode() == 23000 ? '用户名已存在' : $e->getMessage());
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 角色映射配置
$roleMap = [
    'admin'    => '管理员',
    'cashier'  => '收银员',
    'chef'     => '厨师',
    'manager'  => '店长'
];
?>
<!DOCTYPE html>
<html>

<head>
    <title>编辑员工</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .password-field {
            position: relative;
            margin-top: 15px;
        }

        .show-password {
            position: absolute;
            right: 10px;
            top: 35px;
            cursor: pointer;
            color: #666;
        }

        .password-hint {
            font-size: 0.9em;
            color: #666;
            margin-top: 5px;
        }

        .container {
            max-width: 800px;
            margin: 20px auto;
        }

        .alert {
            padding: 10px;
            margin: 10px 0;
        }

        .error {
            background: #ffebee;
            color: #c62828;
        }

        .card {
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
        }

        input[type="text"],
        select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .btn-primary {
            background: #2196F3;
            color: white;
            padding: 8px 16px;
            border: none;
            border-radius: 4px;
        }

        .btn-cancel {
            background: #f8f9fa;
            color: #666;
            padding: 8px 16px;
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-left: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>编辑员工</h2>

        <?php if ($error): ?>
            <div class="alert error"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if ($employee): ?>
            <div class="card">
                <form method="POST">
                    <div class="form-group">
                        <label>用户名</label>
                        <input type="text" name="username"
                            value="<?= htmlspecialchars($employee['username']) ?>"
                            required>
                    </div>

                    <div class="form-group">
                        <label>角色</label>
                        <select name="role" required>
                            <?php foreach ($roleMap as $value => $label): ?>
                                <option value="<?= $value ?>"
                                    <?= $employee['role'] === $value ? 'selected' : '' ?>>
                                    <?= $label ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group password-field">
                        <label>修改密码</label>
                        <input type="password"
                            name="new_password"
                            id="newPassword"
                            placeholder="留空则不修改密码">
                        <span class="show-password" onclick="togglePassword()">
                            <i class="fas fa-eye"></i>
                        </span>
                        <div class="password-hint">可选字段，输入新密码将覆盖旧密码</div>
                    </div>

                    <div class="form-footer">
                        <button type="submit" class="btn-primary">保存更改</button>
                        <a href="user_management.php" class="btn-cancel">取消</a>
                    </div>
                </form>
            </div>
        <?php else: ?>
            <div class="alert error"><?= $error ?: '员工不存在' ?></div>
        <?php endif; ?>
    </div>

    <script>
        function togglePassword() {
            const pwdField = document.getElementById('newPassword');
            const icon = document.querySelector('.show-password i');
            if (pwdField.type === 'password') {
                pwdField.type = 'text';
                icon.classList.replace('fa-eye', 'fa-eye-slash');
            } else {
                pwdField.type = 'password';
                icon.classList.replace('fa-eye-slash', 'fa-eye');
            }
        }
    </script>
</body>

</html>